# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_additional_snapshot_info.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_additional_snapshot_info.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nXcom/digitalasset/canton/sequencer/admin/v30/sequencer_bft_additional_snapshot_info.proto\x12+com.digitalasset.canton.sequencer.admin.v30\"\x9f\t\n\"BftSequencerSnapshotAdditionalInfo\x12\x99\x01\n\x14sequencers_active_at\x18\x01 \x03(\x0b\x32g.com.digitalasset.canton.sequencer.admin.v30.BftSequencerSnapshotAdditionalInfo.SequencersActiveAtEntryR\x12sequencersActiveAt\x1a\xa8\x01\n\x17SequencersActiveAtEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12w\n\x05value\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.sequencer.admin.v30.BftSequencerSnapshotAdditionalInfo.SequencerActiveAtR\x05value:\x02\x38\x01\x1a\xb1\x06\n\x11SequencerActiveAt\x12\x1c\n\ttimestamp\x18\x01 \x01(\x03R\ttimestamp\x12\x31\n\x12start_epoch_number\x18\x02 \x01(\x03H\x00R\x10startEpochNumber\x88\x01\x01\x12L\n!first_block_number_in_start_epoch\x18\x03 \x01(\x03H\x01R\x1c\x66irstBlockNumberInStartEpoch\x88\x01\x01\x12S\n$start_epoch_topology_query_timestamp\x18\x04 \x01(\x03H\x02R startEpochTopologyQueryTimestamp\x88\x01\x01\x12\\\n)start_epoch_could_alter_ordering_topology\x18\x05 \x01(\x08H\x03R$startEpochCouldAlterOrderingTopology\x88\x01\x01\x12/\n\x11previous_bft_time\x18\x06 \x01(\x03H\x04R\x0fpreviousBftTime\x88\x01\x01\x12Y\n\'previous_epoch_topology_query_timestamp\x18\x07 \x01(\x03H\x05R#previousEpochTopologyQueryTimestamp\x88\x01\x01\x12\x46\n\x1dleader_selection_policy_state\x18\x08 \x01(\x0cH\x06R\x1aleaderSelectionPolicyState\x88\x01\x01\x42\x15\n\x13_start_epoch_numberB$\n\"_first_block_number_in_start_epochB\'\n%_start_epoch_topology_query_timestampB,\n*_start_epoch_could_alter_ordering_topologyB\x14\n\x12_previous_bft_timeB*\n(_previous_epoch_topology_query_timestampB \n\x1e_leader_selection_policy_state\"\x9f\x07\n#BlacklistLeaderSelectionPolicyState\x12!\n\x0c\x65poch_number\x18\x01 \x01(\x03R\x0b\x65pochNumber\x12,\n\x12start_block_number\x18\x02 \x01(\x03R\x10startBlockNumber\x12}\n\tblacklist\x18\x03 \x03(\x0b\x32_.com.digitalasset.canton.sequencer.admin.v30.BlacklistLeaderSelectionPolicyState.BlacklistEntryR\tblacklist\x1a\x9e\x01\n\x0e\x42lacklistEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12v\n\x05value\x18\x02 \x01(\x0b\x32`.com.digitalasset.canton.sequencer.admin.v30.BlacklistLeaderSelectionPolicyState.BlacklistStatusR\x05value:\x02\x38\x01\x1a\x86\x04\n\x0f\x42lacklistStatus\x12\x85\x01\n\x08on_trial\x18\x01 \x01(\x0b\x32h.com.digitalasset.canton.sequencer.admin.v30.BlacklistLeaderSelectionPolicyState.BlacklistStatus.OnTrialH\x00R\x07onTrial\x12\x90\x01\n\x0b\x62lacklisted\x18\x02 \x01(\x0b\x32l.com.digitalasset.canton.sequencer.admin.v30.BlacklistLeaderSelectionPolicyState.BlacklistStatus.BlacklistedH\x00R\x0b\x62lacklisted\x1aJ\n\x07OnTrial\x12?\n\x1c\x66\x61iled_attempts_before_trial\x18\x01 \x01(\x03R\x19\x66\x61iledAttemptsBeforeTrial\x1a\x81\x01\n\x0b\x42lacklisted\x12\x34\n\x16\x66\x61iled_attempts_before\x18\x01 \x01(\x03R\x14\x66\x61iledAttemptsBefore\x12<\n\x1b\x65pochs_left_until_new_trial\x18\x02 \x01(\x03R\x17\x65pochsLeftUntilNewTrialB\x08\n\x06statusB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_additional_snapshot_info_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERSACTIVEATENTRY']._loaded_options = None
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERSACTIVEATENTRY']._serialized_options = b'8\001'
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTENTRY']._loaded_options = None
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTENTRY']._serialized_options = b'8\001'
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO']._serialized_start=138
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO']._serialized_end=1321
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERSACTIVEATENTRY']._serialized_start=333
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERSACTIVEATENTRY']._serialized_end=501
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERACTIVEAT']._serialized_start=504
  _globals['_BFTSEQUENCERSNAPSHOTADDITIONALINFO_SEQUENCERACTIVEAT']._serialized_end=1321
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE']._serialized_start=1324
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE']._serialized_end=2251
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTENTRY']._serialized_start=1572
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTENTRY']._serialized_end=1730
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS']._serialized_start=1733
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS']._serialized_end=2251
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS_ONTRIAL']._serialized_start=2035
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS_ONTRIAL']._serialized_end=2109
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS_BLACKLISTED']._serialized_start=2112
  _globals['_BLACKLISTLEADERSELECTIONPOLICYSTATE_BLACKLISTSTATUS_BLACKLISTED']._serialized_end=2241
# @@protoc_insertion_point(module_scope)
