# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import topology_manager_read_service_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/topology/admin/v30/topology_manager_read_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class TopologyManagerReadServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.ListNamespaceDelegation = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListNamespaceDelegation',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResponse.FromString,
                _registered_method=True)
        self.ListDecentralizedNamespaceDefinition = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListDecentralizedNamespaceDefinition',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionResponse.FromString,
                _registered_method=True)
        self.ListOwnerToKeyMapping = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListOwnerToKeyMapping',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResponse.FromString,
                _registered_method=True)
        self.ListPartyToKeyMapping = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyToKeyMapping',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingResponse.FromString,
                _registered_method=True)
        self.ListSynchronizerTrustCertificate = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerTrustCertificate',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateResponse.FromString,
                _registered_method=True)
        self.ListParticipantSynchronizerPermission = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListParticipantSynchronizerPermission',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionResponse.FromString,
                _registered_method=True)
        self.ListPartyHostingLimits = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyHostingLimits',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsResponse.FromString,
                _registered_method=True)
        self.ListVettedPackages = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListVettedPackages',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesResponse.FromString,
                _registered_method=True)
        self.ListPartyToParticipant = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyToParticipant',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantResponse.FromString,
                _registered_method=True)
        self.ListSynchronizerParametersState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerParametersState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateResponse.FromString,
                _registered_method=True)
        self.ListMediatorSynchronizerState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListMediatorSynchronizerState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateResponse.FromString,
                _registered_method=True)
        self.ListSequencerSynchronizerState = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSequencerSynchronizerState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateResponse.FromString,
                _registered_method=True)
        self.ListSynchronizerUpgradeAnnouncement = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerUpgradeAnnouncement',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementResponse.FromString,
                _registered_method=True)
        self.ListSequencerConnectionSuccessor = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSequencerConnectionSuccessor',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorResponse.FromString,
                _registered_method=True)
        self.ListAvailableStores = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListAvailableStores',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresResponse.FromString,
                _registered_method=True)
        self.ListAll = channel.unary_unary(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListAll',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
                _registered_method=True)
        self.ExportTopologySnapshot = channel.unary_stream(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ExportTopologySnapshot',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotResponse.FromString,
                _registered_method=True)
        self.ExportTopologySnapshotV2 = channel.unary_stream(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ExportTopologySnapshotV2',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Response.FromString,
                _registered_method=True)
        self.GenesisState = channel.unary_stream(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/GenesisState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateResponse.FromString,
                _registered_method=True)
        self.GenesisStateV2 = channel.unary_stream(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/GenesisStateV2',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Request.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Response.FromString,
                _registered_method=True)
        self.LogicalUpgradeState = channel.unary_stream(
                '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/LogicalUpgradeState',
                request_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateResponse.FromString,
                _registered_method=True)


class TopologyManagerReadServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def ListNamespaceDelegation(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListDecentralizedNamespaceDefinition(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListOwnerToKeyMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPartyToKeyMapping(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSynchronizerTrustCertificate(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListParticipantSynchronizerPermission(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPartyHostingLimits(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListVettedPackages(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListPartyToParticipant(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSynchronizerParametersState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListMediatorSynchronizerState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSequencerSynchronizerState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSynchronizerUpgradeAnnouncement(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListSequencerConnectionSuccessor(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAvailableStores(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ListAll(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportTopologySnapshot(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def ExportTopologySnapshotV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenesisState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GenesisStateV2(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def LogicalUpgradeState(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TopologyManagerReadServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'ListNamespaceDelegation': grpc.unary_unary_rpc_method_handler(
                    servicer.ListNamespaceDelegation,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResponse.SerializeToString,
            ),
            'ListDecentralizedNamespaceDefinition': grpc.unary_unary_rpc_method_handler(
                    servicer.ListDecentralizedNamespaceDefinition,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionResponse.SerializeToString,
            ),
            'ListOwnerToKeyMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.ListOwnerToKeyMapping,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResponse.SerializeToString,
            ),
            'ListPartyToKeyMapping': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartyToKeyMapping,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingResponse.SerializeToString,
            ),
            'ListSynchronizerTrustCertificate': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSynchronizerTrustCertificate,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateResponse.SerializeToString,
            ),
            'ListParticipantSynchronizerPermission': grpc.unary_unary_rpc_method_handler(
                    servicer.ListParticipantSynchronizerPermission,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionResponse.SerializeToString,
            ),
            'ListPartyHostingLimits': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartyHostingLimits,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsResponse.SerializeToString,
            ),
            'ListVettedPackages': grpc.unary_unary_rpc_method_handler(
                    servicer.ListVettedPackages,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesResponse.SerializeToString,
            ),
            'ListPartyToParticipant': grpc.unary_unary_rpc_method_handler(
                    servicer.ListPartyToParticipant,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantResponse.SerializeToString,
            ),
            'ListSynchronizerParametersState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSynchronizerParametersState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateResponse.SerializeToString,
            ),
            'ListMediatorSynchronizerState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListMediatorSynchronizerState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateResponse.SerializeToString,
            ),
            'ListSequencerSynchronizerState': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSequencerSynchronizerState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateResponse.SerializeToString,
            ),
            'ListSynchronizerUpgradeAnnouncement': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSynchronizerUpgradeAnnouncement,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementResponse.SerializeToString,
            ),
            'ListSequencerConnectionSuccessor': grpc.unary_unary_rpc_method_handler(
                    servicer.ListSequencerConnectionSuccessor,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorResponse.SerializeToString,
            ),
            'ListAvailableStores': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAvailableStores,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresResponse.SerializeToString,
            ),
            'ListAll': grpc.unary_unary_rpc_method_handler(
                    servicer.ListAll,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllResponse.SerializeToString,
            ),
            'ExportTopologySnapshot': grpc.unary_stream_rpc_method_handler(
                    servicer.ExportTopologySnapshot,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotResponse.SerializeToString,
            ),
            'ExportTopologySnapshotV2': grpc.unary_stream_rpc_method_handler(
                    servicer.ExportTopologySnapshotV2,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Response.SerializeToString,
            ),
            'GenesisState': grpc.unary_stream_rpc_method_handler(
                    servicer.GenesisState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateResponse.SerializeToString,
            ),
            'GenesisStateV2': grpc.unary_stream_rpc_method_handler(
                    servicer.GenesisStateV2,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Request.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Response.SerializeToString,
            ),
            'LogicalUpgradeState': grpc.unary_stream_rpc_method_handler(
                    servicer.LogicalUpgradeState,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class TopologyManagerReadService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def ListNamespaceDelegation(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListNamespaceDelegation',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListNamespaceDelegationResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListDecentralizedNamespaceDefinition(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListDecentralizedNamespaceDefinition',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListDecentralizedNamespaceDefinitionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListOwnerToKeyMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListOwnerToKeyMapping',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListOwnerToKeyMappingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPartyToKeyMapping(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyToKeyMapping',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToKeyMappingResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSynchronizerTrustCertificate(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerTrustCertificate',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerTrustCertificateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListParticipantSynchronizerPermission(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListParticipantSynchronizerPermission',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListParticipantSynchronizerPermissionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPartyHostingLimits(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyHostingLimits',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyHostingLimitsResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListVettedPackages(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListVettedPackages',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListVettedPackagesResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListPartyToParticipant(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListPartyToParticipant',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListPartyToParticipantResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSynchronizerParametersState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerParametersState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerParametersStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListMediatorSynchronizerState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListMediatorSynchronizerState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListMediatorSynchronizerStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSequencerSynchronizerState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSequencerSynchronizerState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerSynchronizerStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSynchronizerUpgradeAnnouncement(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSynchronizerUpgradeAnnouncement',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSynchronizerUpgradeAnnouncementResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListSequencerConnectionSuccessor(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListSequencerConnectionSuccessor',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListSequencerConnectionSuccessorResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAvailableStores(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListAvailableStores',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAvailableStoresResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ListAll(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ListAll',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ListAllResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportTopologySnapshot(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ExportTopologySnapshot',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def ExportTopologySnapshotV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/ExportTopologySnapshotV2',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.ExportTopologySnapshotV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenesisState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/GenesisState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GenesisStateV2(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/GenesisStateV2',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Request.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.GenesisStateV2Response.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def LogicalUpgradeState(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.topology.admin.v30.TopologyManagerReadService/LogicalUpgradeState',
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_topology__manager__read__service__pb2.LogicalUpgradeStateResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
