# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/package_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/package_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/package_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"L\n\x13ListPackagesRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1f\n\x0b\x66ilter_name\x18\x02 \x01(\tR\nfilterName\"\xb2\x01\n\x12PackageDescription\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12;\n\x0buploaded_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nuploadedAt\x12\x12\n\x04size\x18\x05 \x01(\rR\x04size\"\x8c\x01\n\x14ListPackagesResponse\x12t\n\x14package_descriptions\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.PackageDescriptionR\x13packageDescriptions\":\n\x19GetPackageContentsRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\"\'\n\x11ModuleDescription\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\"\xb6\x02\n\x1aGetPackageContentsResponse\x12\x63\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.PackageDescriptionR\x0b\x64\x65scription\x12Z\n\x07modules\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ModuleDescriptionR\x07modules\x12,\n\x12is_utility_package\x18\x03 \x01(\x08R\x10isUtilityPackage\x12)\n\x10language_version\x18\x04 \x01(\tR\x0flanguageVersion\"<\n\x1bGetPackageReferencesRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\"q\n\x1cGetPackageReferencesResponse\x12Q\n\x04\x64\x61rs\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x04\x64\x61rs\"K\n\x14RemovePackageRequest\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12\x14\n\x05\x66orce\x18\x02 \x01(\x08R\x05\x66orce\"I\n\x15RemovePackageResponse\x12\x30\n\x07success\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyR\x07success\"\x86\x01\n\x12ValidateDarRequest\x12\x12\n\x04\x64\x61ta\x18\x01 \x01(\x0cR\x04\x64\x61ta\x12\x1a\n\x08\x66ilename\x18\x02 \x01(\tR\x08\x66ilename\x12,\n\x0fsynchronizer_id\x18\x03 \x01(\tH\x00R\x0esynchronizerId\x88\x01\x01\x42\x12\n\x10_synchronizer_id\"=\n\x13ValidateDarResponse\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\"\xcc\x03\n\x10UploadDarRequest\x12\x61\n\x04\x64\x61rs\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.admin.participant.v30.UploadDarRequest.UploadDarDataR\x04\x64\x61rs\x12(\n\x10vet_all_packages\x18\x02 \x01(\x08R\x0evetAllPackages\x12/\n\x13synchronize_vetting\x18\x03 \x01(\x08R\x12synchronizeVetting\x12,\n\x0fsynchronizer_id\x18\x04 \x01(\tH\x00R\x0esynchronizerId\x88\x01\x01\x1a\xb7\x01\n\rUploadDarData\x12\x14\n\x05\x62ytes\x18\x01 \x01(\x0cR\x05\x62ytes\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x12<\n\x18\x65xpected_main_package_id\x18\x03 \x01(\tH\x01R\x15\x65xpectedMainPackageId\x88\x01\x01\x42\x0e\n\x0c_descriptionB\x1b\n\x19_expected_main_package_idB\x12\n\x10_synchronizer_id\",\n\x11UploadDarResponse\x12\x17\n\x07\x64\x61r_ids\x18\x01 \x03(\tR\x06\x64\x61rIds\":\n\x10RemoveDarRequest\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\"\x13\n\x11RemoveDarResponse\"7\n\rGetDarRequest\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\"t\n\x0e\x44\x61rDescription\x12\x12\n\x04main\x18\x01 \x01(\tR\x04main\x12\x12\n\x04name\x18\x02 \x01(\tR\x04name\x12\x18\n\x07version\x18\x03 \x01(\tR\x07version\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"}\n\x0eGetDarResponse\x12\x18\n\x07payload\x18\x01 \x01(\x0cR\x07payload\x12Q\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x04\x64\x61ta\"H\n\x0fListDarsRequest\x12\x14\n\x05limit\x18\x01 \x01(\x05R\x05limit\x12\x1f\n\x0b\x66ilter_name\x18\x02 \x01(\tR\nfilterName\"e\n\x10ListDarsResponse\x12Q\n\x04\x64\x61rs\x18\x01 \x03(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x04\x64\x61rs\"?\n\x15GetDarContentsRequest\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\"\xd8\x01\n\x16GetDarContentsResponse\x12_\n\x0b\x64\x65scription\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.DarDescriptionR\x0b\x64\x65scription\x12]\n\x08packages\x18\x02 \x03(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.PackageDescriptionR\x08packages\"\x9b\x01\n\rVetDarRequest\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\x12 \n\x0bsynchronize\x18\x02 \x01(\x08R\x0bsynchronize\x12,\n\x0fsynchronizer_id\x18\x03 \x01(\tH\x00R\x0esynchronizerId\x88\x01\x01\x42\x12\n\x10_synchronizer_id\"\x10\n\x0eVetDarResponse\"{\n\x0fUnvetDarRequest\x12&\n\x0fmain_package_id\x18\x01 \x01(\tR\rmainPackageId\x12,\n\x0fsynchronizer_id\x18\x02 \x01(\tH\x00R\x0esynchronizerId\x88\x01\x01\x42\x12\n\x10_synchronizer_id\"\x12\n\x10UnvetDarResponse2\xaa\x0e\n\x0ePackageService\x12\x97\x01\n\x0cListPackages\x12\x42.com.digitalasset.canton.admin.participant.v30.ListPackagesRequest\x1a\x43.com.digitalasset.canton.admin.participant.v30.ListPackagesResponse\x12\xa9\x01\n\x12GetPackageContents\x12H.com.digitalasset.canton.admin.participant.v30.GetPackageContentsRequest\x1aI.com.digitalasset.canton.admin.participant.v30.GetPackageContentsResponse\x12\xaf\x01\n\x14GetPackageReferences\x12J.com.digitalasset.canton.admin.participant.v30.GetPackageReferencesRequest\x1aK.com.digitalasset.canton.admin.participant.v30.GetPackageReferencesResponse\x12\x9a\x01\n\rRemovePackage\x12\x43.com.digitalasset.canton.admin.participant.v30.RemovePackageRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.RemovePackageResponse\x12\x94\x01\n\x0bValidateDar\x12\x41.com.digitalasset.canton.admin.participant.v30.ValidateDarRequest\x1a\x42.com.digitalasset.canton.admin.participant.v30.ValidateDarResponse\x12\x8e\x01\n\tUploadDar\x12?.com.digitalasset.canton.admin.participant.v30.UploadDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.UploadDarResponse\x12\x8e\x01\n\tRemoveDar\x12?.com.digitalasset.canton.admin.participant.v30.RemoveDarRequest\x1a@.com.digitalasset.canton.admin.participant.v30.RemoveDarResponse\x12\x85\x01\n\x06GetDar\x12<.com.digitalasset.canton.admin.participant.v30.GetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.GetDarResponse\x12\x8b\x01\n\x08ListDars\x12>.com.digitalasset.canton.admin.participant.v30.ListDarsRequest\x1a?.com.digitalasset.canton.admin.participant.v30.ListDarsResponse\x12\x9d\x01\n\x0eGetDarContents\x12\x44.com.digitalasset.canton.admin.participant.v30.GetDarContentsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.GetDarContentsResponse\x12\x85\x01\n\x06VetDar\x12<.com.digitalasset.canton.admin.participant.v30.VetDarRequest\x1a=.com.digitalasset.canton.admin.participant.v30.VetDarResponse\x12\x8b\x01\n\x08UnvetDar\x12>.com.digitalasset.canton.admin.participant.v30.UnvetDarRequest\x1a?.com.digitalasset.canton.admin.participant.v30.UnvetDarResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.package_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_LISTPACKAGESREQUEST']._serialized_start=180
  _globals['_LISTPACKAGESREQUEST']._serialized_end=256
  _globals['_PACKAGEDESCRIPTION']._serialized_start=259
  _globals['_PACKAGEDESCRIPTION']._serialized_end=437
  _globals['_LISTPACKAGESRESPONSE']._serialized_start=440
  _globals['_LISTPACKAGESRESPONSE']._serialized_end=580
  _globals['_GETPACKAGECONTENTSREQUEST']._serialized_start=582
  _globals['_GETPACKAGECONTENTSREQUEST']._serialized_end=640
  _globals['_MODULEDESCRIPTION']._serialized_start=642
  _globals['_MODULEDESCRIPTION']._serialized_end=681
  _globals['_GETPACKAGECONTENTSRESPONSE']._serialized_start=684
  _globals['_GETPACKAGECONTENTSRESPONSE']._serialized_end=994
  _globals['_GETPACKAGEREFERENCESREQUEST']._serialized_start=996
  _globals['_GETPACKAGEREFERENCESREQUEST']._serialized_end=1056
  _globals['_GETPACKAGEREFERENCESRESPONSE']._serialized_start=1058
  _globals['_GETPACKAGEREFERENCESRESPONSE']._serialized_end=1171
  _globals['_REMOVEPACKAGEREQUEST']._serialized_start=1173
  _globals['_REMOVEPACKAGEREQUEST']._serialized_end=1248
  _globals['_REMOVEPACKAGERESPONSE']._serialized_start=1250
  _globals['_REMOVEPACKAGERESPONSE']._serialized_end=1323
  _globals['_VALIDATEDARREQUEST']._serialized_start=1326
  _globals['_VALIDATEDARREQUEST']._serialized_end=1460
  _globals['_VALIDATEDARRESPONSE']._serialized_start=1462
  _globals['_VALIDATEDARRESPONSE']._serialized_end=1523
  _globals['_UPLOADDARREQUEST']._serialized_start=1526
  _globals['_UPLOADDARREQUEST']._serialized_end=1986
  _globals['_UPLOADDARREQUEST_UPLOADDARDATA']._serialized_start=1783
  _globals['_UPLOADDARREQUEST_UPLOADDARDATA']._serialized_end=1966
  _globals['_UPLOADDARRESPONSE']._serialized_start=1988
  _globals['_UPLOADDARRESPONSE']._serialized_end=2032
  _globals['_REMOVEDARREQUEST']._serialized_start=2034
  _globals['_REMOVEDARREQUEST']._serialized_end=2092
  _globals['_REMOVEDARRESPONSE']._serialized_start=2094
  _globals['_REMOVEDARRESPONSE']._serialized_end=2113
  _globals['_GETDARREQUEST']._serialized_start=2115
  _globals['_GETDARREQUEST']._serialized_end=2170
  _globals['_DARDESCRIPTION']._serialized_start=2172
  _globals['_DARDESCRIPTION']._serialized_end=2288
  _globals['_GETDARRESPONSE']._serialized_start=2290
  _globals['_GETDARRESPONSE']._serialized_end=2415
  _globals['_LISTDARSREQUEST']._serialized_start=2417
  _globals['_LISTDARSREQUEST']._serialized_end=2489
  _globals['_LISTDARSRESPONSE']._serialized_start=2491
  _globals['_LISTDARSRESPONSE']._serialized_end=2592
  _globals['_GETDARCONTENTSREQUEST']._serialized_start=2594
  _globals['_GETDARCONTENTSREQUEST']._serialized_end=2657
  _globals['_GETDARCONTENTSRESPONSE']._serialized_start=2660
  _globals['_GETDARCONTENTSRESPONSE']._serialized_end=2876
  _globals['_VETDARREQUEST']._serialized_start=2879
  _globals['_VETDARREQUEST']._serialized_end=3034
  _globals['_VETDARRESPONSE']._serialized_start=3036
  _globals['_VETDARRESPONSE']._serialized_end=3052
  _globals['_UNVETDARREQUEST']._serialized_start=3054
  _globals['_UNVETDARREQUEST']._serialized_end=3177
  _globals['_UNVETDARRESPONSE']._serialized_start=3179
  _globals['_UNVETDARRESPONSE']._serialized_end=3197
  _globals['_PACKAGESERVICE']._serialized_start=3200
  _globals['_PACKAGESERVICE']._serialized_end=5034
# @@protoc_insertion_point(module_scope)
