# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/topology_transaction.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/topology_transaction.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import state_service_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_state__service__pb2
from . import trace_context_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_trace__context__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1com/daml/ledger/api/v2/topology_transaction.proto\x12\x16\x63om.daml.ledger.api.v2\x1a*com/daml/ledger/api/v2/state_service.proto\x1a*com/daml/ledger/api/v2/trace_context.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xba\x02\n\x13TopologyTransaction\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12\x16\n\x06offset\x18\x02 \x01(\x03R\x06offset\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12;\n\x0brecord_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12=\n\x06\x65vents\x18\x05 \x03(\x0b\x32%.com.daml.ledger.api.v2.TopologyEventR\x06\x65vents\x12I\n\rtrace_context\x18\x06 \x01(\x0b\x32$.com.daml.ledger.api.v2.TraceContextR\x0ctraceContext\"\xa9\x03\n\rTopologyEvent\x12\x85\x01\n!participant_authorization_changed\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.ParticipantAuthorizationChangedH\x00R\x1fparticipantAuthorizationChanged\x12\x85\x01\n!participant_authorization_revoked\x18\x02 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.ParticipantAuthorizationRevokedH\x00R\x1fparticipantAuthorizationRevoked\x12\x7f\n\x1fparticipant_authorization_added\x18\x03 \x01(\x0b\x32\x35.com.daml.ledger.api.v2.ParticipantAuthorizationAddedH\x00R\x1dparticipantAuthorizationAddedB\x07\n\x05\x65vent\"\xc7\x01\n\x1dParticipantAuthorizationAdded\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x64\n\x16participant_permission\x18\x03 \x01(\x0e\x32-.com.daml.ledger.api.v2.ParticipantPermissionR\x15participantPermission\"\xc9\x01\n\x1fParticipantAuthorizationChanged\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\x64\n\x16participant_permission\x18\x03 \x01(\x0e\x32-.com.daml.ledger.api.v2.ParticipantPermissionR\x15participantPermission\"c\n\x1fParticipantAuthorizationRevoked\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantIdB\x97\x01\n\x16\x63om.daml.ledger.api.v2B\x1dTopologyTransactionOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.topology_transaction_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\035TopologyTransactionOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=199
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=513
  _globals['_TOPOLOGYEVENT']._serialized_start=516
  _globals['_TOPOLOGYEVENT']._serialized_end=941
  _globals['_PARTICIPANTAUTHORIZATIONADDED']._serialized_start=944
  _globals['_PARTICIPANTAUTHORIZATIONADDED']._serialized_end=1143
  _globals['_PARTICIPANTAUTHORIZATIONCHANGED']._serialized_start=1146
  _globals['_PARTICIPANTAUTHORIZATIONCHANGED']._serialized_end=1347
  _globals['_PARTICIPANTAUTHORIZATIONREVOKED']._serialized_start=1349
  _globals['_PARTICIPANTAUTHORIZATIONREVOKED']._serialized_end=1448
# @@protoc_insertion_point(module_scope)
