# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.pruning.v30 import pruning_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_pruning_dot_v30_dot_pruning__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n^com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_pruning_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\x1a\x37\x63om/digitalasset/canton/admin/pruning/v30/pruning.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"w\n\x0f\x42\x66tPruneRequest\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\x12+\n\x12min_blocks_to_keep\x18\x02 \x01(\x05R\x0fminBlocksToKeep\",\n\x10\x42\x66tPruneResponse\x12\x18\n\x07message\x18\x01 \x01(\tR\x07message\"\x19\n\x17\x42\x66tPruningStatusRequest\"\x95\x02\n\x18\x42\x66tPruningStatusResponse\x12,\n\x12latest_block_epoch\x18\x01 \x01(\x03R\x10latestBlockEpoch\x12!\n\x0clatest_block\x18\x02 \x01(\x03R\x0blatestBlock\x12P\n\x16latest_block_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14latestBlockTimestamp\x12*\n\x11lower_bound_epoch\x18\x04 \x01(\x03R\x0flowerBoundEpoch\x12*\n\x11lower_bound_block\x18\x05 \x01(\x03R\x0flowerBoundBlock\"{\n\x15SetBftScheduleRequest\x12\x62\n\x08schedule\x18\x01 \x01(\x0b\x32\x46.com.digitalasset.canton.sequencer.admin.v30.BftOrdererPruningScheduleR\x08schedule\"\xa0\x01\n\x19\x42\x66tOrdererPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12+\n\x12min_blocks_to_keep\x18\x02 \x01(\x05R\x0fminBlocksToKeep\"\x18\n\x16SetBftScheduleResponse\"\x17\n\x15GetBftScheduleRequest\"|\n\x16GetBftScheduleResponse\x12\x62\n\x08schedule\x18\x01 \x01(\x0b\x32\x46.com.digitalasset.canton.sequencer.admin.v30.BftOrdererPruningScheduleR\x08schedule\"H\n\x19SetMinBlocksToKeepRequest\x12+\n\x12min_blocks_to_keep\x18\x01 \x01(\x05R\x0fminBlocksToKeep\"\x1c\n\x1aSetMinBlocksToKeepResponse2\x96\r\n(SequencerBftPruningAdministrationService\x12\x9f\x01\n\x10\x42\x66tPruningStatus\x12\x44.com.digitalasset.canton.sequencer.admin.v30.BftPruningStatusRequest\x1a\x45.com.digitalasset.canton.sequencer.admin.v30.BftPruningStatusResponse\x12\x87\x01\n\x08\x42\x66tPrune\x12<.com.digitalasset.canton.sequencer.admin.v30.BftPruneRequest\x1a=.com.digitalasset.canton.sequencer.admin.v30.BftPruneResponse\x12\x8c\x01\n\x0bSetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.SetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.SetScheduleResponse\x12\x99\x01\n\x0eSetBftSchedule\x12\x42.com.digitalasset.canton.sequencer.admin.v30.SetBftScheduleRequest\x1a\x43.com.digitalasset.canton.sequencer.admin.v30.SetBftScheduleResponse\x12\x80\x01\n\x07SetCron\x12\x39.com.digitalasset.canton.admin.pruning.v30.SetCronRequest\x1a:.com.digitalasset.canton.admin.pruning.v30.SetCronResponse\x12\x95\x01\n\x0eSetMaxDuration\x12@.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationRequest\x1a\x41.com.digitalasset.canton.admin.pruning.v30.SetMaxDurationResponse\x12\x8f\x01\n\x0cSetRetention\x12>.com.digitalasset.canton.admin.pruning.v30.SetRetentionRequest\x1a?.com.digitalasset.canton.admin.pruning.v30.SetRetentionResponse\x12\x92\x01\n\rClearSchedule\x12?.com.digitalasset.canton.admin.pruning.v30.ClearScheduleRequest\x1a@.com.digitalasset.canton.admin.pruning.v30.ClearScheduleResponse\x12\x8c\x01\n\x0bGetSchedule\x12=.com.digitalasset.canton.admin.pruning.v30.GetScheduleRequest\x1a>.com.digitalasset.canton.admin.pruning.v30.GetScheduleResponse\x12\x99\x01\n\x0eGetBftSchedule\x12\x42.com.digitalasset.canton.sequencer.admin.v30.GetBftScheduleRequest\x1a\x43.com.digitalasset.canton.sequencer.admin.v30.GetBftScheduleResponse\x12\xa5\x01\n\x12SetMinBlocksToKeep\x12\x46.com.digitalasset.canton.sequencer.admin.v30.SetMinBlocksToKeepRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.SetMinBlocksToKeepResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_pruning_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_BFTPRUNEREQUEST']._serialized_start=265
  _globals['_BFTPRUNEREQUEST']._serialized_end=384
  _globals['_BFTPRUNERESPONSE']._serialized_start=386
  _globals['_BFTPRUNERESPONSE']._serialized_end=430
  _globals['_BFTPRUNINGSTATUSREQUEST']._serialized_start=432
  _globals['_BFTPRUNINGSTATUSREQUEST']._serialized_end=457
  _globals['_BFTPRUNINGSTATUSRESPONSE']._serialized_start=460
  _globals['_BFTPRUNINGSTATUSRESPONSE']._serialized_end=737
  _globals['_SETBFTSCHEDULEREQUEST']._serialized_start=739
  _globals['_SETBFTSCHEDULEREQUEST']._serialized_end=862
  _globals['_BFTORDERERPRUNINGSCHEDULE']._serialized_start=865
  _globals['_BFTORDERERPRUNINGSCHEDULE']._serialized_end=1025
  _globals['_SETBFTSCHEDULERESPONSE']._serialized_start=1027
  _globals['_SETBFTSCHEDULERESPONSE']._serialized_end=1051
  _globals['_GETBFTSCHEDULEREQUEST']._serialized_start=1053
  _globals['_GETBFTSCHEDULEREQUEST']._serialized_end=1076
  _globals['_GETBFTSCHEDULERESPONSE']._serialized_start=1078
  _globals['_GETBFTSCHEDULERESPONSE']._serialized_end=1202
  _globals['_SETMINBLOCKSTOKEEPREQUEST']._serialized_start=1204
  _globals['_SETMINBLOCKSTOKEEPREQUEST']._serialized_end=1276
  _globals['_SETMINBLOCKSTOKEEPRESPONSE']._serialized_start=1278
  _globals['_SETMINBLOCKSTOKEEPRESPONSE']._serialized_end=1306
  _globals['_SEQUENCERBFTPRUNINGADMINISTRATIONSERVICE']._serialized_start=1309
  _globals['_SEQUENCERBFTPRUNINGADMINISTRATIONSERVICE']._serialized_end=2995
# @@protoc_insertion_point(module_scope)
