# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nPcom/digitalasset/canton/sequencer/api/v30/sequencer_authentication_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x83\x04\n\x17SequencerAuthentication\x1a\x64\n\x10\x43hallengeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x38\n\x18member_protocol_versions\x18\x02 \x03(\x05R\x16memberProtocolVersions\x1aM\n\x11\x43hallengeResponse\x12\x14\n\x05nonce\x18\x01 \x01(\x0cR\x05nonce\x12\"\n\x0c\x66ingerprints\x18\x02 \x03(\tR\x0c\x66ingerprints\x1a\x90\x01\n\x13\x41uthenticateRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\x12\x14\n\x05nonce\x18\x03 \x01(\x0cR\x05nonce\x1ag\n\x14\x41uthenticateResponse\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x12\x39\n\nexpires_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\texpiresAt\x1a%\n\rLogoutRequest\x12\x14\n\x05token\x18\x01 \x01(\x0cR\x05token\x1a\x10\n\x0eLogoutResponse2\xd1\x04\n\x1eSequencerAuthenticationService\x12\xb8\x01\n\tChallenge\x12S.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.ChallengeRequest\x1aT.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.ChallengeResponse\"\x00\x12\xc1\x01\n\x0c\x41uthenticate\x12V.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.AuthenticateRequest\x1aW.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.AuthenticateResponse\"\x00\x12\xaf\x01\n\x06Logout\x12P.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.LogoutRequest\x1aQ.com.digitalasset.canton.sequencer.api.v30.SequencerAuthentication.LogoutResponse\"\x00\x42ZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_authentication_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_SEQUENCERAUTHENTICATION']._serialized_start=210
  _globals['_SEQUENCERAUTHENTICATION']._serialized_end=725
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_start=237
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGEREQUEST']._serialized_end=337
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_start=339
  _globals['_SEQUENCERAUTHENTICATION_CHALLENGERESPONSE']._serialized_end=416
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_start=419
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATEREQUEST']._serialized_end=563
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_start=565
  _globals['_SEQUENCERAUTHENTICATION_AUTHENTICATERESPONSE']._serialized_end=668
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTREQUEST']._serialized_start=670
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTREQUEST']._serialized_end=707
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTRESPONSE']._serialized_start=709
  _globals['_SEQUENCERAUTHENTICATION_LOGOUTRESPONSE']._serialized_end=725
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_start=728
  _globals['_SEQUENCERAUTHENTICATIONSERVICE']._serialized_end=1321
# @@protoc_insertion_point(module_scope)
