# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/pruning/v30/pruning.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/pruning/v30/pruning.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7com/digitalasset/canton/admin/pruning/v30/pruning.proto\x12)com.digitalasset.canton.admin.pruning.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"l\n\x12SetScheduleRequest\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x15\n\x13SetScheduleResponse\"\x14\n\x12GetScheduleRequest\"m\n\x13GetScheduleResponse\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\"\x82\x01\n\x1dSetParticipantScheduleRequest\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\" \n\x1eSetParticipantScheduleResponse\"\x1f\n\x1dGetParticipantScheduleRequest\"\x83\x01\n\x1eGetParticipantScheduleResponse\x12\x61\n\x08schedule\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.pruning.v30.ParticipantPruningScheduleR\x08schedule\"\x9c\x01\n\x0fPruningSchedule\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\x12<\n\x0cmax_duration\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\x12\x37\n\tretention\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\xa8\x01\n\x1aParticipantPruningSchedule\x12V\n\x08schedule\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.admin.pruning.v30.PruningScheduleR\x08schedule\x12\x32\n\x15prune_internally_only\x18\x02 \x01(\x08R\x13pruneInternallyOnly\"\x16\n\x14\x43learScheduleRequest\"\x17\n\x15\x43learScheduleResponse\"$\n\x0eSetCronRequest\x12\x12\n\x04\x63ron\x18\x01 \x01(\tR\x04\x63ron\"\x11\n\x0fSetCronResponse\"U\n\x15SetMaxDurationRequest\x12<\n\x0cmax_duration\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0bmaxDuration\"\x18\n\x16SetMaxDurationResponse\"N\n\x13SetRetentionRequest\x12\x37\n\tretention\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\tretention\"\x16\n\x14SetRetentionResponse\"3\n\x1b\x46indPruningTimestampRequest\x12\x14\n\x05index\x18\x01 \x01(\x05R\x05index\"X\n\x1c\x46indPruningTimestampResponse\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"\x84\x01\n\x1fSetNoWaitCommitmentsFromRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"\"\n SetNoWaitCommitmentsFromResponse\"\x86\x01\n!ResetNoWaitCommitmentsFromRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"$\n\"ResetNoWaitCommitmentsFromResponse\":\n\rSynchronizers\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\"w\n\x1fGetNoWaitCommitmentsFromRequest\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\x12)\n\x10participant_uids\x18\x02 \x03(\tR\x0fparticipantUids\"\x91\x02\n GetNoWaitCommitmentsFromResponse\x12r\n\x14ignored_participants\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x13ignoredParticipants\x12y\n\x18not_ignored_participants\x18\x02 \x03(\x0b\x32?.com.digitalasset.canton.admin.pruning.v30.WaitCommitmentsSetupR\x16notIgnoredParticipants\"\xae\x01\n\x14WaitCommitmentsSetup\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12^\n\rsynchronizers\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.pruning.v30.SynchronizersR\rsynchronizersBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.pruning.v30.pruning_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/pruning/v30'
  _globals['_SETSCHEDULEREQUEST']._serialized_start=167
  _globals['_SETSCHEDULEREQUEST']._serialized_end=275
  _globals['_SETSCHEDULERESPONSE']._serialized_start=277
  _globals['_SETSCHEDULERESPONSE']._serialized_end=298
  _globals['_GETSCHEDULEREQUEST']._serialized_start=300
  _globals['_GETSCHEDULEREQUEST']._serialized_end=320
  _globals['_GETSCHEDULERESPONSE']._serialized_start=322
  _globals['_GETSCHEDULERESPONSE']._serialized_end=431
  _globals['_SETPARTICIPANTSCHEDULEREQUEST']._serialized_start=434
  _globals['_SETPARTICIPANTSCHEDULEREQUEST']._serialized_end=564
  _globals['_SETPARTICIPANTSCHEDULERESPONSE']._serialized_start=566
  _globals['_SETPARTICIPANTSCHEDULERESPONSE']._serialized_end=598
  _globals['_GETPARTICIPANTSCHEDULEREQUEST']._serialized_start=600
  _globals['_GETPARTICIPANTSCHEDULEREQUEST']._serialized_end=631
  _globals['_GETPARTICIPANTSCHEDULERESPONSE']._serialized_start=634
  _globals['_GETPARTICIPANTSCHEDULERESPONSE']._serialized_end=765
  _globals['_PRUNINGSCHEDULE']._serialized_start=768
  _globals['_PRUNINGSCHEDULE']._serialized_end=924
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_start=927
  _globals['_PARTICIPANTPRUNINGSCHEDULE']._serialized_end=1095
  _globals['_CLEARSCHEDULEREQUEST']._serialized_start=1097
  _globals['_CLEARSCHEDULEREQUEST']._serialized_end=1119
  _globals['_CLEARSCHEDULERESPONSE']._serialized_start=1121
  _globals['_CLEARSCHEDULERESPONSE']._serialized_end=1144
  _globals['_SETCRONREQUEST']._serialized_start=1146
  _globals['_SETCRONREQUEST']._serialized_end=1182
  _globals['_SETCRONRESPONSE']._serialized_start=1184
  _globals['_SETCRONRESPONSE']._serialized_end=1201
  _globals['_SETMAXDURATIONREQUEST']._serialized_start=1203
  _globals['_SETMAXDURATIONREQUEST']._serialized_end=1288
  _globals['_SETMAXDURATIONRESPONSE']._serialized_start=1290
  _globals['_SETMAXDURATIONRESPONSE']._serialized_end=1314
  _globals['_SETRETENTIONREQUEST']._serialized_start=1316
  _globals['_SETRETENTIONREQUEST']._serialized_end=1394
  _globals['_SETRETENTIONRESPONSE']._serialized_start=1396
  _globals['_SETRETENTIONRESPONSE']._serialized_end=1418
  _globals['_FINDPRUNINGTIMESTAMPREQUEST']._serialized_start=1420
  _globals['_FINDPRUNINGTIMESTAMPREQUEST']._serialized_end=1471
  _globals['_FINDPRUNINGTIMESTAMPRESPONSE']._serialized_start=1473
  _globals['_FINDPRUNINGTIMESTAMPRESPONSE']._serialized_end=1561
  _globals['_SETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1564
  _globals['_SETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=1696
  _globals['_SETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=1698
  _globals['_SETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=1732
  _globals['_RESETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1735
  _globals['_RESETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=1869
  _globals['_RESETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=1871
  _globals['_RESETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=1907
  _globals['_SYNCHRONIZERS']._serialized_start=1909
  _globals['_SYNCHRONIZERS']._serialized_end=1967
  _globals['_GETNOWAITCOMMITMENTSFROMREQUEST']._serialized_start=1969
  _globals['_GETNOWAITCOMMITMENTSFROMREQUEST']._serialized_end=2088
  _globals['_GETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_start=2091
  _globals['_GETNOWAITCOMMITMENTSFROMRESPONSE']._serialized_end=2364
  _globals['_WAITCOMMITMENTSSETUP']._serialized_start=2367
  _globals['_WAITCOMMITMENTSSETUP']._serialized_end=2541
# @@protoc_insertion_point(module_scope)
