# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from ....v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nIcom/digitalasset/canton/sequencer/api/v30/sequencer_channel_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\"\xf3\x03\n ConnectToSequencerChannelRequest\x12\x61\n\x08metadata\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.sequencer.api.v30.SequencerChannelMetadataH\x00R\x08metadata\x12h\n\x0bsession_key\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyH\x00R\nsessionKey\x12\x8a\x01\n\x1bsession_key_acknowledgement\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyAckH\x00R\x19sessionKeyAcknowledgement\x12\x1a\n\x07payload\x18\x04 \x01(\x0cH\x00R\x07payload\x12N\n\rtrace_context\x18\x05 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContextB\t\n\x07request\"\x86\x04\n!ConnectToSequencerChannelResponse\x12r\n\tconnected\x18\x01 \x01(\x0b\x32R.com.digitalasset.canton.sequencer.api.v30.SequencerChannelConnectedToAllEndpointsH\x00R\tconnected\x12h\n\x0bsession_key\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyH\x00R\nsessionKey\x12\x8a\x01\n\x1bsession_key_acknowledgement\x18\x03 \x01(\x0b\x32H.com.digitalasset.canton.sequencer.api.v30.SequencerChannelSessionKeyAckH\x00R\x19sessionKeyAcknowledgement\x12\x1a\n\x07payload\x18\x04 \x01(\x0cH\x00R\x07payload\x12N\n\rtrace_context\x18\x05 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContextB\n\n\x08response\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"\x91\x01\n\x18SequencerChannelMetadata\x12\x1d\n\nchannel_id\x18\x01 \x01(\tR\tchannelId\x12+\n\x11initiating_member\x18\x02 \x01(\tR\x10initiatingMember\x12)\n\x10receiving_member\x18\x03 \x01(\tR\x0freceivingMember\")\n\'SequencerChannelConnectedToAllEndpoints\"\x89\x01\n\x1aSequencerChannelSessionKey\x12k\n\x15\x65ncrypted_session_key\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.crypto.v30.AsymmetricEncryptedR\x13\x65ncryptedSessionKey\"\x1f\n\x1dSequencerChannelSessionKeyAck2\xcf\x02\n\x17SequencerChannelService\x12\xba\x01\n\x19\x43onnectToSequencerChannel\x12K.com.digitalasset.canton.sequencer.api.v30.ConnectToSequencerChannelRequest\x1aL.com.digitalasset.canton.sequencer.api.v30.ConnectToSequencerChannelResponse(\x01\x30\x01\x12w\n\x04Ping\x12\x36.com.digitalasset.canton.sequencer.api.v30.PingRequest\x1a\x37.com.digitalasset.canton.sequencer.api.v30.PingResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_channel_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_CONNECTTOSEQUENCERCHANNELREQUEST']._serialized_start=219
  _globals['_CONNECTTOSEQUENCERCHANNELREQUEST']._serialized_end=718
  _globals['_CONNECTTOSEQUENCERCHANNELRESPONSE']._serialized_start=721
  _globals['_CONNECTTOSEQUENCERCHANNELRESPONSE']._serialized_end=1239
  _globals['_PINGREQUEST']._serialized_start=1241
  _globals['_PINGREQUEST']._serialized_end=1254
  _globals['_PINGRESPONSE']._serialized_start=1256
  _globals['_PINGRESPONSE']._serialized_end=1270
  _globals['_SEQUENCERCHANNELMETADATA']._serialized_start=1273
  _globals['_SEQUENCERCHANNELMETADATA']._serialized_end=1418
  _globals['_SEQUENCERCHANNELCONNECTEDTOALLENDPOINTS']._serialized_start=1420
  _globals['_SEQUENCERCHANNELCONNECTEDTOALLENDPOINTS']._serialized_end=1461
  _globals['_SEQUENCERCHANNELSESSIONKEY']._serialized_start=1464
  _globals['_SEQUENCERCHANNELSESSIONKEY']._serialized_end=1601
  _globals['_SEQUENCERCHANNELSESSIONKEYACK']._serialized_start=1603
  _globals['_SEQUENCERCHANNELSESSIONKEYACK']._serialized_end=1634
  _globals['_SEQUENCERCHANNELSERVICE']._serialized_start=1637
  _globals['_SEQUENCERCHANNELSERVICE']._serialized_end=1972
# @@protoc_insertion_point(module_scope)
