# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/topology/admin/v30/topology_manager_write_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a\x1egoogle/protobuf/duration.proto\"\xaa\x03\n\x1bGenerateTransactionsRequest\x12n\n\tproposals\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest.ProposalR\tproposals\x1a\x9a\x02\n\x08Proposal\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\x12I\n\x05store\x18\x04 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\"\xaf\x02\n\x1cGenerateTransactionsResponse\x12\x94\x01\n\x16generated_transactions\x18\x01 \x03(\x0b\x32].com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse.GeneratedTransactionR\x15generatedTransactions\x1ax\n\x14GeneratedTransaction\x12\x35\n\x16serialized_transaction\x18\x01 \x01(\x0cR\x15serializedTransaction\x12)\n\x10transaction_hash\x18\x02 \x01(\x0cR\x0ftransactionHash\"\xc2\x05\n\x10\x41uthorizeRequest\x12\x63\n\x08proposal\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest.ProposalH\x00R\x08proposal\x12+\n\x10transaction_hash\x18\x02 \x01(\tH\x00R\x0ftransactionHash\x12\x30\n\x14must_fully_authorize\x18\x03 \x01(\x08R\x12mustFullyAuthorize\x12Z\n\rforce_changes\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12\x1b\n\tsigned_by\x18\x05 \x03(\tR\x08signedBy\x12I\n\x05store\x18\x06 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\x1a\xc9\x01\n\x08Proposal\x12T\n\x06\x63hange\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\x06\x63hange\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mappingB\x06\n\x04type\"v\n\x11\x41uthorizeResponse\x12\x61\n\x0btransaction\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0btransaction\"\xf8\x02\n\x16\x41\x64\x64TransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12Z\n\rforce_changes\x18\x02 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\x0c\x66orceChanges\x12I\n\x05store\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\"\x19\n\x17\x41\x64\x64TransactionsResponse\"\xeb\x01\n\x1dImportTopologySnapshotRequest\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12I\n\x05store\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\" \n\x1eImportTopologySnapshotResponse\"\xed\x01\n\x1fImportTopologySnapshotV2Request\x12+\n\x11topology_snapshot\x18\x01 \x01(\x0cR\x10topologySnapshot\x12I\n\x05store\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12R\n\x18wait_to_become_effective\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x15waitToBecomeEffective\"\"\n ImportTopologySnapshotV2Response\"\xbe\x02\n\x17SignTransactionsRequest\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\x12\x1b\n\tsigned_by\x18\x02 \x03(\tR\x08signedBy\x12I\n\x05store\x18\x03 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12V\n\x0b\x66orce_flags\x18\x04 \x03(\x0e\x32\x35.com.digitalasset.canton.topology.admin.v30.ForceFlagR\nforceFlags\"\x7f\n\x18SignTransactionsResponse\x12\x63\n\x0ctransactions\x18\x01 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x0ctransactions\"d\n#CreateTemporaryTopologyStoreRequest\x12\x12\n\x04name\x18\x01 \x01(\tR\x04name\x12)\n\x10protocol_version\x18\x02 \x01(\rR\x0fprotocolVersion\"\x80\x01\n$CreateTemporaryTopologyStoreResponse\x12X\n\x08store_id\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryR\x07storeId\"}\n!DropTemporaryTopologyStoreRequest\x12X\n\x08store_id\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.topology.admin.v30.StoreId.TemporaryR\x07storeId\"$\n\"DropTemporaryTopologyStoreResponse*\x85\x06\n\tForceFlag\x12\x1a\n\x16\x46ORCE_FLAG_UNSPECIFIED\x10\x00\x12\x1b\n\x17\x46ORCE_FLAG_ALIEN_MEMBER\x10\x01\x12\x39\n5FORCE_FLAG_LEDGER_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\x02\x12$\n FORCE_FLAG_ALLOW_UNKNOWN_PACKAGE\x10\x04\x12*\n&FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES\x10\x05\x12\x32\n.FORCE_FLAG_DISABLE_PARTY_WITH_ACTIVE_CONTRACTS\x10\x06\x12-\n)FORCE_FLAG_ALLOW_UNVALIDATED_SIGNING_KEYS\x10\x07\x12>\n:FORCE_FLAG_PREPARATION_TIME_RECORD_TIME_TOLERANCE_INCREASE\x10\t\x12L\nHFORCE_FLAG_ALLOW_INSUFFICIENT_PARTICIPANT_PERMISSION_FOR_SIGNATORY_PARTY\x10\n\x12L\nHFORCE_FLAG_ALLOW_INSUFFICIENT_SIGNATORY_ASSIGNING_PARTICIPANTS_FOR_PARTY\x10\x0b\x12.\n*FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES\x10\x0c\x12(\n$FORCE_FLAG_ALLOW_OUT_OF_BOUNDS_VALUE\x10\r\x12\x37\n3FORCE_FLAG_ALLOW_CONFIRMING_THRESHOLD_CANNOT_BE_MET\x10\x0e\"\x04\x08\x03\x10\x03\"\x04\x08\x08\x10\x08*\x1e\x46ORCE_FLAG_ALLOW_UNVET_PACKAGE*4FORCE_FLAG_ALLOW_UNVET_PACKAGE_WITH_ACTIVE_CONTRACTS2\x81\x0b\n\x1bTopologyManagerWriteService\x12\x88\x01\n\tAuthorize\x12<.com.digitalasset.canton.topology.admin.v30.AuthorizeRequest\x1a=.com.digitalasset.canton.topology.admin.v30.AuthorizeResponse\x12\x9a\x01\n\x0f\x41\x64\x64Transactions\x12\x42.com.digitalasset.canton.topology.admin.v30.AddTransactionsRequest\x1a\x43.com.digitalasset.canton.topology.admin.v30.AddTransactionsResponse\x12\xb1\x01\n\x16ImportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotResponse(\x01\x12\xb7\x01\n\x18ImportTopologySnapshotV2\x12K.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotV2Request\x1aL.com.digitalasset.canton.topology.admin.v30.ImportTopologySnapshotV2Response(\x01\x12\x9d\x01\n\x10SignTransactions\x12\x43.com.digitalasset.canton.topology.admin.v30.SignTransactionsRequest\x1a\x44.com.digitalasset.canton.topology.admin.v30.SignTransactionsResponse\x12\xa9\x01\n\x14GenerateTransactions\x12G.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsRequest\x1aH.com.digitalasset.canton.topology.admin.v30.GenerateTransactionsResponse\x12\xc1\x01\n\x1c\x43reateTemporaryTopologyStore\x12O.com.digitalasset.canton.topology.admin.v30.CreateTemporaryTopologyStoreRequest\x1aP.com.digitalasset.canton.topology.admin.v30.CreateTemporaryTopologyStoreResponse\x12\xbb\x01\n\x1a\x44ropTemporaryTopologyStore\x12M.com.digitalasset.canton.topology.admin.v30.DropTemporaryTopologyStoreRequest\x1aN.com.digitalasset.canton.topology.admin.v30.DropTemporaryTopologyStoreResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_write_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_FORCEFLAG']._serialized_start=3636
  _globals['_FORCEFLAG']._serialized_end=4409
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_start=270
  _globals['_GENERATETRANSACTIONSREQUEST']._serialized_end=696
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_start=414
  _globals['_GENERATETRANSACTIONSREQUEST_PROPOSAL']._serialized_end=696
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_start=699
  _globals['_GENERATETRANSACTIONSRESPONSE']._serialized_end=1002
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_start=882
  _globals['_GENERATETRANSACTIONSRESPONSE_GENERATEDTRANSACTION']._serialized_end=1002
  _globals['_AUTHORIZEREQUEST']._serialized_start=1005
  _globals['_AUTHORIZEREQUEST']._serialized_end=1711
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_start=1502
  _globals['_AUTHORIZEREQUEST_PROPOSAL']._serialized_end=1703
  _globals['_AUTHORIZERESPONSE']._serialized_start=1713
  _globals['_AUTHORIZERESPONSE']._serialized_end=1831
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_start=1834
  _globals['_ADDTRANSACTIONSREQUEST']._serialized_end=2210
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_start=2212
  _globals['_ADDTRANSACTIONSRESPONSE']._serialized_end=2237
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=2240
  _globals['_IMPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=2475
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=2477
  _globals['_IMPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=2509
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_start=2512
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_end=2749
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_start=2751
  _globals['_IMPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_end=2785
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_start=2788
  _globals['_SIGNTRANSACTIONSREQUEST']._serialized_end=3106
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_start=3108
  _globals['_SIGNTRANSACTIONSRESPONSE']._serialized_end=3235
  _globals['_CREATETEMPORARYTOPOLOGYSTOREREQUEST']._serialized_start=3237
  _globals['_CREATETEMPORARYTOPOLOGYSTOREREQUEST']._serialized_end=3337
  _globals['_CREATETEMPORARYTOPOLOGYSTORERESPONSE']._serialized_start=3340
  _globals['_CREATETEMPORARYTOPOLOGYSTORERESPONSE']._serialized_end=3468
  _globals['_DROPTEMPORARYTOPOLOGYSTOREREQUEST']._serialized_start=3470
  _globals['_DROPTEMPORARYTOPOLOGYSTOREREQUEST']._serialized_end=3595
  _globals['_DROPTEMPORARYTOPOLOGYSTORERESPONSE']._serialized_start=3597
  _globals['_DROPTEMPORARYTOPOLOGYSTORERESPONSE']._serialized_end=3633
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_start=4412
  _globals['_TOPOLOGYMANAGERWRITESERVICE']._serialized_end=5821
# @@protoc_insertion_point(module_scope)
