# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/health/admin/v1/status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/health/admin/v1/status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ..v0 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v0_dot_status__service__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n<com/digitalasset/canton/health/admin/v1/status_service.proto\x12\'com.digitalasset.canton.health.admin.v1\x1a<com/digitalasset/canton/health/admin/v0/status_service.proto\x1a\x1egoogle/protobuf/duration.proto\".\n\x07\x46\x61ilure\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\"\xd7\x03\n\x06Status\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x12\x31\n\x06uptime\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x06uptime\x12P\n\x05ports\x18\x03 \x03(\x0b\x32:.com.digitalasset.canton.health.admin.v1.Status.PortsEntryR\x05ports\x12\x16\n\x06\x61\x63tive\x18\x04 \x01(\x08R\x06\x61\x63tive\x12\x65\n\x0ftopology_queues\x18\x05 \x01(\x0b\x32<.com.digitalasset.canton.health.admin.v0.TopologyQueueStatusR\x0etopologyQueues\x12\x63\n\ncomponents\x18\x06 \x03(\x0b\x32\x43.com.digitalasset.canton.health.admin.v0.NodeStatus.ComponentStatusR\ncomponents\x12\x18\n\x07version\x18\x07 \x01(\tR\x07version\x1a\x38\n\nPortsEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\x05R\x05value:\x02\x38\x01\x42XZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.health.admin.v1.status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/health/admin/v1'
  _globals['_STATUS_PORTSENTRY']._loaded_options = None
  _globals['_STATUS_PORTSENTRY']._serialized_options = b'8\001'
  _globals['_FAILURE']._serialized_start=199
  _globals['_FAILURE']._serialized_end=245
  _globals['_STATUS']._serialized_start=248
  _globals['_STATUS']._serialized_end=719
  _globals['_STATUS_PORTSENTRY']._serialized_start=663
  _globals['_STATUS_PORTSENTRY']._serialized_end=719
# @@protoc_insertion_point(module_scope)
