# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive/interactive_submission_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/interactive/interactive_submission_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from .. import crypto_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_crypto__pb2
from . import interactive_submission_common_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive_dot_interactive__submission__common__data__pb2
from .transaction.v1 import interactive_submission_data_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_interactive_dot_transaction_dot_v1_dot_interactive__submission__data__pb2
from .. import package_reference_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__reference__pb2
from .. import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from .. import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2
from .. import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/daml/ledger/api/v2/interactive/interactive_submission_service.proto\x12\"com.daml.ledger.api.v2.interactive\x1a%com/daml/ledger/api/v2/commands.proto\x1a#com/daml/ledger/api/v2/crypto.proto\x1aKcom/daml/ledger/api/v2/interactive/interactive_submission_common_data.proto\x1aScom/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto\x1a.com/daml/ledger/api/v2/package_reference.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\x1a\"com/daml/ledger/api/v2/value.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x01\n\x13\x43ostEstimationHints\x12\x1a\n\x08\x64isabled\x18\x01 \x01(\x08R\x08\x64isabled\x12]\n\x13\x65xpected_signatures\x18\x02 \x03(\x0e\x32,.com.daml.ledger.api.v2.SigningAlgorithmSpecR\x12\x65xpectedSignatures\"\xe4\x02\n\x0e\x43ostEstimation\x12M\n\x14\x65stimation_timestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13\x65stimationTimestamp\x12^\n,confirmation_request_traffic_cost_estimation\x18\x02 \x01(\x04R(confirmationRequestTrafficCostEstimation\x12`\n-confirmation_response_traffic_cost_estimation\x18\x03 \x01(\x04R)confirmationResponseTrafficCostEstimation\x12\x41\n\x1dtotal_traffic_cost_estimation\x18\x04 \x01(\x04R\x1atotalTrafficCostEstimation\"\xdb\x06\n\x18PrepareSubmissionRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x12;\n\x08\x63ommands\x18\x03 \x03(\x0b\x32\x1f.com.daml.ledger.api.v2.CommandR\x08\x63ommands\x12Y\n\x0fmin_ledger_time\x18\x04 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTime\x12G\n\x0fmax_record_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\rmaxRecordTime\x88\x01\x01\x12\x15\n\x06\x61\x63t_as\x18\x05 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07read_as\x18\x06 \x03(\tR\x06readAs\x12Z\n\x13\x64isclosed_contracts\x18\x07 \x03(\x0b\x32).com.daml.ledger.api.v2.DisclosedContractR\x12\x64isclosedContracts\x12\'\n\x0fsynchronizer_id\x18\x08 \x01(\tR\x0esynchronizerId\x12\x45\n\x1fpackage_id_selection_preference\x18\t \x03(\tR\x1cpackageIdSelectionPreference\x12\'\n\x0fverbose_hashing\x18\n \x01(\x08R\x0everboseHashing\x12\x61\n\x16prefetch_contract_keys\x18\x0f \x03(\x0b\x32+.com.daml.ledger.api.v2.PrefetchContractKeyR\x14prefetchContractKeys\x12p\n\x15\x65stimate_traffic_cost\x18\x10 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.CostEstimationHintsH\x01R\x13\x65stimateTrafficCost\x88\x01\x01\x42\x12\n\x10_max_record_timeB\x18\n\x16_estimate_traffic_cost\"\xeb\x03\n\x19PrepareSubmissionResponse\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12:\n\x19prepared_transaction_hash\x18\x02 \x01(\x0cR\x17preparedTransactionHash\x12n\n\x16hashing_scheme_version\x18\x03 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12,\n\x0fhashing_details\x18\x04 \x01(\tH\x00R\x0ehashingDetails\x88\x01\x01\x12`\n\x0f\x63ost_estimation\x18\x05 \x01(\x0b\x32\x32.com.daml.ledger.api.v2.interactive.CostEstimationH\x01R\x0e\x63ostEstimation\x88\x01\x01\x42\x12\n\x10_hashing_detailsB\x12\n\x10_cost_estimation\"p\n\x15SinglePartySignatures\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x41\n\nsignatures\x18\x02 \x03(\x0b\x32!.com.daml.ledger.api.v2.SignatureR\nsignatures\"l\n\x0fPartySignatures\x12Y\n\nsignatures\x18\x01 \x03(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.SinglePartySignaturesR\nsignatures\"\x90\x05\n\x18\x45xecuteSubmissionRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTimeB\x16\n\x14\x64\x65\x64uplication_period\"\x1b\n\x19\x45xecuteSubmissionResponse\"\x97\x05\n\x1f\x45xecuteSubmissionAndWaitRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTimeB\x16\n\x14\x64\x65\x64uplication_period\"l\n ExecuteSubmissionAndWaitResponse\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12+\n\x11\x63ompletion_offset\x18\x02 \x01(\x03R\x10\x63ompletionOffset\"\xff\x05\n-ExecuteSubmissionAndWaitForTransactionRequest\x12j\n\x14prepared_transaction\x18\x01 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.PreparedTransactionR\x13preparedTransaction\x12^\n\x10party_signatures\x18\x02 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.PartySignaturesR\x0fpartySignatures\x12R\n\x16\x64\x65\x64uplication_duration\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x15\x64\x65\x64uplicationDuration\x12\x33\n\x14\x64\x65\x64uplication_offset\x18\x04 \x01(\x03H\x00R\x13\x64\x65\x64uplicationOffset\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x06 \x01(\tR\x06userId\x12n\n\x16hashing_scheme_version\x18\x07 \x01(\x0e\x32\x38.com.daml.ledger.api.v2.interactive.HashingSchemeVersionR\x14hashingSchemeVersion\x12Y\n\x0fmin_ledger_time\x18\x08 \x01(\x0b\x32\x31.com.daml.ledger.api.v2.interactive.MinLedgerTimeR\rminLedgerTime\x12X\n\x12transaction_format\x18\t \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormatB\x16\n\x14\x64\x65\x64uplication_period\"w\n.ExecuteSubmissionAndWaitForTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction\"\xb0\x01\n\rMinLedgerTime\x12K\n\x13min_ledger_time_abs\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x10minLedgerTimeAbs\x12J\n\x13min_ledger_time_rel\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationH\x00R\x10minLedgerTimeRelB\x06\n\x04time\"\xb6\x01\n\x13PreparedTransaction\x12U\n\x0btransaction\x18\x01 \x01(\x0b\x32\x33.com.daml.ledger.api.v2.interactive.DamlTransactionR\x0btransaction\x12H\n\x08metadata\x18\x02 \x01(\x0b\x32,.com.daml.ledger.api.v2.interactive.MetadataR\x08metadata\"\x86\t\n\x08Metadata\x12\x61\n\x0esubmitter_info\x18\x02 \x01(\x0b\x32:.com.daml.ledger.api.v2.interactive.Metadata.SubmitterInfoR\rsubmitterInfo\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12%\n\x0emediator_group\x18\x04 \x01(\rR\rmediatorGroup\x12)\n\x10transaction_uuid\x18\x05 \x01(\tR\x0ftransactionUuid\x12)\n\x10preparation_time\x18\x06 \x01(\x04R\x0fpreparationTime\x12\x63\n\x0finput_contracts\x18\x07 \x03(\x0b\x32:.com.daml.ledger.api.v2.interactive.Metadata.InputContractR\x0einputContracts\x12>\n\x19min_ledger_effective_time\x18\t \x01(\x04H\x00R\x16minLedgerEffectiveTime\x88\x01\x01\x12>\n\x19max_ledger_effective_time\x18\n \x01(\x04H\x01R\x16maxLedgerEffectiveTime\x88\x01\x01\x12p\n\x12global_key_mapping\x18\x08 \x03(\x0b\x32\x42.com.daml.ledger.api.v2.interactive.Metadata.GlobalKeyMappingEntryR\x10globalKeyMapping\x12+\n\x0fmax_record_time\x18\x0b \x01(\x04H\x02R\rmaxRecordTime\x88\x01\x01\x1a\x45\n\rSubmitterInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12\x1d\n\ncommand_id\x18\x02 \x01(\tR\tcommandId\x1a\x9c\x01\n\x15GlobalKeyMappingEntry\x12?\n\x03key\x18\x01 \x01(\x0b\x32-.com.daml.ledger.api.v2.interactive.GlobalKeyR\x03key\x12\x38\n\x05value\x18\x02 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueH\x00R\x05value\x88\x01\x01\x42\x08\n\x06_value\x1a\xb0\x01\n\rInputContract\x12K\n\x02v1\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.transaction.v1.CreateH\x00R\x02v1\x12\x1e\n\ncreated_at\x18\xe8\x07 \x01(\x04R\tcreatedAt\x12\x1e\n\nevent_blob\x18\xea\x07 \x01(\x0cR\teventBlobB\n\n\x08\x63ontractJ\x06\x08\xe9\x07\x10\xea\x07\x42\x1c\n\x1a_min_ledger_effective_timeB\x1c\n\x1a_max_ledger_effective_timeB\x12\n\x10_max_record_timeJ\x04\x08\x01\x10\x02\"\xa6\x03\n\x0f\x44\x61mlTransaction\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version\x12\x14\n\x05roots\x18\x02 \x03(\tR\x05roots\x12N\n\x05nodes\x18\x03 \x03(\x0b\x32\x38.com.daml.ledger.api.v2.interactive.DamlTransaction.NodeR\x05nodes\x12[\n\nnode_seeds\x18\x04 \x03(\x0b\x32<.com.daml.ledger.api.v2.interactive.DamlTransaction.NodeSeedR\tnodeSeeds\x1a\x37\n\x08NodeSeed\x12\x17\n\x07node_id\x18\x01 \x01(\x05R\x06nodeId\x12\x12\n\x04seed\x18\x02 \x01(\x0cR\x04seed\x1a}\n\x04Node\x12\x17\n\x07node_id\x18\x01 \x01(\tR\x06nodeId\x12J\n\x02v1\x18\xe8\x07 \x01(\x0b\x32\x37.com.daml.ledger.api.v2.interactive.transaction.v1.NodeH\x00R\x02v1B\x10\n\x0eversioned_node\"\xcf\x01\n!GetPreferredPackageVersionRequest\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\x44\n\x10vetting_valid_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0evettingValidAt\"\x8a\x01\n\"GetPreferredPackageVersionResponse\x12\x64\n\x12package_preference\x18\x01 \x01(\x0b\x32\x35.com.daml.ledger.api.v2.interactive.PackagePreferenceR\x11packagePreference\"\x93\x01\n\x11PackagePreference\x12U\n\x11package_reference\x18\x01 \x01(\x0b\x32(.com.daml.ledger.api.v2.PackageReferenceR\x10packageReference\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\"X\n\x19PackageVettingRequirement\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\"\x8d\x02\n\x1bGetPreferredPackagesRequest\x12\x7f\n\x1cpackage_vetting_requirements\x18\x01 \x03(\x0b\x32=.com.daml.ledger.api.v2.interactive.PackageVettingRequirementR\x1apackageVettingRequirements\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x44\n\x10vetting_valid_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0evettingValidAt\"\xa0\x01\n\x1cGetPreferredPackagesResponse\x12W\n\x12package_references\x18\x01 \x03(\x0b\x32(.com.daml.ledger.api.v2.PackageReferenceR\x11packageReferences\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId*c\n\x14HashingSchemeVersion\x12&\n\"HASHING_SCHEME_VERSION_UNSPECIFIED\x10\x00\x12\x1d\n\x19HASHING_SCHEME_VERSION_V2\x10\x02\"\x04\x08\x01\x10\x01\x32\x88\x08\n\x1cInteractiveSubmissionService\x12\x90\x01\n\x11PrepareSubmission\x12<.com.daml.ledger.api.v2.interactive.PrepareSubmissionRequest\x1a=.com.daml.ledger.api.v2.interactive.PrepareSubmissionResponse\x12\x90\x01\n\x11\x45xecuteSubmission\x12<.com.daml.ledger.api.v2.interactive.ExecuteSubmissionRequest\x1a=.com.daml.ledger.api.v2.interactive.ExecuteSubmissionResponse\x12\xa5\x01\n\x18\x45xecuteSubmissionAndWait\x12\x43.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitRequest\x1a\x44.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitResponse\x12\xcf\x01\n&ExecuteSubmissionAndWaitForTransaction\x12Q.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitForTransactionRequest\x1aR.com.daml.ledger.api.v2.interactive.ExecuteSubmissionAndWaitForTransactionResponse\x12\xab\x01\n\x1aGetPreferredPackageVersion\x12\x45.com.daml.ledger.api.v2.interactive.GetPreferredPackageVersionRequest\x1a\x46.com.daml.ledger.api.v2.interactive.GetPreferredPackageVersionResponse\x12\x99\x01\n\x14GetPreferredPackages\x12?.com.daml.ledger.api.v2.interactive.GetPreferredPackagesRequest\x1a@.com.daml.ledger.api.v2.interactive.GetPreferredPackagesResponseB\xc4\x01\n\"com.daml.ledger.api.v2.interactiveB&InteractiveSubmissionServiceOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\xaa\x02\"Com.Daml.Ledger.Api.V2.Interactiveb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive.interactive_submission_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\"com.daml.ledger.api.v2.interactiveB&InteractiveSubmissionServiceOuterClassZQgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive\252\002\"Com.Daml.Ledger.Api.V2.Interactive'
  _globals['_HASHINGSCHEMEVERSION']._serialized_start=8006
  _globals['_HASHINGSCHEMEVERSION']._serialized_end=8105
  _globals['_COSTESTIMATIONHINTS']._serialized_start=590
  _globals['_COSTESTIMATIONHINTS']._serialized_end=734
  _globals['_COSTESTIMATION']._serialized_start=737
  _globals['_COSTESTIMATION']._serialized_end=1093
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_start=1096
  _globals['_PREPARESUBMISSIONREQUEST']._serialized_end=1955
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_start=1958
  _globals['_PREPARESUBMISSIONRESPONSE']._serialized_end=2449
  _globals['_SINGLEPARTYSIGNATURES']._serialized_start=2451
  _globals['_SINGLEPARTYSIGNATURES']._serialized_end=2563
  _globals['_PARTYSIGNATURES']._serialized_start=2565
  _globals['_PARTYSIGNATURES']._serialized_end=2673
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_start=2676
  _globals['_EXECUTESUBMISSIONREQUEST']._serialized_end=3332
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_start=3334
  _globals['_EXECUTESUBMISSIONRESPONSE']._serialized_end=3361
  _globals['_EXECUTESUBMISSIONANDWAITREQUEST']._serialized_start=3364
  _globals['_EXECUTESUBMISSIONANDWAITREQUEST']._serialized_end=4027
  _globals['_EXECUTESUBMISSIONANDWAITRESPONSE']._serialized_start=4029
  _globals['_EXECUTESUBMISSIONANDWAITRESPONSE']._serialized_end=4137
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONREQUEST']._serialized_start=4140
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONREQUEST']._serialized_end=4907
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONRESPONSE']._serialized_start=4909
  _globals['_EXECUTESUBMISSIONANDWAITFORTRANSACTIONRESPONSE']._serialized_end=5028
  _globals['_MINLEDGERTIME']._serialized_start=5031
  _globals['_MINLEDGERTIME']._serialized_end=5207
  _globals['_PREPAREDTRANSACTION']._serialized_start=5210
  _globals['_PREPAREDTRANSACTION']._serialized_end=5392
  _globals['_METADATA']._serialized_start=5395
  _globals['_METADATA']._serialized_end=6553
  _globals['_METADATA_SUBMITTERINFO']._serialized_start=6060
  _globals['_METADATA_SUBMITTERINFO']._serialized_end=6129
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_start=6132
  _globals['_METADATA_GLOBALKEYMAPPINGENTRY']._serialized_end=6288
  _globals['_METADATA_INPUTCONTRACT']._serialized_start=6291
  _globals['_METADATA_INPUTCONTRACT']._serialized_end=6467
  _globals['_DAMLTRANSACTION']._serialized_start=6556
  _globals['_DAMLTRANSACTION']._serialized_end=6978
  _globals['_DAMLTRANSACTION_NODESEED']._serialized_start=6796
  _globals['_DAMLTRANSACTION_NODESEED']._serialized_end=6851
  _globals['_DAMLTRANSACTION_NODE']._serialized_start=6853
  _globals['_DAMLTRANSACTION_NODE']._serialized_end=6978
  _globals['_GETPREFERREDPACKAGEVERSIONREQUEST']._serialized_start=6981
  _globals['_GETPREFERREDPACKAGEVERSIONREQUEST']._serialized_end=7188
  _globals['_GETPREFERREDPACKAGEVERSIONRESPONSE']._serialized_start=7191
  _globals['_GETPREFERREDPACKAGEVERSIONRESPONSE']._serialized_end=7329
  _globals['_PACKAGEPREFERENCE']._serialized_start=7332
  _globals['_PACKAGEPREFERENCE']._serialized_end=7479
  _globals['_PACKAGEVETTINGREQUIREMENT']._serialized_start=7481
  _globals['_PACKAGEVETTINGREQUIREMENT']._serialized_end=7569
  _globals['_GETPREFERREDPACKAGESREQUEST']._serialized_start=7572
  _globals['_GETPREFERREDPACKAGESREQUEST']._serialized_end=7841
  _globals['_GETPREFERREDPACKAGESRESPONSE']._serialized_start=7844
  _globals['_GETPREFERREDPACKAGESRESPONSE']._serialized_end=8004
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_start=8108
  _globals['_INTERACTIVESUBMISSIONSERVICE']._serialized_end=9140
# @@protoc_insertion_point(module_scope)
