# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nFcom/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto\x12+com.digitalasset.canton.admin.sequencer.v30\x1a\x1egoogle/protobuf/duration.proto\"\x82\x03\n\x13SequencerConnection\x12[\n\x04grpc\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.sequencer.v30.SequencerConnection.GrpcH\x00R\x04grpc\x12\x14\n\x05\x61lias\x18\x03 \x01(\tR\x05\x61lias\x12&\n\x0csequencer_id\x18\x04 \x01(\tH\x01R\x0bsequencerId\x88\x01\x01\x1a\xb6\x01\n\x04Grpc\x12 \n\x0b\x63onnections\x18\x01 \x03(\tR\x0b\x63onnections\x12-\n\x12transport_security\x18\x02 \x01(\x08R\x11transportSecurity\x12?\n\x19\x63ustom_trust_certificates\x18\x03 \x01(\x0cH\x00R\x17\x63ustomTrustCertificates\x88\x01\x01\x42\x1c\n\x1a_custom_trust_certificatesB\x06\n\x04typeB\x0f\n\r_sequencer_id\"\xb3\x04\n\x14SequencerConnections\x12u\n\x15sequencer_connections\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionR\x14sequencerConnections\x12:\n\x19sequencer_trust_threshold\x18\x02 \x01(\rR\x17sequencerTrustThreshold\x12\x95\x01\n submission_request_amplification\x18\x03 \x01(\x0b\x32K.com.digitalasset.canton.admin.sequencer.v30.SubmissionRequestAmplificationR\x1esubmissionRequestAmplification\x12:\n\x19sequencer_liveness_margin\x18\x04 \x01(\rR\x17sequencerLivenessMargin\x12\x93\x01\n sequencer_connection_pool_delays\x18\x05 \x01(\x0b\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionPoolDelaysR\x1dsequencerConnectionPoolDelays\"o\n\x1eSubmissionRequestAmplification\x12\x16\n\x06\x66\x61\x63tor\x18\x01 \x01(\rR\x06\x66\x61\x63tor\x12\x35\n\x08patience\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x08patience\"\xd5\x02\n\x1dSequencerConnectionPoolDelays\x12\x45\n\x11min_restart_delay\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0fminRestartDelay\x12\x45\n\x11max_restart_delay\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0fmaxRestartDelay\x12W\n\x1asubscription_request_delay\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18subscriptionRequestDelay\x12M\n\x15warn_validation_delay\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x13warnValidationDelay*\x89\x02\n\x1dSequencerConnectionValidation\x12/\n+SEQUENCER_CONNECTION_VALIDATION_UNSPECIFIED\x10\x00\x12,\n(SEQUENCER_CONNECTION_VALIDATION_DISABLED\x10\x01\x12*\n&SEQUENCER_CONNECTION_VALIDATION_ACTIVE\x10\x02\x12\'\n#SEQUENCER_CONNECTION_VALIDATION_ALL\x10\x03\x12\x34\n0SEQUENCER_CONNECTION_VALIDATION_THRESHOLD_ACTIVE\x10\x04\x42\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.sequencer.v30.sequencer_connection_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30'
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_start=1564
  _globals['_SEQUENCERCONNECTIONVALIDATION']._serialized_end=1829
  _globals['_SEQUENCERCONNECTION']._serialized_start=152
  _globals['_SEQUENCERCONNECTION']._serialized_end=538
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_start=331
  _globals['_SEQUENCERCONNECTION_GRPC']._serialized_end=513
  _globals['_SEQUENCERCONNECTIONS']._serialized_start=541
  _globals['_SEQUENCERCONNECTIONS']._serialized_end=1104
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_start=1106
  _globals['_SUBMISSIONREQUESTAMPLIFICATION']._serialized_end=1217
  _globals['_SEQUENCERCONNECTIONPOOLDELAYS']._serialized_start=1220
  _globals['_SEQUENCERCONNECTIONPOOLDELAYS']._serialized_end=1561
# @@protoc_insertion_point(module_scope)
