# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/resource_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/resource_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOcom/digitalasset/canton/admin/participant/v30/resource_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\"x\n\x18SetResourceLimitsRequest\x12\\\n\nnew_limits\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.ResourceLimitsR\tnewLimits\"\x1b\n\x19SetResourceLimitsResponse\"\x1a\n\x18GetResourceLimitsRequest\"\x81\x01\n\x19GetResourceLimitsResponse\x12\x64\n\x0e\x63urrent_limits\x18\x01 \x01(\x0b\x32=.com.digitalasset.canton.admin.participant.v30.ResourceLimitsR\rcurrentLimits\"\x8f\x02\n\x0eResourceLimits\x12L\n max_inflight_validation_requests\x18\x01 \x01(\rH\x00R\x1dmaxInflightValidationRequests\x88\x01\x01\x12\x33\n\x13max_submission_rate\x18\x02 \x01(\rH\x01R\x11maxSubmissionRate\x88\x01\x01\x12=\n\x1bmax_submission_burst_factor\x18\x03 \x01(\x01R\x18maxSubmissionBurstFactorB#\n!_max_inflight_validation_requestsB\x16\n\x14_max_submission_rate2\xed\x02\n\x19ResourceManagementService\x12\xa6\x01\n\x11SetResourceLimits\x12G.com.digitalasset.canton.admin.participant.v30.SetResourceLimitsRequest\x1aH.com.digitalasset.canton.admin.participant.v30.SetResourceLimitsResponse\x12\xa6\x01\n\x11GetResourceLimits\x12G.com.digitalasset.canton.admin.participant.v30.GetResourceLimitsRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetResourceLimitsResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.resource_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SETRESOURCELIMITSREQUEST']._serialized_start=130
  _globals['_SETRESOURCELIMITSREQUEST']._serialized_end=250
  _globals['_SETRESOURCELIMITSRESPONSE']._serialized_start=252
  _globals['_SETRESOURCELIMITSRESPONSE']._serialized_end=279
  _globals['_GETRESOURCELIMITSREQUEST']._serialized_start=281
  _globals['_GETRESOURCELIMITSREQUEST']._serialized_end=307
  _globals['_GETRESOURCELIMITSRESPONSE']._serialized_start=310
  _globals['_GETRESOURCELIMITSRESPONSE']._serialized_end=439
  _globals['_RESOURCELIMITS']._serialized_start=442
  _globals['_RESOURCELIMITS']._serialized_end=713
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_start=716
  _globals['_RESOURCEMANAGEMENTSERVICE']._serialized_end=1081
# @@protoc_insertion_point(module_scope)
