# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/acs_import.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/acs_import.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n>com/digitalasset/canton/admin/participant/v30/acs_import.proto\x12-com.digitalasset.canton.admin.participant.v30\"\xbe\x05\n\x1fRepresentativePackageIdOverride\x12\x91\x01\n\x11\x63ontract_override\x18\x01 \x03(\x0b\x32\x64.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.ContractOverrideEntryR\x10\x63ontractOverride\x12\x95\x01\n\x13package_id_override\x18\x02 \x03(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.PackageIdOverrideEntryR\x11packageIdOverride\x12\x9b\x01\n\x15package_name_override\x18\x03 \x03(\x0b\x32g.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverride.PackageNameOverrideEntryR\x13packageNameOverride\x1a\x43\n\x15\x43ontractOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x44\n\x16PackageIdOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01\x1a\x46\n\x18PackageNameOverrideEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05value\x18\x02 \x01(\tR\x05value:\x02\x38\x01*\xa8\x01\n\x12\x43ontractImportMode\x12$\n CONTRACT_IMPORT_MODE_UNSPECIFIED\x10\x00\x12\x1f\n\x1b\x43ONTRACT_IMPORT_MODE_ACCEPT\x10\x01\x12#\n\x1f\x43ONTRACT_IMPORT_MODE_VALIDATION\x10\x02\x12&\n\"CONTRACT_IMPORT_MODE_RECOMPUTATION\x10\x03\x42^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.acs_import_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._loaded_options = None
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_options = b'8\001'
  _globals['_CONTRACTIMPORTMODE']._serialized_start=819
  _globals['_CONTRACTIMPORTMODE']._serialized_end=987
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE']._serialized_start=114
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE']._serialized_end=816
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_start=607
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_CONTRACTOVERRIDEENTRY']._serialized_end=674
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_start=676
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGEIDOVERRIDEENTRY']._serialized_end=744
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_start=746
  _globals['_REPRESENTATIVEPACKAGEIDOVERRIDE_PACKAGENAMEOVERRIDEENTRY']._serialized_end=816
# @@protoc_insertion_point(module_scope)
