# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/package_reference.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/package_reference.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.com/daml/ledger/api/v2/package_reference.proto\x12\x16\x63om.daml.ledger.api.v2\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"}\n\x10PackageReference\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x03 \x01(\tR\x0epackageVersion\"\x98\x02\n\rVettedPackage\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12L\n\x14valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12validFromInclusive\x12N\n\x15valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validUntilExclusive\x12!\n\x0cpackage_name\x18\x04 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x05 \x01(\tR\x0epackageVersion\"\xcc\x01\n\x0eVettedPackages\x12\x41\n\x08packages\x18\x01 \x03(\x0b\x32%.com.daml.ledger.api.v2.VettedPackageR\x08packages\x12%\n\x0eparticipant_id\x18\x02 \x01(\tR\rparticipantId\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\'\n\x0ftopology_serial\x18\x04 \x01(\rR\x0etopologySerial\"l\n\x13PriorTopologySerial\x12\x16\n\x05prior\x18\x01 \x01(\rH\x00R\x05prior\x12\x33\n\x08no_prior\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07noPriorB\x08\n\x06serialB\x94\x01\n\x16\x63om.daml.ledger.api.v2B\x1aPackageReferenceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.package_reference_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\032PackageReferenceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_PACKAGEREFERENCE']._serialized_start=136
  _globals['_PACKAGEREFERENCE']._serialized_end=261
  _globals['_VETTEDPACKAGE']._serialized_start=264
  _globals['_VETTEDPACKAGE']._serialized_end=544
  _globals['_VETTEDPACKAGES']._serialized_start=547
  _globals['_VETTEDPACKAGES']._serialized_end=751
  _globals['_PRIORTOPOLOGYSERIAL']._serialized_start=753
  _globals['_PRIORTOPOLOGYSERIAL']._serialized_end=861
# @@protoc_insertion_point(module_scope)
