# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ......crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\ndcom/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30/bft_ordering_service.proto\x12Icom.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xfe\x01\n\x12\x42\x66tOrderingMessage\x12#\n\rtrace_context\x18\x01 \x01(\tR\x0ctraceContext\x12u\n\x04\x62ody\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessageBodyR\x04\x62ody\x12\x17\n\x07sent_by\x18\x03 \x01(\tR\x06sentBy\x12\x33\n\x07sent_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x06sentAt\"\xf9\x05\n\x16\x42\x66tOrderingMessageBody\x12\x8d\x01\n\x14\x61vailability_message\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x13\x61vailabilityMessage\x12\x87\x01\n\x11\x63onsensus_message\x18\x02 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x10\x63onsensusMessage\x12\x90\x01\n\x16state_transfer_message\x18\x03 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x14stateTransferMessage\x12\x99\x01\n\x16retransmission_message\x18\x04 \x01(\x0b\x32`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.RetransmissionMessageH\x00R\x15retransmissionMessage\x12\x8a\x01\n\x11\x63onnection_opened\x18\x05 \x01(\x0b\x32[.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ConnectionOpenedH\x00R\x10\x63onnectionOpenedB\t\n\x07message\"\x8a\x01\n\rSignedMessage\x12\x18\n\x07message\x18\x01 \x01(\x0cR\x07message\x12\x12\n\x04\x66rom\x18\x02 \x01(\tR\x04\x66rom\x12K\n\tsignature\x18\x03 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\"\x12\n\x10\x43onnectionOpened\"\xd6\x04\n\x13\x41vailabilityMessage\x12,\n\x04ping\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x04ping\x12~\n\rstore_request\x18\x02 \x01(\x0b\x32W.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.StoreRequestH\x00R\x0cstoreRequest\x12\x81\x01\n\x0estore_response\x18\x03 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.StoreResponseH\x00R\rstoreResponse\x12~\n\rbatch_request\x18\x04 \x01(\x0b\x32W.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchRequestH\x00R\x0c\x62\x61tchRequest\x12\x81\x01\n\x0e\x62\x61tch_response\x18\x05 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchResponseH\x00R\rbatchResponseB\t\n\x07message\"\x91\x01\n\x0cStoreRequest\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12\x66\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchR\x05\x62\x61tch\"\xb4\x01\n\x05\x42\x61tch\x12\x87\x01\n\x11ordering_requests\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.OrderingRequestR\x10orderingRequests\x12!\n\x0c\x65poch_number\x18\x02 \x01(\x03R\x0b\x65pochNumber\"\xb4\x01\n\x0fOrderingRequest\x12#\n\rtrace_context\x18\x01 \x01(\tR\x0ctraceContext\x12\x10\n\x03tag\x18\x02 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x03 \x01(\x0cR\x07payload\x12P\n\x16ordering_start_instant\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x14orderingStartInstant\"w\n\rStoreResponse\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\")\n\x0c\x42\x61tchRequest\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\"\x92\x01\n\rBatchResponse\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12\x66\n\x05\x62\x61tch\x18\x02 \x01(\x0b\x32P.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BatchR\x05\x62\x61tch\"\x87\x01\n\rOrderingBlock\x12v\n\x06proofs\x18\x01 \x03(\x0b\x32^.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ProofOfAvailabilityR\x06proofs\"\xc3\x01\n\x13ProofOfAvailability\x12\x19\n\x08\x62\x61tch_id\x18\x01 \x01(\x0cR\x07\x62\x61tchId\x12n\n\x04\x61\x63ks\x18\x02 \x03(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.AvailabilityAckR\x04\x61\x63ks\x12!\n\x0c\x65poch_number\x18\x03 \x01(\x03R\x0b\x65pochNumber\"r\n\x0f\x41vailabilityAck\x12\x12\n\x04\x66rom\x18\x01 \x01(\tR\x04\x66rom\x12K\n\tsignature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\tsignature\"\x95\x06\n\x10\x43onsensusMessage\x12\x7f\n\x0e\x62lock_metadata\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockMetadataR\rblockMetadata\x12\x1f\n\x0bview_number\x18\x02 \x01(\x03R\nviewNumber\x12\x12\n\x04\x66rom\x18\x03 \x01(\tR\x04\x66rom\x12x\n\x0bpre_prepare\x18\x04 \x01(\x0b\x32U.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrePrepareH\x00R\nprePrepare\x12n\n\x07prepare\x18\x05 \x01(\x0b\x32R.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrepareH\x00R\x07prepare\x12k\n\x06\x63ommit\x18\x06 \x01(\x0b\x32Q.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitH\x00R\x06\x63ommit\x12x\n\x0bview_change\x18\x07 \x01(\x0b\x32U.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ViewChangeH\x00R\nviewChange\x12o\n\x08new_view\x18\x08 \x01(\x0b\x32R.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.NewViewH\x00R\x07newViewB\t\n\x07message\"U\n\rBlockMetadata\x12!\n\x0c\x65poch_number\x18\x01 \x01(\x03R\x0b\x65pochNumber\x12!\n\x0c\x62lock_number\x18\x02 \x01(\x03R\x0b\x62lockNumber\"\x9e\x02\n\nPrePrepare\x12n\n\x05\x62lock\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.OrderingBlockR\x05\x62lock\x12\x9f\x01\n\x1d\x62\x66t_time_canonical_commit_set\x18\x02 \x01(\x0b\x32].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CanonicalCommitSetR\x19\x62\x66tTimeCanonicalCommitSet\"(\n\x07Prepare\x12\x1d\n\nblock_hash\x18\x01 \x01(\x0cR\tblockHash\"P\n\x06\x43ommit\x12\x1d\n\nblock_hash\x18\x01 \x01(\x0cR\tblockHash\x12\'\n\x0flocal_timestamp\x18\x02 \x01(\x03R\x0elocalTimestamp\"\x97\x01\n\nViewChange\x12\x88\x01\n\x0f\x63onsensus_certs\x18\x02 \x03(\x0b\x32_.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.ConsensusCertificateR\x0e\x63onsensusCerts\"\x83\x02\n\x07NewView\x12{\n\x0cview_changes\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x0bviewChanges\x12{\n\x0cpre_prepares\x18\x03 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x0bprePrepares\"\x9c\x01\n\x12\x43\x61nonicalCommitSet\x12\x85\x01\n\x11\x63\x61nonical_commits\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x10\x63\x61nonicalCommits\"\xc8\x02\n\x14\x43onsensusCertificate\x12\x90\x01\n\x13prepare_certificate\x18\x01 \x01(\x0b\x32].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.PrepareCertificateH\x00R\x12prepareCertificate\x12\x8d\x01\n\x12\x63ommit_certificate\x18\x02 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateH\x00R\x11\x63ommitCertificateB\r\n\x0b\x63\x65rtificate\"\x85\x02\n\x12PrepareCertificate\x12y\n\x0bpre_prepare\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\nprePrepare\x12t\n\x08prepares\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x08prepares\"\x82\x02\n\x11\x43ommitCertificate\x12y\n\x0bpre_prepare\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\nprePrepare\x12r\n\x07\x63ommits\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageR\x07\x63ommits\"\xd5\x02\n\x15RetransmissionMessage\x12\x91\x01\n\x16retransmission_request\x18\x01 \x01(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SignedMessageH\x00R\x15retransmissionRequest\x12\x9c\x01\n\x17retransmission_response\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.RetransmissionResponseH\x00R\x16retransmissionResponseB\t\n\x07message\"\xa8\x01\n\x16RetransmissionResponse\x12\x8d\x01\n\x13\x63ommit_certificates\x18\x01 \x03(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateR\x12\x63ommitCertificates\"\xa6\x01\n\x0b\x45pochStatus\x12!\n\x0c\x65poch_number\x18\x01 \x01(\x03R\x0b\x65pochNumber\x12t\n\x08segments\x18\x02 \x03(\x0b\x32X.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentStatusR\x08segments\"\xd9\x02\n\rSegmentStatus\x12\x34\n\x08\x63omplete\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x08\x63omplete\x12\x86\x01\n\x0ein_view_change\x18\x02 \x01(\x0b\x32^.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentInViewChangeH\x00R\x0cinViewChange\x12\x7f\n\x0bin_progress\x18\x03 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.SegmentInProgressH\x00R\ninProgressB\x08\n\x06status\"\xa7\x01\n\x13SegmentInViewChange\x12\x1f\n\x0bview_number\x18\x01 \x01(\x03R\nviewNumber\x12?\n\x1cview_change_messages_present\x18\x02 \x03(\x08R\x19viewChangeMessagesPresent\x12.\n\x13\x61re_blocks_complete\x18\x03 \x03(\x08R\x11\x61reBlocksComplete\"\xb3\x01\n\x11SegmentInProgress\x12\x1f\n\x0bview_number\x18\x01 \x01(\x03R\nviewNumber\x12}\n\x0e\x62lock_statuses\x18\x02 \x03(\x0b\x32V.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockStatusR\rblockStatuses\"\xcc\x01\n\x0b\x42lockStatus\x12\x34\n\x08\x63omplete\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x08\x63omplete\x12}\n\x0bin_progress\x18\x02 \x01(\x0b\x32Z.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockInProgressH\x00R\ninProgressB\x08\n\x06status\"\x88\x01\n\x0f\x42lockInProgress\x12!\n\x0cpre_prepared\x18\x01 \x01(\x08R\x0bprePrepared\x12)\n\x10prepares_present\x18\x02 \x03(\x08R\x0fpreparesPresent\x12\'\n\x0f\x63ommits_present\x18\x03 \x03(\x08R\x0e\x63ommitsPresent\"\xb6\x02\n\x14StateTransferMessage\x12\x86\x01\n\rblock_request\x18\x01 \x01(\x0b\x32_.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockTransferRequestH\x00R\x0c\x62lockRequest\x12\x89\x01\n\x0e\x62lock_response\x18\x02 \x01(\x0b\x32`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BlockTransferResponseH\x00R\rblockResponseB\t\n\x07message\",\n\x14\x42lockTransferRequest\x12\x14\n\x05\x65poch\x18\x01 \x01(\x03R\x05\x65poch\"\xc1\x01\n\x15\x42lockTransferResponse\x12\x90\x01\n\x12\x63ommit_certificate\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.CommitCertificateH\x00R\x11\x63ommitCertificate\x88\x01\x01\x42\x15\n\x13_commit_certificate2\xe2\x01\n\x12\x42\x66tOrderingService\x12\xcb\x01\n\x07Receive\x12].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessage\x1a].com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.BftOrderingMessage(\x01\x30\x01\x42zZxgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.v30.bft_ordering_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Zxgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/v30'
  _globals['_BFTORDERINGMESSAGE']._serialized_start=291
  _globals['_BFTORDERINGMESSAGE']._serialized_end=545
  _globals['_BFTORDERINGMESSAGEBODY']._serialized_start=548
  _globals['_BFTORDERINGMESSAGEBODY']._serialized_end=1309
  _globals['_SIGNEDMESSAGE']._serialized_start=1312
  _globals['_SIGNEDMESSAGE']._serialized_end=1450
  _globals['_CONNECTIONOPENED']._serialized_start=1452
  _globals['_CONNECTIONOPENED']._serialized_end=1470
  _globals['_AVAILABILITYMESSAGE']._serialized_start=1473
  _globals['_AVAILABILITYMESSAGE']._serialized_end=2071
  _globals['_STOREREQUEST']._serialized_start=2074
  _globals['_STOREREQUEST']._serialized_end=2219
  _globals['_BATCH']._serialized_start=2222
  _globals['_BATCH']._serialized_end=2402
  _globals['_ORDERINGREQUEST']._serialized_start=2405
  _globals['_ORDERINGREQUEST']._serialized_end=2585
  _globals['_STORERESPONSE']._serialized_start=2587
  _globals['_STORERESPONSE']._serialized_end=2706
  _globals['_BATCHREQUEST']._serialized_start=2708
  _globals['_BATCHREQUEST']._serialized_end=2749
  _globals['_BATCHRESPONSE']._serialized_start=2752
  _globals['_BATCHRESPONSE']._serialized_end=2898
  _globals['_ORDERINGBLOCK']._serialized_start=2901
  _globals['_ORDERINGBLOCK']._serialized_end=3036
  _globals['_PROOFOFAVAILABILITY']._serialized_start=3039
  _globals['_PROOFOFAVAILABILITY']._serialized_end=3234
  _globals['_AVAILABILITYACK']._serialized_start=3236
  _globals['_AVAILABILITYACK']._serialized_end=3350
  _globals['_CONSENSUSMESSAGE']._serialized_start=3353
  _globals['_CONSENSUSMESSAGE']._serialized_end=4142
  _globals['_BLOCKMETADATA']._serialized_start=4144
  _globals['_BLOCKMETADATA']._serialized_end=4229
  _globals['_PREPREPARE']._serialized_start=4232
  _globals['_PREPREPARE']._serialized_end=4518
  _globals['_PREPARE']._serialized_start=4520
  _globals['_PREPARE']._serialized_end=4560
  _globals['_COMMIT']._serialized_start=4562
  _globals['_COMMIT']._serialized_end=4642
  _globals['_VIEWCHANGE']._serialized_start=4645
  _globals['_VIEWCHANGE']._serialized_end=4796
  _globals['_NEWVIEW']._serialized_start=4799
  _globals['_NEWVIEW']._serialized_end=5058
  _globals['_CANONICALCOMMITSET']._serialized_start=5061
  _globals['_CANONICALCOMMITSET']._serialized_end=5217
  _globals['_CONSENSUSCERTIFICATE']._serialized_start=5220
  _globals['_CONSENSUSCERTIFICATE']._serialized_end=5548
  _globals['_PREPARECERTIFICATE']._serialized_start=5551
  _globals['_PREPARECERTIFICATE']._serialized_end=5812
  _globals['_COMMITCERTIFICATE']._serialized_start=5815
  _globals['_COMMITCERTIFICATE']._serialized_end=6073
  _globals['_RETRANSMISSIONMESSAGE']._serialized_start=6076
  _globals['_RETRANSMISSIONMESSAGE']._serialized_end=6417
  _globals['_RETRANSMISSIONRESPONSE']._serialized_start=6420
  _globals['_RETRANSMISSIONRESPONSE']._serialized_end=6588
  _globals['_EPOCHSTATUS']._serialized_start=6591
  _globals['_EPOCHSTATUS']._serialized_end=6757
  _globals['_SEGMENTSTATUS']._serialized_start=6760
  _globals['_SEGMENTSTATUS']._serialized_end=7105
  _globals['_SEGMENTINVIEWCHANGE']._serialized_start=7108
  _globals['_SEGMENTINVIEWCHANGE']._serialized_end=7275
  _globals['_SEGMENTINPROGRESS']._serialized_start=7278
  _globals['_SEGMENTINPROGRESS']._serialized_end=7457
  _globals['_BLOCKSTATUS']._serialized_start=7460
  _globals['_BLOCKSTATUS']._serialized_end=7664
  _globals['_BLOCKINPROGRESS']._serialized_start=7667
  _globals['_BLOCKINPROGRESS']._serialized_end=7803
  _globals['_STATETRANSFERMESSAGE']._serialized_start=7806
  _globals['_STATETRANSFERMESSAGE']._serialized_end=8116
  _globals['_BLOCKTRANSFERREQUEST']._serialized_start=8118
  _globals['_BLOCKTRANSFERREQUEST']._serialized_end=8162
  _globals['_BLOCKTRANSFERRESPONSE']._serialized_start=8165
  _globals['_BLOCKTRANSFERRESPONSE']._serialized_end=8358
  _globals['_BFTORDERINGSERVICE']._serialized_start=8361
  _globals['_BFTORDERINGSERVICE']._serialized_end=8587
# @@protoc_insertion_point(module_scope)
