# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/topology.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/topology.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import sequencing_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_sequencing__parameters__pb2
from . import synchronizer_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_synchronizer__parameters__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n3com/digitalasset/canton/protocol/v30/topology.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a@com/digitalasset/canton/protocol/v30/sequencing_parameters.proto\x1a\x42\x63om/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xd1\n\n\x05\x45nums\"y\n\x10TopologyChangeOp\x12\"\n\x1eTOPOLOGY_CHANGE_OP_UNSPECIFIED\x10\x00\x12\"\n\x1eTOPOLOGY_CHANGE_OP_ADD_REPLACE\x10\x01\x12\x1d\n\x19TOPOLOGY_CHANGE_OP_REMOVE\x10\x02\"\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\"\xff\x06\n\x13TopologyMappingCode\x12%\n!TOPOLOGY_MAPPING_CODE_UNSPECIFIED\x10\x00\x12.\n*TOPOLOGY_MAPPING_CODE_NAMESPACE_DELEGATION\x10\x01\x12<\n8TOPOLOGY_MAPPING_CODE_DECENTRALIZED_NAMESPACE_DEFINITION\x10\x03\x12.\n*TOPOLOGY_MAPPING_CODE_OWNER_TO_KEY_MAPPING\x10\x04\x12\x38\n4TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_TRUST_CERTIFICATE\x10\x05\x12\x30\n,TOPOLOGY_MAPPING_CODE_PARTICIPANT_PERMISSION\x10\x06\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_HOSTING_LIMITS\x10\x07\x12)\n%TOPOLOGY_MAPPING_CODE_VETTED_PACKAGES\x10\x08\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_TO_PARTICIPANT\x10\t\x12\x37\n3TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_PARAMETERS_STATE\x10\x0b\x12\x35\n1TOPOLOGY_MAPPING_CODE_MEDIATOR_SYNCHRONIZER_STATE\x10\x0c\x12\x36\n2TOPOLOGY_MAPPING_CODE_SEQUENCER_SYNCHRONIZER_STATE\x10\r\x12=\n9TOPOLOGY_MAPPING_CODE_SEQUENCING_DYNAMIC_PARAMETERS_STATE\x10\x11\x12.\n*TOPOLOGY_MAPPING_CODE_PARTY_TO_KEY_MAPPING\x10\x12\x12=\n9TOPOLOGY_MAPPING_CODE_SYNCHRONIZER_MIGRATION_ANNOUNCEMENT\x10\x13\x12\x38\n4TOPOLOGY_MAPPING_CODE_SEQUENCER_CONNECTION_SUCCESSOR\x10\x14\"\x04\x08\x02\x10\x02\"\x04\x08\n\x10\n\"\x04\x08\x0e\x10\x0e\"\x04\x08\x0f\x10\x0f\"\x04\x08\x10\x10\x10\"\x90\x01\n\x16ParticipantFeatureFlag\x12(\n$PARTICIPANT_FEATURE_FLAG_UNSPECIFIED\x10\x00\x12L\nHPARTICIPANT_FEATURE_FLAG_PV33_EXTERNAL_SIGNING_LOCAL_CONTRACT_IN_SUBVIEW\x10\x01\"\xc4\x06\n\x13NamespaceDelegation\x12\x1c\n\tnamespace\x18\x01 \x01(\tR\tnamespace\x12S\n\ntarget_key\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\ttargetKey\x12\x30\n\x12is_root_delegation\x18\x03 \x01(\x08\x42\x02\x18\x01R\x10isRootDelegation\x12\x81\x01\n\x15\x63\x61n_sign_all_mappings\x18\x04 \x01(\x0b\x32L.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignAllMappingsH\x00R\x12\x63\x61nSignAllMappings\x12\xb0\x01\n&can_sign_all_but_namespace_delegations\x18\x05 \x01(\x0b\x32[.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignAllButNamespaceDelegationsH\x00R!canSignAllButNamespaceDelegations\x12\x8e\x01\n\x19\x63\x61n_sign_specific_mapings\x18\x06 \x01(\x0b\x32Q.com.digitalasset.canton.protocol.v30.NamespaceDelegation.CanSignSpecificMappingsH\x00R\x16\x63\x61nSignSpecificMapings\x1a\x14\n\x12\x43\x61nSignAllMappings\x1a#\n!CanSignAllButNamespaceDelegations\x1av\n\x17\x43\x61nSignSpecificMappings\x12[\n\x08mappings\x18\x01 \x03(\x0e\x32?.com.digitalasset.canton.protocol.v30.Enums.TopologyMappingCodeR\x08mappingsB\r\n\x0brestriction\"\x91\x01\n DecentralizedNamespaceDefinition\x12\x37\n\x17\x64\x65\x63\x65ntralized_namespace\x18\x01 \x01(\tR\x16\x64\x65\x63\x65ntralizedNamespace\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold\x12\x16\n\x06owners\x18\x03 \x03(\tR\x06owners\"\x81\x01\n\x11OwnerToKeyMapping\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12N\n\x0bpublic_keys\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.PublicKeyR\npublicKeysJ\x04\x08\x03\x10\x04\"\xa6\x01\n\x11PartyToKeyMapping\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12W\n\x0csigning_keys\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.crypto.v30.SigningPublicKeyR\x0bsigningKeysJ\x04\x08\x02\x10\x03\"\xe5\x01\n\x1cSynchronizerTrustCertificate\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12g\n\rfeature_flags\x18\x05 \x03(\x0e\x32\x42.com.digitalasset.canton.protocol.v30.Enums.ParticipantFeatureFlagR\x0c\x66\x65\x61tureFlagsJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xeb\x02\n!ParticipantSynchronizerPermission\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\'\n\x0fparticipant_uid\x18\x02 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12[\n\x06limits\x18\x04 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerLimitsR\x06limits\x12$\n\x0blogin_after\x18\x05 \x01(\x03H\x00R\nloginAfter\x88\x01\x01\x42\x0e\n\x0c_login_after\"Y\n\x12PartyHostingLimits\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x14\n\x05party\x18\x02 \x01(\tR\x05partyJ\x04\x08\x03\x10\x04\"\x93\x03\n\x0eVettedPackages\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12#\n\x0bpackage_ids\x18\x02 \x03(\tB\x02\x18\x01R\npackageIds\x12^\n\x08packages\x18\x04 \x03(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.VettedPackages.VettedPackageR\x08packages\x1a\xcc\x01\n\rVettedPackage\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12L\n\x14valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12validFromInclusive\x12N\n\x15valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x13validUntilExclusiveJ\x04\x08\x03\x10\x04\"\xf6\x04\n\x12PartyToParticipant\x12\x14\n\x05party\x18\x01 \x01(\tR\x05party\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12o\n\x0cparticipants\x18\x03 \x03(\x0b\x32K.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipantR\x0cparticipants\x12o\n\x12party_signing_keys\x18\x06 \x01(\x0b\x32<.com.digitalasset.canton.crypto.v30.SigningKeysWithThresholdH\x00R\x10partySigningKeys\x88\x01\x01\x1a\xa6\x02\n\x12HostingParticipant\x12\'\n\x0fparticipant_uid\x18\x01 \x01(\tR\x0eparticipantUid\x12\x61\n\npermission\x18\x02 \x01(\x0e\x32\x41.com.digitalasset.canton.protocol.v30.Enums.ParticipantPermissionR\npermission\x12v\n\nonboarding\x18\x03 \x01(\x0b\x32V.com.digitalasset.canton.protocol.v30.PartyToParticipant.HostingParticipant.OnboardingR\nonboarding\x1a\x0c\n\nOnboardingB\x15\n\x13_party_signing_keysJ\x04\x08\x04\x10\x05J\x04\x08\x05\x10\x06\"\xc4\x01\n\x1bSynchronizerParametersState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12|\n\x17synchronizer_parameters\x18\x02 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.DynamicSynchronizerParametersR\x16synchronizerParameters\"\xc3\x01\n DynamicSequencingParametersState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12v\n\x15sequencing_parameters\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersR\x14sequencingParameters\"\xae\x01\n\x19MediatorSynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x14\n\x05group\x18\x02 \x01(\rR\x05group\x12\x1c\n\tthreshold\x18\x03 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x04 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x05 \x03(\tR\tobservers\"\x99\x01\n\x1aSequencerSynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x1c\n\tthreshold\x18\x02 \x01(\rR\tthreshold\x12\x16\n\x06\x61\x63tive\x18\x03 \x03(\tR\x06\x61\x63tive\x12\x1c\n\tobservers\x18\x04 \x03(\tR\tobservers\"\xad\x01\n\x1fSynchronizerUpgradeAnnouncement\x12K\n\"successor_physical_synchronizer_id\x18\x01 \x01(\tR\x1fsuccessorPhysicalSynchronizerId\x12=\n\x0cupgrade_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0bupgradeTime\"\x86\x04\n\x1cSequencerConnectionSuccessor\x12!\n\x0csequencer_id\x18\x01 \x01(\tR\x0bsequencerId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12v\n\nconnection\x18\x03 \x01(\x0b\x32V.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessor.SequencerConnectionR\nconnection\x1a\xa1\x02\n\x13SequencerConnection\x12q\n\x04grpc\x18\x01 \x01(\x0b\x32[.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessor.SequencerConnection.GrpcH\x00R\x04grpc\x1a\x83\x01\n\x04Grpc\x12\x1c\n\tendpoints\x18\x01 \x03(\tR\tendpoints\x12?\n\x19\x63ustom_trust_certificates\x18\x02 \x01(\x0cH\x00R\x17\x63ustomTrustCertificates\x88\x01\x01\x42\x1c\n\x1a_custom_trust_certificatesB\x11\n\x0f\x63onnection_type\"\xae\x0f\n\x0fTopologyMapping\x12n\n\x14namespace_delegation\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationH\x00R\x13namespaceDelegation\x12\x96\x01\n\"decentralized_namespace_definition\x18\x03 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionH\x00R decentralizedNamespaceDefinition\x12j\n\x14owner_to_key_mapping\x18\x04 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingH\x00R\x11ownerToKeyMapping\x12\x8a\x01\n\x1esynchronizer_trust_certificate\x18\x05 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SynchronizerTrustCertificateH\x00R\x1csynchronizerTrustCertificate\x12\x80\x01\n\x16participant_permission\x18\x06 \x01(\x0b\x32G.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerPermissionH\x00R\x15participantPermission\x12l\n\x14party_hosting_limits\x18\x07 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsH\x00R\x12partyHostingLimits\x12_\n\x0fvetted_packages\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesH\x00R\x0evettedPackages\x12l\n\x14party_to_participant\x18\t \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantH\x00R\x12partyToParticipant\x12\x87\x01\n\x1dsynchronizer_parameters_state\x18\x0b \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.SynchronizerParametersStateH\x00R\x1bsynchronizerParametersState\x12\x81\x01\n\x1bmediator_synchronizer_state\x18\x0c \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.MediatorSynchronizerStateH\x00R\x19mediatorSynchronizerState\x12\x84\x01\n\x1csequencer_synchronizer_state\x18\r \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SequencerSynchronizerStateH\x00R\x1asequencerSynchronizerState\x12\x97\x01\n#sequencing_dynamic_parameters_state\x18\x0f \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DynamicSequencingParametersStateH\x00R sequencingDynamicParametersState\x12j\n\x14party_to_key_mapping\x18\x10 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingH\x00R\x11partyToKeyMapping\x12\x93\x01\n!synchronizer_upgrade_announcement\x18\x11 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.SynchronizerUpgradeAnnouncementH\x00R\x1fsynchronizerUpgradeAnnouncement\x12\x8a\x01\n\x1esequencer_connection_successor\x18\x12 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessorH\x00R\x1csequencerConnectionSuccessorB\t\n\x07mappingJ\x04\x08\x02\x10\x03J\x04\x08\n\x10\x0bJ\x04\x08\x0e\x10\x0f\"\xda\x01\n\x13TopologyTransaction\x12Z\n\toperation\x18\x01 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x16\n\x06serial\x18\x02 \x01(\rR\x06serial\x12O\n\x07mapping\x18\x03 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.TopologyMappingR\x07mapping\"\x9a\x01\n\x1aMultiTransactionSignatures\x12-\n\x12transaction_hashes\x18\x01 \x03(\x0cR\x11transactionHashes\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"\xad\x02\n\x19SignedTopologyTransaction\x12 \n\x0btransaction\x18\x01 \x01(\x0cR\x0btransaction\x12M\n\nsignatures\x18\x02 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\x12\x1a\n\x08proposal\x18\x03 \x01(\x08R\x08proposal\x12\x82\x01\n\x1cmulti_transaction_signatures\x18\x04 \x03(\x0b\x32@.com.digitalasset.canton.protocol.v30.MultiTransactionSignaturesR\x1amultiTransactionSignatures\"K\n\x1aSignedTopologyTransactions\x12-\n\x12signed_transaction\x18\x01 \x03(\x0cR\x11signedTransaction\"\xcc\x01\n\x1dTopologyTransactionsBroadcast\x12\x38\n\x18physical_synchronizer_id\x18\x01 \x01(\tR\x16physicalSynchronizerId\x12q\n\x13signed_transactions\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionsR\x12signedTransactionsBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.topology_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_NAMESPACEDELEGATION'].fields_by_name['is_root_delegation']._loaded_options = None
  _globals['_NAMESPACEDELEGATION'].fields_by_name['is_root_delegation']._serialized_options = b'\030\001'
  _globals['_VETTEDPACKAGES'].fields_by_name['package_ids']._loaded_options = None
  _globals['_VETTEDPACKAGES'].fields_by_name['package_ids']._serialized_options = b'\030\001'
  _globals['_ENUMS']._serialized_start=310
  _globals['_ENUMS']._serialized_end=1671
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_start=319
  _globals['_ENUMS_TOPOLOGYCHANGEOP']._serialized_end=440
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_start=443
  _globals['_ENUMS_PARTICIPANTPERMISSION']._serialized_end=626
  _globals['_ENUMS_TOPOLOGYMAPPINGCODE']._serialized_start=629
  _globals['_ENUMS_TOPOLOGYMAPPINGCODE']._serialized_end=1524
  _globals['_ENUMS_PARTICIPANTFEATUREFLAG']._serialized_start=1527
  _globals['_ENUMS_PARTICIPANTFEATUREFLAG']._serialized_end=1671
  _globals['_NAMESPACEDELEGATION']._serialized_start=1674
  _globals['_NAMESPACEDELEGATION']._serialized_end=2510
  _globals['_NAMESPACEDELEGATION_CANSIGNALLMAPPINGS']._serialized_start=2318
  _globals['_NAMESPACEDELEGATION_CANSIGNALLMAPPINGS']._serialized_end=2338
  _globals['_NAMESPACEDELEGATION_CANSIGNALLBUTNAMESPACEDELEGATIONS']._serialized_start=2340
  _globals['_NAMESPACEDELEGATION_CANSIGNALLBUTNAMESPACEDELEGATIONS']._serialized_end=2375
  _globals['_NAMESPACEDELEGATION_CANSIGNSPECIFICMAPPINGS']._serialized_start=2377
  _globals['_NAMESPACEDELEGATION_CANSIGNSPECIFICMAPPINGS']._serialized_end=2495
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_start=2513
  _globals['_DECENTRALIZEDNAMESPACEDEFINITION']._serialized_end=2658
  _globals['_OWNERTOKEYMAPPING']._serialized_start=2661
  _globals['_OWNERTOKEYMAPPING']._serialized_end=2790
  _globals['_PARTYTOKEYMAPPING']._serialized_start=2793
  _globals['_PARTYTOKEYMAPPING']._serialized_end=2959
  _globals['_SYNCHRONIZERTRUSTCERTIFICATE']._serialized_start=2962
  _globals['_SYNCHRONIZERTRUSTCERTIFICATE']._serialized_end=3191
  _globals['_PARTICIPANTSYNCHRONIZERPERMISSION']._serialized_start=3194
  _globals['_PARTICIPANTSYNCHRONIZERPERMISSION']._serialized_end=3557
  _globals['_PARTYHOSTINGLIMITS']._serialized_start=3559
  _globals['_PARTYHOSTINGLIMITS']._serialized_end=3648
  _globals['_VETTEDPACKAGES']._serialized_start=3651
  _globals['_VETTEDPACKAGES']._serialized_end=4054
  _globals['_VETTEDPACKAGES_VETTEDPACKAGE']._serialized_start=3844
  _globals['_VETTEDPACKAGES_VETTEDPACKAGE']._serialized_end=4048
  _globals['_PARTYTOPARTICIPANT']._serialized_start=4057
  _globals['_PARTYTOPARTICIPANT']._serialized_end=4687
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_start=4358
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT']._serialized_end=4652
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT_ONBOARDING']._serialized_start=4640
  _globals['_PARTYTOPARTICIPANT_HOSTINGPARTICIPANT_ONBOARDING']._serialized_end=4652
  _globals['_SYNCHRONIZERPARAMETERSSTATE']._serialized_start=4690
  _globals['_SYNCHRONIZERPARAMETERSSTATE']._serialized_end=4886
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_start=4889
  _globals['_DYNAMICSEQUENCINGPARAMETERSSTATE']._serialized_end=5084
  _globals['_MEDIATORSYNCHRONIZERSTATE']._serialized_start=5087
  _globals['_MEDIATORSYNCHRONIZERSTATE']._serialized_end=5261
  _globals['_SEQUENCERSYNCHRONIZERSTATE']._serialized_start=5264
  _globals['_SEQUENCERSYNCHRONIZERSTATE']._serialized_end=5417
  _globals['_SYNCHRONIZERUPGRADEANNOUNCEMENT']._serialized_start=5420
  _globals['_SYNCHRONIZERUPGRADEANNOUNCEMENT']._serialized_end=5593
  _globals['_SEQUENCERCONNECTIONSUCCESSOR']._serialized_start=5596
  _globals['_SEQUENCERCONNECTIONSUCCESSOR']._serialized_end=6114
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION']._serialized_start=5825
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION']._serialized_end=6114
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION_GRPC']._serialized_start=5964
  _globals['_SEQUENCERCONNECTIONSUCCESSOR_SEQUENCERCONNECTION_GRPC']._serialized_end=6095
  _globals['_TOPOLOGYMAPPING']._serialized_start=6117
  _globals['_TOPOLOGYMAPPING']._serialized_end=8083
  _globals['_TOPOLOGYTRANSACTION']._serialized_start=8086
  _globals['_TOPOLOGYTRANSACTION']._serialized_end=8304
  _globals['_MULTITRANSACTIONSIGNATURES']._serialized_start=8307
  _globals['_MULTITRANSACTIONSIGNATURES']._serialized_end=8461
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_start=8464
  _globals['_SIGNEDTOPOLOGYTRANSACTION']._serialized_end=8765
  _globals['_SIGNEDTOPOLOGYTRANSACTIONS']._serialized_start=8767
  _globals['_SIGNEDTOPOLOGYTRANSACTIONS']._serialized_end=8842
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_start=8845
  _globals['_TOPOLOGYTRANSACTIONSBROADCAST']._serialized_end=9049
# @@protoc_insertion_point(module_scope)
