# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

if TYPE_CHECKING:
    from ..models.features_descriptor import FeaturesDescriptor


T = TypeVar("T", bound="GetLedgerApiVersionResponse")


@_attrs_define
class GetLedgerApiVersionResponse:
    """
    Attributes:
        version (str): The version of the ledger API.
        features (FeaturesDescriptor | Unset):
    """

    version: str
    features: FeaturesDescriptor | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        version = self.version

        features: dict[str, Any] | Unset = UNSET
        if not isinstance(self.features, Unset):
            features = self.features.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "version": version,
            }
        )
        if features is not UNSET:
            field_dict["features"] = features

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.features_descriptor import FeaturesDescriptor

        d = dict(src_dict)
        version = d.pop("version")

        _features = d.pop("features", UNSET)
        features: FeaturesDescriptor | Unset
        if isinstance(_features, Unset):
            features = UNSET
        else:
            features = FeaturesDescriptor.from_dict(_features)

        get_ledger_api_version_response = cls(
            version=version,
            features=features,
        )

        get_ledger_api_version_response.additional_properties = d
        return get_ledger_api_version_response

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
