# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/sequencing.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/sequencing.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ...v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.rpc import status_pb2 as google_dot_rpc_dot_status__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5com/digitalasset/canton/protocol/v30/sequencing.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x17google/rpc/status.proto\"\xfa\x01\n\x1dPossiblyIgnoredSequencedEvent\x12\x18\n\x07\x63ounter\x18\x01 \x01(\x03R\x07\x63ounter\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12N\n\rtrace_context\x18\x03 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\x12\x1d\n\nis_ignored\x18\x04 \x01(\x08R\tisIgnored\x12#\n\nunderlying\x18\x05 \x01(\x0cH\x00R\nunderlying\x88\x01\x01\x42\r\n\x0b_underlying\"\x82\x01\n\x0eRecipientsTree\x12\x1e\n\nrecipients\x18\x01 \x03(\tR\nrecipients\x12P\n\x08\x63hildren\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x08\x63hildren\"k\n\nRecipients\x12]\n\x0frecipients_tree\x18\x01 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.RecipientsTreeR\x0erecipientsTree\"A\n\x10ServiceAgreement\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x1d\n\nlegal_text\x18\x02 \x01(\tR\tlegalText\".\n\x18SequencingSubmissionCost\x12\x12\n\x04\x63ost\x18\x01 \x01(\x03R\x04\x63ost\"\xa8\x07\n\x1cStaticSynchronizerParameters\x12n\n\x16required_signing_specs\x18\x01 \x01(\x0b\x32\x38.com.digitalasset.canton.crypto.v30.RequiredSigningSpecsR\x14requiredSigningSpecs\x12w\n\x19required_encryption_specs\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.crypto.v30.RequiredEncryptionSpecsR\x17requiredEncryptionSpecs\x12{\n\x1erequired_symmetric_key_schemes\x18\x03 \x03(\x0e\x32\x36.com.digitalasset.canton.crypto.v30.SymmetricKeySchemeR\x1brequiredSymmetricKeySchemes\x12k\n\x18required_hash_algorithms\x18\x04 \x03(\x0e\x32\x31.com.digitalasset.canton.crypto.v30.HashAlgorithmR\x16requiredHashAlgorithms\x12r\n\x1brequired_crypto_key_formats\x18\x05 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.CryptoKeyFormatR\x18requiredCryptoKeyFormats\x12q\n\x1arequired_signature_formats\x18\x06 \x03(\x0e\x32\x33.com.digitalasset.canton.crypto.v30.SignatureFormatR\x18requiredSignatureFormats\x12)\n\x10protocol_version\x18\x07 \x01(\x05R\x0fprotocolVersion\x12\x16\n\x06serial\x18\x08 \x01(\x05R\x06serial\x12<\n\x1a\x65nable_transparency_checks\x18\t \x01(\x08R\x18\x65nableTransparencyChecks\x12M\n\x15topology_change_delay\x18\n \x01(\x0b\x32\x19.google.protobuf.DurationR\x13topologyChangeDelay\"\xc5\x01\n\x08\x45nvelope\x12\x18\n\x07\x63ontent\x18\x01 \x01(\x0cR\x07\x63ontent\x12P\n\nrecipients\x18\x02 \x01(\x0b\x32\x30.com.digitalasset.canton.protocol.v30.RecipientsR\nrecipients\x12M\n\nsignatures\x18\x03 \x03(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\nsignatures\"U\n\x05\x42\x61tch\x12L\n\tenvelopes\x18\x01 \x03(\x0b\x32..com.digitalasset.canton.protocol.v30.EnvelopeR\tenvelopes\"\x85\x02\n\x0f\x43ompressedBatch\x12h\n\talgorithm\x18\x01 \x01(\x0e\x32J.com.digitalasset.canton.protocol.v30.CompressedBatch.CompressionAlgorithmR\talgorithm\x12)\n\x10\x63ompressed_batch\x18\x02 \x01(\x0cR\x0f\x63ompressedBatch\"]\n\x14\x43ompressionAlgorithm\x12%\n!COMPRESSION_ALGORITHM_UNSPECIFIED\x10\x00\x12\x1e\n\x1a\x43OMPRESSION_ALGORITHM_GZIP\x10\x01\"\xa9\x04\n\x0eSequencedEvent\x12\x32\n\x12previous_timestamp\x18\t \x01(\x03H\x00R\x11previousTimestamp\x88\x01\x01\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x12\"\n\nmessage_id\x18\x04 \x01(\tH\x01R\tmessageId\x88\x01\x01\x12K\n\x05\x62\x61tch\x18\x05 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12\x44\n\x14\x64\x65liver_error_reason\x18\x06 \x01(\x0b\x32\x12.google.rpc.StatusR\x12\x64\x65liverErrorReason\x12\x32\n\x12topology_timestamp\x18\x07 \x01(\x03H\x02R\x11topologyTimestamp\x88\x01\x01\x12]\n\x0ftraffic_receipt\x18\x08 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.TrafficReceiptR\x0etrafficReceiptB\x15\n\x13_previous_timestampB\r\n\x0b_message_idB\x15\n\x13_topology_timestampJ\x04\x08\x01\x10\x02\"\xdd\x03\n\x11SubmissionRequest\x12\x16\n\x06sender\x18\x01 \x01(\tR\x06sender\x12\x1d\n\nmessage_id\x18\x02 \x01(\tR\tmessageId\x12K\n\x05\x62\x61tch\x18\x04 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.CompressedBatchR\x05\x62\x61tch\x12.\n\x13max_sequencing_time\x18\x05 \x01(\x03R\x11maxSequencingTime\x12\x32\n\x12topology_timestamp\x18\x06 \x01(\x03H\x00R\x11topologyTimestamp\x88\x01\x01\x12`\n\x10\x61ggregation_rule\x18\x07 \x01(\x0b\x32\x35.com.digitalasset.canton.protocol.v30.AggregationRuleR\x0f\x61ggregationRule\x12g\n\x0fsubmission_cost\x18\x08 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.SequencingSubmissionCostR\x0esubmissionCostB\x15\n\x13_topology_timestampBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.sequencing_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_start=380
  _globals['_POSSIBLYIGNOREDSEQUENCEDEVENT']._serialized_end=630
  _globals['_RECIPIENTSTREE']._serialized_start=633
  _globals['_RECIPIENTSTREE']._serialized_end=763
  _globals['_RECIPIENTS']._serialized_start=765
  _globals['_RECIPIENTS']._serialized_end=872
  _globals['_SERVICEAGREEMENT']._serialized_start=874
  _globals['_SERVICEAGREEMENT']._serialized_end=939
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_start=941
  _globals['_SEQUENCINGSUBMISSIONCOST']._serialized_end=987
  _globals['_STATICSYNCHRONIZERPARAMETERS']._serialized_start=990
  _globals['_STATICSYNCHRONIZERPARAMETERS']._serialized_end=1926
  _globals['_ENVELOPE']._serialized_start=1929
  _globals['_ENVELOPE']._serialized_end=2126
  _globals['_BATCH']._serialized_start=2128
  _globals['_BATCH']._serialized_end=2213
  _globals['_COMPRESSEDBATCH']._serialized_start=2216
  _globals['_COMPRESSEDBATCH']._serialized_end=2477
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_start=2384
  _globals['_COMPRESSEDBATCH_COMPRESSIONALGORITHM']._serialized_end=2477
  _globals['_SEQUENCEDEVENT']._serialized_start=2480
  _globals['_SEQUENCEDEVENT']._serialized_end=3033
  _globals['_SUBMISSIONREQUEST']._serialized_start=3036
  _globals['_SUBMISSIONREQUEST']._serialized_end=3513
# @@protoc_insertion_point(module_scope)
