# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc
import warnings

from . import sequencer_service_pb2 as com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2

GRPC_GENERATED_VERSION = '1.76.0'
GRPC_VERSION = grpc.__version__
_version_not_supported = False

try:
    from grpc._utilities import first_version_is_lower
    _version_not_supported = first_version_is_lower(GRPC_VERSION, GRPC_GENERATED_VERSION)
except ImportError:
    _version_not_supported = True

if _version_not_supported:
    raise RuntimeError(
        f'The grpc package installed is at version {GRPC_VERSION},'
        + ' but the generated code in com/digitalasset/canton/sequencer/api/v30/sequencer_service_pb2_grpc.py depends on'
        + f' grpcio>={GRPC_GENERATED_VERSION}.'
        + f' Please upgrade your grpc module to grpcio>={GRPC_GENERATED_VERSION}'
        + f' or downgrade your generated code using grpcio-tools<={GRPC_VERSION}.'
    )


class SequencerServiceStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.SendAsync = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/SendAsync',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
                _registered_method=True)
        self.Subscribe = channel.unary_stream(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/Subscribe',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
                _registered_method=True)
        self.AcknowledgeSigned = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/AcknowledgeSigned',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.FromString,
                _registered_method=True)
        self.DownloadTopologyStateForInit = channel.unary_stream(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInit',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.FromString,
                _registered_method=True)
        self.DownloadTopologyStateForInitHash = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInitHash',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.FromString,
                _registered_method=True)
        self.GetTrafficStateForMember = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTrafficStateForMember',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.FromString,
                _registered_method=True)
        self.GetTime = channel.unary_unary(
                '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTime',
                request_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.SerializeToString,
                response_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.FromString,
                _registered_method=True)


class SequencerServiceServicer(object):
    """Missing associated documentation comment in .proto file."""

    def SendAsync(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Subscribe(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AcknowledgeSigned(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadTopologyStateForInit(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DownloadTopologyStateForInitHash(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTrafficStateForMember(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetTime(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SequencerServiceServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'SendAsync': grpc.unary_unary_rpc_method_handler(
                    servicer.SendAsync,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.SerializeToString,
            ),
            'Subscribe': grpc.unary_stream_rpc_method_handler(
                    servicer.Subscribe,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.SerializeToString,
            ),
            'AcknowledgeSigned': grpc.unary_unary_rpc_method_handler(
                    servicer.AcknowledgeSigned,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.SerializeToString,
            ),
            'DownloadTopologyStateForInit': grpc.unary_stream_rpc_method_handler(
                    servicer.DownloadTopologyStateForInit,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.SerializeToString,
            ),
            'DownloadTopologyStateForInitHash': grpc.unary_unary_rpc_method_handler(
                    servicer.DownloadTopologyStateForInitHash,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.SerializeToString,
            ),
            'GetTrafficStateForMember': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTrafficStateForMember,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.SerializeToString,
            ),
            'GetTime': grpc.unary_unary_rpc_method_handler(
                    servicer.GetTime,
                    request_deserializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.FromString,
                    response_serializer=com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'com.digitalasset.canton.sequencer.api.v30.SequencerService', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))
    server.add_registered_method_handlers('com.digitalasset.canton.sequencer.api.v30.SequencerService', rpc_method_handlers)


 # This class is part of an EXPERIMENTAL API.
class SequencerService(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def SendAsync(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/SendAsync',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SendAsyncResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def Subscribe(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/Subscribe',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.SubscriptionResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def AcknowledgeSigned(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/AcknowledgeSigned',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.AcknowledgeSignedResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadTopologyStateForInit(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_stream(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInit',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def DownloadTopologyStateForInitHash(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/DownloadTopologyStateForInitHash',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.DownloadTopologyStateForInitHashResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTrafficStateForMember(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTrafficStateForMember',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTrafficStateForMemberResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)

    @staticmethod
    def GetTime(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(
            request,
            target,
            '/com.digitalasset.canton.sequencer.api.v30.SequencerService/GetTime',
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeRequest.SerializeToString,
            com_dot_digitalasset_dot_canton_dot_sequencer_dot_api_dot_v30_dot_sequencer__service__pb2.GetTimeResponse.FromString,
            options,
            channel_credentials,
            insecure,
            call_credentials,
            compression,
            wait_for_ready,
            timeout,
            metadata,
            _registered_method=True)
