# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/admin/package_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/admin/package_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .. import package_reference_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_package__reference__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n=com/daml/ledger/api/v2/admin/package_management_service.proto\x12\x1c\x63om.daml.ledger.api.v2.admin\x1a.com/daml/ledger/api/v2/package_reference.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x1a\n\x18ListKnownPackagesRequest\"r\n\x19ListKnownPackagesResponse\x12U\n\x0fpackage_details\x18\x01 \x03(\x0b\x32,.com.daml.ledger.api.v2.admin.PackageDetailsR\x0epackageDetails\"\xbd\x01\n\x0ePackageDetails\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_size\x18\x02 \x01(\x04R\x0bpackageSize\x12;\n\x0bknown_since\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nknownSince\x12\x12\n\x04name\x18\x04 \x01(\tR\x04name\x12\x18\n\x07version\x18\x05 \x01(\tR\x07version\"\xe8\x02\n\x14UploadDarFileRequest\x12\x19\n\x08\x64\x61r_file\x18\x01 \x01(\x0cR\x07\x64\x61rFile\x12#\n\rsubmission_id\x18\x02 \x01(\tR\x0csubmissionId\x12g\n\x0evetting_change\x18\x03 \x01(\x0e\x32@.com.daml.ledger.api.v2.admin.UploadDarFileRequest.VettingChangeR\rvettingChange\x12\'\n\x0fsynchronizer_id\x18\x04 \x01(\tR\x0esynchronizerId\"~\n\rVettingChange\x12\x1e\n\x1aVETTING_CHANGE_UNSPECIFIED\x10\x00\x12#\n\x1fVETTING_CHANGE_VET_ALL_PACKAGES\x10\x01\x12(\n$VETTING_CHANGE_DONT_VET_ANY_PACKAGES\x10\x02\"\x17\n\x15UploadDarFileResponse\"\x81\x01\n\x16ValidateDarFileRequest\x12\x19\n\x08\x64\x61r_file\x18\x01 \x01(\x0cR\x07\x64\x61rFile\x12#\n\rsubmission_id\x18\x02 \x01(\tR\x0csubmissionId\x12\'\n\x0fsynchronizer_id\x18\x04 \x01(\tR\x0esynchronizerId\"\x19\n\x17ValidateDarFileResponse\"\x98\x04\n\x14VettedPackagesChange\x12J\n\x03vet\x18\x01 \x01(\x0b\x32\x36.com.daml.ledger.api.v2.admin.VettedPackagesChange.VetH\x00R\x03vet\x12P\n\x05unvet\x18\x02 \x01(\x0b\x32\x38.com.daml.ledger.api.v2.admin.VettedPackagesChange.UnvetH\x00R\x05unvet\x1aT\n\x05Unvet\x12K\n\x08packages\x18\x01 \x03(\x0b\x32/.com.daml.ledger.api.v2.admin.VettedPackagesRefR\x08packages\x1a\xfe\x01\n\x03Vet\x12K\n\x08packages\x18\x01 \x03(\x0b\x32/.com.daml.ledger.api.v2.admin.VettedPackagesRefR\x08packages\x12S\n\x18new_valid_from_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x15newValidFromInclusive\x12U\n\x19new_valid_until_exclusive\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x16newValidUntilExclusiveB\x0b\n\toperation\"~\n\x11VettedPackagesRef\x12\x1d\n\npackage_id\x18\x01 \x01(\tR\tpackageId\x12!\n\x0cpackage_name\x18\x02 \x01(\tR\x0bpackageName\x12\'\n\x0fpackage_version\x18\x03 \x01(\tR\x0epackageVersion\"\x9e\x03\n\x1bUpdateVettedPackagesRequest\x12L\n\x07\x63hanges\x18\x01 \x03(\x0b\x32\x32.com.daml.ledger.api.v2.admin.VettedPackagesChangeR\x07\x63hanges\x12\x17\n\x07\x64ry_run\x18\x02 \x01(\x08R\x06\x64ryRun\x12\'\n\x0fsynchronizer_id\x18\x03 \x01(\tR\x0esynchronizerId\x12\x65\n\x18\x65xpected_topology_serial\x18\x04 \x01(\x0b\x32+.com.daml.ledger.api.v2.PriorTopologySerialR\x16\x65xpectedTopologySerial\x12\x87\x01\n\"update_vetted_packages_force_flags\x18\x05 \x03(\x0e\x32;.com.daml.ledger.api.v2.admin.UpdateVettedPackagesForceFlagR\x1eupdateVettedPackagesForceFlags\"\xd0\x01\n\x1cUpdateVettedPackagesResponse\x12X\n\x14past_vetted_packages\x18\x01 \x01(\x0b\x32&.com.daml.ledger.api.v2.VettedPackagesR\x12pastVettedPackages\x12V\n\x13new_vetted_packages\x18\x02 \x01(\x0b\x32&.com.daml.ledger.api.v2.VettedPackagesR\x11newVettedPackages*\xe2\x01\n\x1dUpdateVettedPackagesForceFlag\x12\x31\n-UPDATE_VETTED_PACKAGES_FORCE_FLAG_UNSPECIFIED\x10\x00\x12\x45\nAUPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_VET_INCOMPATIBLE_UPGRADES\x10\x02\x12\x41\n=UPDATE_VETTED_PACKAGES_FORCE_FLAG_ALLOW_UNVETTED_DEPENDENCIES\x10\x03\"\x04\x08\x01\x10\x01\x32\xab\x04\n\x18PackageManagementService\x12\x84\x01\n\x11ListKnownPackages\x12\x36.com.daml.ledger.api.v2.admin.ListKnownPackagesRequest\x1a\x37.com.daml.ledger.api.v2.admin.ListKnownPackagesResponse\x12x\n\rUploadDarFile\x12\x32.com.daml.ledger.api.v2.admin.UploadDarFileRequest\x1a\x33.com.daml.ledger.api.v2.admin.UploadDarFileResponse\x12~\n\x0fValidateDarFile\x12\x34.com.daml.ledger.api.v2.admin.ValidateDarFileRequest\x1a\x35.com.daml.ledger.api.v2.admin.ValidateDarFileResponse\x12\x8d\x01\n\x14UpdateVettedPackages\x12\x39.com.daml.ledger.api.v2.admin.UpdateVettedPackagesRequest\x1a:.com.daml.ledger.api.v2.admin.UpdateVettedPackagesResponseB\xae\x01\n\x1c\x63om.daml.ledger.api.v2.adminB\"PackageManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\xaa\x02\x1c\x43om.Daml.Ledger.Api.V2.Adminb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.admin.package_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\034com.daml.ledger.api.v2.adminB\"PackageManagementServiceOuterClassZKgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/admin\252\002\034Com.Daml.Ledger.Api.V2.Admin'
  _globals['_UPDATEVETTEDPACKAGESFORCEFLAG']._serialized_start=2355
  _globals['_UPDATEVETTEDPACKAGESFORCEFLAG']._serialized_end=2581
  _globals['_LISTKNOWNPACKAGESREQUEST']._serialized_start=176
  _globals['_LISTKNOWNPACKAGESREQUEST']._serialized_end=202
  _globals['_LISTKNOWNPACKAGESRESPONSE']._serialized_start=204
  _globals['_LISTKNOWNPACKAGESRESPONSE']._serialized_end=318
  _globals['_PACKAGEDETAILS']._serialized_start=321
  _globals['_PACKAGEDETAILS']._serialized_end=510
  _globals['_UPLOADDARFILEREQUEST']._serialized_start=513
  _globals['_UPLOADDARFILEREQUEST']._serialized_end=873
  _globals['_UPLOADDARFILEREQUEST_VETTINGCHANGE']._serialized_start=747
  _globals['_UPLOADDARFILEREQUEST_VETTINGCHANGE']._serialized_end=873
  _globals['_UPLOADDARFILERESPONSE']._serialized_start=875
  _globals['_UPLOADDARFILERESPONSE']._serialized_end=898
  _globals['_VALIDATEDARFILEREQUEST']._serialized_start=901
  _globals['_VALIDATEDARFILEREQUEST']._serialized_end=1030
  _globals['_VALIDATEDARFILERESPONSE']._serialized_start=1032
  _globals['_VALIDATEDARFILERESPONSE']._serialized_end=1057
  _globals['_VETTEDPACKAGESCHANGE']._serialized_start=1060
  _globals['_VETTEDPACKAGESCHANGE']._serialized_end=1596
  _globals['_VETTEDPACKAGESCHANGE_UNVET']._serialized_start=1242
  _globals['_VETTEDPACKAGESCHANGE_UNVET']._serialized_end=1326
  _globals['_VETTEDPACKAGESCHANGE_VET']._serialized_start=1329
  _globals['_VETTEDPACKAGESCHANGE_VET']._serialized_end=1583
  _globals['_VETTEDPACKAGESREF']._serialized_start=1598
  _globals['_VETTEDPACKAGESREF']._serialized_end=1724
  _globals['_UPDATEVETTEDPACKAGESREQUEST']._serialized_start=1727
  _globals['_UPDATEVETTEDPACKAGESREQUEST']._serialized_end=2141
  _globals['_UPDATEVETTEDPACKAGESRESPONSE']._serialized_start=2144
  _globals['_UPDATEVETTEDPACKAGESRESPONSE']._serialized_end=2352
  _globals['_PACKAGEMANAGEMENTSERVICE']._serialized_start=2584
  _globals['_PACKAGEMANAGEMENTSERVICE']._serialized_end=3139
# @@protoc_insertion_point(module_scope)
