# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from .... import value_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nScom/daml/ledger/api/v2/interactive/transaction/v1/interactive_submission_data.proto\x12\x31\x63om.daml.ledger.api.v2.interactive.transaction.v1\x1a\"com/daml/ledger/api/v2/value.proto\"\xe3\x02\n\x05\x46\x65tch\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12 \n\x0bsignatories\x18\x05 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x06 \x03(\tR\x0cstakeholders\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x45\n\x0cinterface_id\x18\x08 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\"\xf2\x04\n\x08\x45xercise\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12 \n\x0bsignatories\x18\x05 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x06 \x03(\tR\x0cstakeholders\x12%\n\x0e\x61\x63ting_parties\x18\x07 \x03(\tR\ractingParties\x12\x45\n\x0cinterface_id\x18\x08 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\x0binterfaceId\x12\x1b\n\tchoice_id\x18\t \x01(\tR\x08\x63hoiceId\x12@\n\x0c\x63hosen_value\x18\n \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0b\x63hosenValue\x12\x1c\n\tconsuming\x18\x0b \x01(\x08R\tconsuming\x12\x1a\n\x08\x63hildren\x18\x0c \x03(\tR\x08\x63hildren\x12\x46\n\x0f\x65xercise_result\x18\r \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x0e\x65xerciseResult\x12)\n\x10\x63hoice_observers\x18\x0e \x03(\tR\x0f\x63hoiceObservers\"\xb1\x02\n\x06\x43reate\x12\x1d\n\nlf_version\x18\x01 \x01(\tR\tlfVersion\x12\x1f\n\x0b\x63ontract_id\x18\x02 \x01(\tR\ncontractId\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\x12\x43\n\x0btemplate_id\x18\x04 \x01(\x0b\x32\".com.daml.ledger.api.v2.IdentifierR\ntemplateId\x12\x39\n\x08\x61rgument\x18\x05 \x01(\x0b\x32\x1d.com.daml.ledger.api.v2.ValueR\x08\x61rgument\x12 \n\x0bsignatories\x18\x06 \x03(\tR\x0bsignatories\x12\"\n\x0cstakeholders\x18\x07 \x03(\tR\x0cstakeholders\"&\n\x08Rollback\x12\x1a\n\x08\x63hildren\x18\x01 \x03(\tR\x08\x63hildren\"\xf0\x02\n\x04Node\x12S\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x39.com.daml.ledger.api.v2.interactive.transaction.v1.CreateH\x00R\x06\x63reate\x12P\n\x05\x66\x65tch\x18\x02 \x01(\x0b\x32\x38.com.daml.ledger.api.v2.interactive.transaction.v1.FetchH\x00R\x05\x66\x65tch\x12Y\n\x08\x65xercise\x18\x03 \x01(\x0b\x32;.com.daml.ledger.api.v2.interactive.transaction.v1.ExerciseH\x00R\x08\x65xercise\x12Y\n\x08rollback\x18\x04 \x01(\x0b\x32;.com.daml.ledger.api.v2.interactive.transaction.v1.RollbackH\x00R\x08rollbackB\x0b\n\tnode_typeB\xee\x01\n1com.daml.ledger.api.v2.interactive.transaction.v1B#InteractiveSubmissionDataOuterClassZ`github.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive/transaction/v1\xaa\x02\x31\x43om.Daml.Ledger.Api.V2.Interactive.Transaction.V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.interactive.transaction.v1.interactive_submission_data_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n1com.daml.ledger.api.v2.interactive.transaction.v1B#InteractiveSubmissionDataOuterClassZ`github.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2/interactive/transaction/v1\252\0021Com.Daml.Ledger.Api.V2.Interactive.Transaction.V1'
  _globals['_FETCH']._serialized_start=175
  _globals['_FETCH']._serialized_end=530
  _globals['_EXERCISE']._serialized_start=533
  _globals['_EXERCISE']._serialized_end=1159
  _globals['_CREATE']._serialized_start=1162
  _globals['_CREATE']._serialized_end=1467
  _globals['_ROLLBACK']._serialized_start=1469
  _globals['_ROLLBACK']._serialized_end=1507
  _globals['_NODE']._serialized_start=1510
  _globals['_NODE']._serialized_end=1878
# @@protoc_insertion_point(module_scope)
