# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...health.v30 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_health_dot_v30_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJcom/digitalasset/canton/admin/sequencer/v30/sequencer_status_service.proto\x12+com.digitalasset.canton.admin.sequencer.v30\x1a=com/digitalasset/canton/admin/health/v30/status_service.proto\"\x18\n\x16SequencerStatusRequest\"\x8b\x08\n\x17SequencerStatusResponse\x12|\n\x06status\x18\x01 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.SequencerStatusResponseStatusH\x00R\x06status\x12\x63\n\x0fnot_initialized\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.health.v30.NotInitializedH\x00R\x0enotInitialized\x1a(\n\x14\x43onnectedParticipant\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x1a%\n\x11\x43onnectedMediator\x12\x10\n\x03uid\x18\x01 \x01(\tR\x03uid\x1a\xb3\x05\n\x1dSequencerStatusResponseStatus\x12U\n\rcommon_status\x18\x01 \x01(\x0b\x32\x30.com.digitalasset.canton.admin.health.v30.StatusR\x0c\x63ommonStatus\x12\x90\x01\n\x16\x63onnected_participants\x18\x02 \x03(\x0b\x32Y.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.ConnectedParticipantR\x15\x63onnectedParticipants\x12\x87\x01\n\x13\x63onnected_mediators\x18\x03 \x03(\x0b\x32V.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponse.ConnectedMediatorR\x12\x63onnectedMediators\x12`\n\tsequencer\x18\x04 \x01(\x0b\x32\x42.com.digitalasset.canton.admin.sequencer.v30.SequencerHealthStatusR\tsequencer\x12\x38\n\x18physical_synchronizer_id\x18\x05 \x01(\tR\x16physicalSynchronizerId\x12W\n\x05\x61\x64min\x18\x06 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.sequencer.v30.SequencerAdminStatusR\x05\x61\x64min\x12)\n\x10protocol_version\x18\x07 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind\"Z\n\x15SequencerHealthStatus\x12\x16\n\x06\x61\x63tive\x18\x01 \x01(\x08R\x06\x61\x63tive\x12\x1d\n\x07\x64\x65tails\x18\x02 \x01(\tH\x00R\x07\x64\x65tails\x88\x01\x01\x42\n\n\x08_details\"J\n\x14SequencerAdminStatus\x12\x32\n\x15\x61\x63\x63\x65pts_admin_changes\x18\x01 \x01(\x08R\x13\x61\x63\x63\x65ptsAdminChanges2\xb7\x01\n\x16SequencerStatusService\x12\x9c\x01\n\x0fSequencerStatus\x12\x43.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusRequest\x1a\x44.com.digitalasset.canton.admin.sequencer.v30.SequencerStatusResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.sequencer.v30.sequencer_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/sequencer/v30'
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_start=186
  _globals['_SEQUENCERSTATUSREQUEST']._serialized_end=210
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_start=213
  _globals['_SEQUENCERSTATUSRESPONSE']._serialized_end=1248
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDPARTICIPANT']._serialized_start=467
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDPARTICIPANT']._serialized_end=507
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDMEDIATOR']._serialized_start=509
  _globals['_SEQUENCERSTATUSRESPONSE_CONNECTEDMEDIATOR']._serialized_end=546
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_start=549
  _globals['_SEQUENCERSTATUSRESPONSE_SEQUENCERSTATUSRESPONSESTATUS']._serialized_end=1240
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_start=1250
  _globals['_SEQUENCERHEALTHSTATUS']._serialized_end=1340
  _globals['_SEQUENCERADMINSTATUS']._serialized_start=1342
  _globals['_SEQUENCERADMINSTATUS']._serialized_end=1416
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_start=1419
  _globals['_SEQUENCERSTATUSSERVICE']._serialized_end=1602
# @@protoc_insertion_point(module_scope)
