# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/initialization_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/initialization_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nGcom/digitalasset/canton/topology/admin/v30/initialization_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\"\xc3\x01\n\rInitIdRequest\x12\x1e\n\nidentifier\x18\x01 \x01(\tR\nidentifier\x12\x1c\n\tnamespace\x18\x02 \x01(\tR\tnamespace\x12t\n\x15namespace_delegations\x18\x03 \x03(\x0b\x32?.com.digitalasset.canton.protocol.v30.SignedTopologyTransactionR\x14namespaceDelegations\"\x10\n\x0eInitIdResponse\"^\n\rGetIdResponse\x12 \n\x0binitialized\x18\x01 \x01(\x08R\x0binitialized\x12+\n\x11unique_identifier\x18\x02 \x01(\tR\x10uniqueIdentifier\"\"\n GetOnboardingTransactionsRequest\"\x89\x01\n!GetOnboardingTransactionsResponse\x12\x64\n\x0ctransactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x0ctransactions\"\x0e\n\x0cGetIdRequest\"\x14\n\x12\x43urrentTimeRequest\"8\n\x13\x43urrentTimeResponse\x12!\n\x0c\x63urrent_time\x18\x01 \x01(\x03R\x0b\x63urrentTime2\xaf\x03\n\x1dIdentityInitializationService\x12\x7f\n\x06InitId\x12\x39.com.digitalasset.canton.topology.admin.v30.InitIdRequest\x1a:.com.digitalasset.canton.topology.admin.v30.InitIdResponse\x12|\n\x05GetId\x12\x38.com.digitalasset.canton.topology.admin.v30.GetIdRequest\x1a\x39.com.digitalasset.canton.topology.admin.v30.GetIdResponse\x12\x8e\x01\n\x0b\x43urrentTime\x12>.com.digitalasset.canton.topology.admin.v30.CurrentTimeRequest\x1a?.com.digitalasset.canton.topology.admin.v30.CurrentTimeResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.initialization_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_INITIDREQUEST']._serialized_start=230
  _globals['_INITIDREQUEST']._serialized_end=425
  _globals['_INITIDRESPONSE']._serialized_start=427
  _globals['_INITIDRESPONSE']._serialized_end=443
  _globals['_GETIDRESPONSE']._serialized_start=445
  _globals['_GETIDRESPONSE']._serialized_end=539
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_start=541
  _globals['_GETONBOARDINGTRANSACTIONSREQUEST']._serialized_end=575
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_start=578
  _globals['_GETONBOARDINGTRANSACTIONSRESPONSE']._serialized_end=715
  _globals['_GETIDREQUEST']._serialized_start=717
  _globals['_GETIDREQUEST']._serialized_end=731
  _globals['_CURRENTTIMEREQUEST']._serialized_start=733
  _globals['_CURRENTTIMEREQUEST']._serialized_end=753
  _globals['_CURRENTTIMERESPONSE']._serialized_start=755
  _globals['_CURRENTTIMERESPONSE']._serialized_end=811
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_start=814
  _globals['_IDENTITYINITIALIZATIONSERVICE']._serialized_end=1245
# @@protoc_insertion_point(module_scope)
