# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/participant_reassignment.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/participant_reassignment.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...crypto.v30 import crypto_pb2 as com_dot_digitalasset_dot_canton_dot_crypto_dot_v30_dot_crypto__pb2
from . import common_stable_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_common__stable__pb2
from . import merkle_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_merkle__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/protocol/v30/participant_reassignment.proto\x12$com.digitalasset.canton.protocol.v30\x1a/com/digitalasset/canton/crypto/v30/crypto.proto\x1a\x38\x63om/digitalasset/canton/protocol/v30/common_stable.proto\x1a\x31\x63om/digitalasset/canton/protocol/v30/merkle.proto\x1a\x1fgoogle/protobuf/timestamp.proto\" \n\x0eReassignmentId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xf3\x03\n\x16UnassignmentCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x02 \x01(\tR\x1csourcePhysicalSynchronizerId\x12V\n\x0cstakeholders\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.StakeholdersR\x0cstakeholders\x12@\n\x1creassigning_participant_uids\x18\x04 \x03(\tR\x1areassigningParticipantUids\x12\x12\n\x04uuid\x18\x05 \x01(\tR\x04uuid\x12\x32\n\x15source_mediator_group\x18\x06 \x01(\x05R\x13sourceMediatorGroup\x12r\n\x12submitter_metadata\x18\x07 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\"\x97\x01\n\x14ReassignmentViewTree\x12\x1f\n\x0b\x63ommon_data\x18\x01 \x01(\x0cR\ncommonData\x12^\n\x10participant_data\x18\x02 \x01(\x0b\x32\x33.com.digitalasset.canton.protocol.v30.BlindableNodeR\x0fparticipantData\"\xe4\x01\n\x19\x41ssignmentMediatorMessage\x12N\n\x04tree\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.ReassignmentViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xe6\x01\n\x1bUnassignmentMediatorMessage\x12N\n\x04tree\x18\x01 \x01(\x0b\x32:.com.digitalasset.canton.protocol.v30.ReassignmentViewTreeR\x04tree\x12w\n submitting_participant_signature\x18\x02 \x01(\x0b\x32-.com.digitalasset.canton.crypto.v30.SignatureR\x1esubmittingParticipantSignature\"\xfd\x04\n\x14\x41ssignmentCommonData\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x08 \x01(\tR\x1csourcePhysicalSynchronizerId\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x02 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12\x43\n\x0funassignment_ts\x18\t \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0eunassignmentTs\x12V\n\x0cstakeholders\x18\x03 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.StakeholdersR\x0cstakeholders\x12\x12\n\x04uuid\x18\x04 \x01(\tR\x04uuid\x12\x32\n\x15target_mediator_group\x18\x05 \x01(\x05R\x13targetMediatorGroup\x12r\n\x12submitter_metadata\x18\x06 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\x12@\n\x1creassigning_participant_uids\x18\x07 \x03(\tR\x1areassigningParticipantUids\"\xf9\x01\n\x1dReassignmentSubmitterMetadata\x12\x1c\n\tsubmitter\x18\x01 \x01(\tR\tsubmitter\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12#\n\rsubmission_id\x18\x04 \x01(\tR\x0csubmissionId\x12\x17\n\x07user_id\x18\x05 \x01(\tR\x06userId\x12\x1f\n\x0bworkflow_id\x18\x06 \x01(\tR\nworkflowId\"\x96\x02\n\x10UnassignmentView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x02 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12)\n\x10target_timestamp\x18\x03 \x01(\x03R\x0ftargetTimestamp\x12R\n\tcontracts\x18\x04 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\"\xb6\x04\n\x10UnassignmentData\x12r\n\x12submitter_metadata\x18\x01 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ReassignmentSubmitterMetadataR\x11submitterMetadata\x12R\n\tcontracts\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\x12@\n\x1creassigning_participant_uids\x18\x03 \x03(\tR\x1areassigningParticipantUids\x12\x45\n\x1fsource_physical_synchronizer_id\x18\x04 \x01(\tR\x1csourcePhysicalSynchronizerId\x12\x45\n\x1ftarget_physical_synchronizer_id\x18\x05 \x01(\tR\x1ctargetPhysicalSynchronizerId\x12\x45\n\x10target_timestamp\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0ftargetTimestamp\x12\x43\n\x0funassignment_ts\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0eunassignmentTs\"\x81\x02\n\x0e\x41ssignmentView\x12<\n\x04salt\x18\x01 \x01(\x0b\x32(.com.digitalasset.canton.crypto.v30.SaltR\x04salt\x12R\n\tcontracts\x18\x02 \x03(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ActiveContractR\tcontracts\x12]\n\x0freassignment_id\x18\x03 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.ReassignmentIdR\x0ereassignmentId\"_\n\x0e\x41\x63tiveContract\x12\x1a\n\x08\x63ontract\x18\x01 \x01(\x0cR\x08\x63ontract\x12\x31\n\x14reassignment_counter\x18\x02 \x01(\x03R\x13reassignmentCounterBUZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.participant_reassignment_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_REASSIGNMENTID']._serialized_start=300
  _globals['_REASSIGNMENTID']._serialized_end=332
  _globals['_UNASSIGNMENTCOMMONDATA']._serialized_start=335
  _globals['_UNASSIGNMENTCOMMONDATA']._serialized_end=834
  _globals['_REASSIGNMENTVIEWTREE']._serialized_start=837
  _globals['_REASSIGNMENTVIEWTREE']._serialized_end=988
  _globals['_ASSIGNMENTMEDIATORMESSAGE']._serialized_start=991
  _globals['_ASSIGNMENTMEDIATORMESSAGE']._serialized_end=1219
  _globals['_UNASSIGNMENTMEDIATORMESSAGE']._serialized_start=1222
  _globals['_UNASSIGNMENTMEDIATORMESSAGE']._serialized_end=1452
  _globals['_ASSIGNMENTCOMMONDATA']._serialized_start=1455
  _globals['_ASSIGNMENTCOMMONDATA']._serialized_end=2092
  _globals['_REASSIGNMENTSUBMITTERMETADATA']._serialized_start=2095
  _globals['_REASSIGNMENTSUBMITTERMETADATA']._serialized_end=2344
  _globals['_UNASSIGNMENTVIEW']._serialized_start=2347
  _globals['_UNASSIGNMENTVIEW']._serialized_end=2625
  _globals['_UNASSIGNMENTDATA']._serialized_start=2628
  _globals['_UNASSIGNMENTDATA']._serialized_end=3194
  _globals['_ASSIGNMENTVIEW']._serialized_start=3197
  _globals['_ASSIGNMENTVIEW']._serialized_end=3454
  _globals['_ACTIVECONTRACT']._serialized_start=3456
  _globals['_ACTIVECONTRACT']._serialized_end=3551
# @@protoc_insertion_point(module_scope)
