# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/participant/protocol/v30/submission_tracking.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import participant_transaction_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_participant__transaction__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nJcom/digitalasset/canton/participant/protocol/v30/submission_tracking.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/participant_transaction.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xf9\x01\n\x0e\x43ompletionInfo\x12\x15\n\x06\x61\x63t_as\x18\x01 \x03(\tR\x05\x61\x63tAs\x12\x17\n\x07user_id\x18\x02 \x01(\tR\x06userId\x12\x1d\n\ncommand_id\x18\x03 \x01(\tR\tcommandId\x12s\n\x18opt_deduplication_period\x18\x04 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.DeduplicationPeriodR\x16optDeduplicationPeriod\x12#\n\rsubmission_id\x18\x05 \x01(\tR\x0csubmissionId\"H\n\x0f\x43ommandRejected\x1a\x35\n\x1bGrpcRejectionReasonTemplate\x12\x16\n\x06status\x18\x01 \x01(\x0cR\x06status\"\x9d\x01\n\x16SubmissionTrackingData\x12w\n\x0btransaction\x18\x01 \x01(\x0b\x32S.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingDataH\x00R\x0btransactionB\n\n\x08tracking\"\xc4\x04\n!TransactionSubmissionTrackingData\x12i\n\x0f\x63ompletion_info\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.participant.protocol.v30.CompletionInfoR\x0e\x63ompletionInfo\x12\x8b\x01\n\x0frejection_cause\x18\x02 \x01(\x0b\x32\x62.com.digitalasset.canton.participant.protocol.v30.TransactionSubmissionTrackingData.RejectionCauseR\x0erejectionCause\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x1a\xeb\x01\n\x0eRejectionCause\x12\x32\n\x07timeout\x18\x01 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\x07timeout\x12\x9b\x01\n\x19rejection_reason_template\x18\x02 \x01(\x0b\x32].com.digitalasset.canton.participant.protocol.v30.CommandRejected.GrpcRejectionReasonTemplateH\x00R\x17rejectionReasonTemplateB\x07\n\x05\x63\x61useBaZ_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.submission_tracking_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_COMPLETIONINFO']._serialized_start=226
  _globals['_COMPLETIONINFO']._serialized_end=475
  _globals['_COMMANDREJECTED']._serialized_start=477
  _globals['_COMMANDREJECTED']._serialized_end=549
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_start=496
  _globals['_COMMANDREJECTED_GRPCREJECTIONREASONTEMPLATE']._serialized_end=549
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_start=552
  _globals['_SUBMISSIONTRACKINGDATA']._serialized_end=709
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_start=712
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA']._serialized_end=1292
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_start=1057
  _globals['_TRANSACTIONSUBMISSIONTRACKINGDATA_REJECTIONCAUSE']._serialized_end=1292
# @@protoc_insertion_point(module_scope)
