# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/command_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/command_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_commands__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import reassignment_commands_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__commands__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,com/daml/ledger/api/v2/command_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a%com/daml/ledger/api/v2/commands.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a\x32\x63om/daml/ledger/api/v2/reassignment_commands.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"T\n\x14SubmitAndWaitRequest\x12<\n\x08\x63ommands\x18\x01 \x01(\x0b\x32 .com.daml.ledger.api.v2.CommandsR\x08\x63ommands\"\xbc\x01\n\"SubmitAndWaitForTransactionRequest\x12<\n\x08\x63ommands\x18\x01 \x01(\x0b\x32 .com.daml.ledger.api.v2.CommandsR\x08\x63ommands\x12X\n\x12transaction_format\x18\x02 \x01(\x0b\x32).com.daml.ledger.api.v2.TransactionFormatR\x11transactionFormat\"a\n\x15SubmitAndWaitResponse\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12+\n\x11\x63ompletion_offset\x18\x02 \x01(\x03R\x10\x63ompletionOffset\"l\n#SubmitAndWaitForTransactionResponse\x12\x45\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionR\x0btransaction\"\xd0\x01\n#SubmitAndWaitForReassignmentRequest\x12\x61\n\x15reassignment_commands\x18\x01 \x01(\x0b\x32,.com.daml.ledger.api.v2.ReassignmentCommandsR\x14reassignmentCommands\x12\x46\n\x0c\x65vent_format\x18\x02 \x01(\x0b\x32#.com.daml.ledger.api.v2.EventFormatR\x0b\x65ventFormat\"p\n$SubmitAndWaitForReassignmentResponse\x12H\n\x0creassignment\x18\x01 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentR\x0creassignment2\xb3\x03\n\x0e\x43ommandService\x12l\n\rSubmitAndWait\x12,.com.daml.ledger.api.v2.SubmitAndWaitRequest\x1a-.com.daml.ledger.api.v2.SubmitAndWaitResponse\x12\x96\x01\n\x1bSubmitAndWaitForTransaction\x12:.com.daml.ledger.api.v2.SubmitAndWaitForTransactionRequest\x1a;.com.daml.ledger.api.v2.SubmitAndWaitForTransactionResponse\x12\x99\x01\n\x1cSubmitAndWaitForReassignment\x12;.com.daml.ledger.api.v2.SubmitAndWaitForReassignmentRequest\x1a<.com.daml.ledger.api.v2.SubmitAndWaitForReassignmentResponseB\x92\x01\n\x16\x63om.daml.ledger.api.v2B\x18\x43ommandServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.command_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\030CommandServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SUBMITANDWAITREQUEST']._serialized_start=297
  _globals['_SUBMITANDWAITREQUEST']._serialized_end=381
  _globals['_SUBMITANDWAITFORTRANSACTIONREQUEST']._serialized_start=384
  _globals['_SUBMITANDWAITFORTRANSACTIONREQUEST']._serialized_end=572
  _globals['_SUBMITANDWAITRESPONSE']._serialized_start=574
  _globals['_SUBMITANDWAITRESPONSE']._serialized_end=671
  _globals['_SUBMITANDWAITFORTRANSACTIONRESPONSE']._serialized_start=673
  _globals['_SUBMITANDWAITFORTRANSACTIONRESPONSE']._serialized_end=781
  _globals['_SUBMITANDWAITFORREASSIGNMENTREQUEST']._serialized_start=784
  _globals['_SUBMITANDWAITFORREASSIGNMENTREQUEST']._serialized_end=992
  _globals['_SUBMITANDWAITFORREASSIGNMENTRESPONSE']._serialized_start=994
  _globals['_SUBMITANDWAITFORREASSIGNMENTRESPONSE']._serialized_end=1106
  _globals['_COMMANDSERVICE']._serialized_start=1109
  _globals['_COMMANDSERVICE']._serialized_end=1544
# @@protoc_insertion_point(module_scope)
