# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nRcom/digitalasset/canton/admin/participant/v30/participant_inspection_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"U\n\x19LookupOffsetByTimeRequest\x12\x38\n\ttimestamp\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\"D\n\x1aLookupOffsetByTimeResponse\x12\x1b\n\x06offset\x18\x01 \x01(\x03H\x00R\x06offset\x88\x01\x01\x42\t\n\x07_offset\"\x85\x02\n\x15OpenCommitmentRequest\x12\x1e\n\ncommitment\x18\x01 \x01(\x0cR\ncommitment\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\x12N\n$computed_for_counter_participant_uid\x18\x03 \x01(\tR computedForCounterParticipantUid\x12\x42\n\x0fperiod_end_tick\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rperiodEndTick\".\n\x16OpenCommitmentResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"]\n\x16\x43ommitmentContractMeta\x12\x10\n\x03\x63id\x18\x01 \x01(\x0cR\x03\x63id\x12\x31\n\x14reassignment_counter\x18\x02 \x01(\x03R\x13reassignmentCounter\"\xd6\x01\n!InspectCommitmentContractsRequest\x12\x12\n\x04\x63ids\x18\x01 \x03(\x0cR\x04\x63ids\x12\x38\n\x18\x65xpected_synchronizer_id\x18\x02 \x01(\tR\x16\x65xpectedSynchronizerId\x12\x38\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12)\n\x10\x64ownload_payload\x18\x04 \x01(\x08R\x0f\x64ownloadPayload\":\n\"InspectCommitmentContractsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\x83\x02\n\x12\x43ommitmentContract\x12\x10\n\x03\x63id\x18\x01 \x01(\x0cR\x03\x63id\x12\x45\n\x1f\x61\x63tive_on_expected_synchronizer\x18\x02 \x01(\x08R\x1c\x61\x63tiveOnExpectedSynchronizer\x12\x1f\n\x08\x63ontract\x18\x03 \x01(\x0cH\x00R\x08\x63ontract\x88\x01\x01\x12\x66\n\x06states\x18\x04 \x03(\x0b\x32N.com.digitalasset.canton.admin.participant.v30.ContractState.SynchronizerStateR\x06statesB\x0b\n\t_contract\"\xcc\x08\n\rContractState\x1a\xbe\x04\n\x11SynchronizerState\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12`\n\x07\x63reated\x18\x02 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ContractState.CreatedH\x00R\x07\x63reated\x12\x63\n\x08\x61rchived\x18\x03 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.ContractState.ArchivedH\x00R\x08\x61rchived\x12i\n\nunassigned\x18\x04 \x01(\x0b\x32G.com.digitalasset.canton.admin.participant.v30.ContractState.UnassignedH\x00R\nunassigned\x12\x63\n\x08\x61ssigned\x18\x05 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.ContractState.AssignedH\x00R\x08\x61ssigned\x12`\n\x07unknown\x18\x06 \x01(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ContractState.UnknownH\x00R\x07unknownB\x07\n\x05state\x1a\t\n\x07\x43reated\x1a\xc0\x01\n\x08\x41ssigned\x12>\n\x1breassignment_counter_target\x18\x01 \x01(\x03R\x19reassignmentCounterTarget\x12t\n\x0freassignment_id\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.ContractState.ReassignmentIdR\x0ereassignmentId\x1a\n\n\x08\x41rchived\x1a\xf2\x01\n\nUnassigned\x12\x34\n\x16target_synchronizer_id\x18\x01 \x01(\tR\x14targetSynchronizerId\x12\x38\n\x18reassignment_counter_src\x18\x02 \x01(\x03R\x16reassignmentCounterSrc\x12t\n\x0freassignment_id\x18\x03 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.ContractState.ReassignmentIdR\x0ereassignmentId\x1a\t\n\x07Unknown\x1a \n\x0eReassignmentId\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\xd1\x02\n#LookupReceivedAcsCommitmentsRequest\x12\x65\n\x0btime_ranges\x18\x01 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.SynchronizerTimeRangeR\ntimeRanges\x12\x36\n\x17\x63ounter_participant_ids\x18\x02 \x03(\tR\x15\x63ounterParticipantIds\x12q\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\"\x97\x01\n$LookupReceivedAcsCommitmentsResponse\x12o\n\x08received\x18\x01 \x03(\x0b\x32S.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentPerSynchronizerR\x08received\"\x8d\x01\n\tTimeRange\x12\x41\n\x0e\x66rom_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\rfromExclusive\x12=\n\x0cto_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0btoInclusive\"\xa8\x01\n\x15SynchronizerTimeRange\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12Y\n\x08interval\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.participant.v30.TimeRangeH\x00R\x08interval\x88\x01\x01\x42\x0b\n\t_interval\"\xa2\x01\n\x08Interval\x12L\n\x14start_tick_exclusive\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x12startTickExclusive\x12H\n\x12\x65nd_tick_inclusive\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x65ndTickInclusive\"\x9c\x03\n\x15ReceivedAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12\x43\n\x1eorigin_counter_participant_uid\x18\x02 \x01(\tR\x1boriginCounterParticipantUid\x12\x34\n\x13received_commitment\x18\x03 \x01(\x0cH\x00R\x12receivedCommitment\x88\x01\x01\x12*\n\x0eown_commitment\x18\x04 \x01(\x0cH\x01R\rownCommitment\x88\x01\x01\x12\\\n\x05state\x18\x05 \x01(\x0e\x32\x46.com.digitalasset.canton.admin.participant.v30.ReceivedCommitmentStateR\x05stateB\x16\n\x14_received_commitmentB\x11\n\x0f_own_commitment\"\xb1\x01\n$ReceivedAcsCommitmentPerSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12`\n\x08received\x18\x02 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.ReceivedAcsCommitmentR\x08received\"\x90\x03\n\x11SentAcsCommitment\x12S\n\x08interval\x18\x01 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.IntervalR\x08interval\x12?\n\x1c\x64\x65st_counter_participant_uid\x18\x02 \x01(\tR\x19\x64\x65stCounterParticipantUid\x12*\n\x0eown_commitment\x18\x03 \x01(\x0cH\x00R\rownCommitment\x88\x01\x01\x12\x34\n\x13received_commitment\x18\x04 \x01(\x0cH\x01R\x12receivedCommitment\x88\x01\x01\x12X\n\x05state\x18\x05 \x01(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x05stateB\x11\n\x0f_own_commitmentB\x16\n\x14_received_commitment\"\xa1\x01\n SentAcsCommitmentPerSynchronizer\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12T\n\x04sent\x18\x02 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentR\x04sent\"\xc9\x02\n\x1fLookupSentAcsCommitmentsRequest\x12\x65\n\x0btime_ranges\x18\x01 \x03(\x0b\x32\x44.com.digitalasset.canton.admin.participant.v30.SynchronizerTimeRangeR\ntimeRanges\x12\x36\n\x17\x63ounter_participant_ids\x18\x02 \x03(\tR\x15\x63ounterParticipantIds\x12m\n\x10\x63ommitment_state\x18\x03 \x03(\x0e\x32\x42.com.digitalasset.canton.admin.participant.v30.SentCommitmentStateR\x0f\x63ommitmentState\x12\x18\n\x07verbose\x18\x04 \x01(\x08R\x07verbose\"\x87\x01\n LookupSentAcsCommitmentsResponse\x12\x63\n\x04sent\x18\x01 \x03(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.SentAcsCommitmentPerSynchronizerR\x04sent\"\xbb\x02\n(SlowCounterParticipantSynchronizerConfig\x12)\n\x10synchronizer_ids\x18\x01 \x03(\tR\x0fsynchronizerIds\x12\x44\n\x1e\x64istinguished_participant_uids\x18\x02 \x03(\tR\x1c\x64istinguishedParticipantUids\x12\x37\n\x17threshold_distinguished\x18\x03 \x01(\x04R\x16thresholdDistinguished\x12+\n\x11threshold_default\x18\x04 \x01(\x04R\x10thresholdDefault\x12\x38\n\x18participant_uids_metrics\x18\x05 \x03(\tR\x16participantUidsMetrics\"\x9f\x01\n*SetConfigForSlowCounterParticipantsRequest\x12q\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantSynchronizerConfigR\x07\x63onfigs\"-\n+SetConfigForSlowCounterParticipantsResponse\"W\n*GetConfigForSlowCounterParticipantsRequest\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\"\xa0\x01\n+GetConfigForSlowCounterParticipantsResponse\x12q\n\x07\x63onfigs\x18\x01 \x03(\x0b\x32W.com.digitalasset.canton.admin.participant.v30.SlowCounterParticipantSynchronizerConfigR\x07\x63onfigs\"\xbb\x02\n\x16\x43ounterParticipantInfo\x12\x36\n\x17\x63ounter_participant_uid\x18\x01 \x01(\tR\x15\x63ounterParticipantUid\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12)\n\x10intervals_behind\x18\x03 \x01(\x04R\x0fintervalsBehind\x12<\n\x0c\x62\x65hind_since\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x0b\x62\x65hindSince\x12W\n\x1a\x61s_of_sequencing_timestamp\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x17\x61sOfSequencingTimestamp\"\xc5\x01\n/GetIntervalsBehindForCounterParticipantsRequest\x12\x36\n\x17\x63ounter_participant_ids\x18\x01 \x03(\tR\x15\x63ounterParticipantIds\x12)\n\x10synchronizer_ids\x18\x02 \x03(\tR\x0fsynchronizerIds\x12!\n\tthreshold\x18\x03 \x01(\x04H\x00R\tthreshold\x88\x01\x01\x42\x0c\n\n_threshold\"\xa4\x01\n0GetIntervalsBehindForCounterParticipantsResponse\x12p\n\x10intervals_behind\x18\x01 \x03(\x0b\x32\x45.com.digitalasset.canton.admin.participant.v30.CounterParticipantInfoR\x0fintervalsBehind\"?\n\x14\x43ountInFlightRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\"{\n\x15\x43ountInFlightResponse\x12/\n\x13pending_submissions\x18\x01 \x01(\rR\x12pendingSubmissions\x12\x31\n\x14pending_transactions\x18\x02 \x01(\rR\x13pendingTransactions*\xe4\x01\n\x17ReceivedCommitmentState\x12)\n%RECEIVED_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12#\n\x1fRECEIVED_COMMITMENT_STATE_MATCH\x10\x01\x12&\n\"RECEIVED_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"RECEIVED_COMMITMENT_STATE_BUFFERED\x10\x03\x12)\n%RECEIVED_COMMITMENT_STATE_OUTSTANDING\x10\x04*\xa9\x01\n\x13SentCommitmentState\x12%\n!SENT_COMMITMENT_STATE_UNSPECIFIED\x10\x00\x12\x1f\n\x1bSENT_COMMITMENT_STATE_MATCH\x10\x01\x12\"\n\x1eSENT_COMMITMENT_STATE_MISMATCH\x10\x02\x12&\n\"SENT_COMMITMENT_STATE_NOT_COMPARED\x10\x03\x32\x83\x0e\n\x1cParticipantInspectionService\x12\xa9\x01\n\x12LookupOffsetByTime\x12H.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTimeRequest\x1aI.com.digitalasset.canton.admin.participant.v30.LookupOffsetByTimeResponse\x12\x9f\x01\n\x0eOpenCommitment\x12\x44.com.digitalasset.canton.admin.participant.v30.OpenCommitmentRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.OpenCommitmentResponse0\x01\x12\xc3\x01\n\x1aInspectCommitmentContracts\x12P.com.digitalasset.canton.admin.participant.v30.InspectCommitmentContractsRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.InspectCommitmentContractsResponse0\x01\x12\xbb\x01\n\x18LookupSentAcsCommitments\x12N.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitmentsRequest\x1aO.com.digitalasset.canton.admin.participant.v30.LookupSentAcsCommitmentsResponse\x12\xc7\x01\n\x1cLookupReceivedAcsCommitments\x12R.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitmentsRequest\x1aS.com.digitalasset.canton.admin.participant.v30.LookupReceivedAcsCommitmentsResponse\x12\xdc\x01\n#SetConfigForSlowCounterParticipants\x12Y.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipantsRequest\x1aZ.com.digitalasset.canton.admin.participant.v30.SetConfigForSlowCounterParticipantsResponse\x12\xdc\x01\n#GetConfigForSlowCounterParticipants\x12Y.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipantsRequest\x1aZ.com.digitalasset.canton.admin.participant.v30.GetConfigForSlowCounterParticipantsResponse\x12\xeb\x01\n(GetIntervalsBehindForCounterParticipants\x12^.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipantsRequest\x1a_.com.digitalasset.canton.admin.participant.v30.GetIntervalsBehindForCounterParticipantsResponse\x12\x9a\x01\n\rCountInFlight\x12\x43.com.digitalasset.canton.admin.participant.v30.CountInFlightRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.CountInFlightResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.participant_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_start=6665
  _globals['_RECEIVEDCOMMITMENTSTATE']._serialized_end=6893
  _globals['_SENTCOMMITMENTSTATE']._serialized_start=6896
  _globals['_SENTCOMMITMENTSTATE']._serialized_end=7065
  _globals['_LOOKUPOFFSETBYTIMEREQUEST']._serialized_start=198
  _globals['_LOOKUPOFFSETBYTIMEREQUEST']._serialized_end=283
  _globals['_LOOKUPOFFSETBYTIMERESPONSE']._serialized_start=285
  _globals['_LOOKUPOFFSETBYTIMERESPONSE']._serialized_end=353
  _globals['_OPENCOMMITMENTREQUEST']._serialized_start=356
  _globals['_OPENCOMMITMENTREQUEST']._serialized_end=617
  _globals['_OPENCOMMITMENTRESPONSE']._serialized_start=619
  _globals['_OPENCOMMITMENTRESPONSE']._serialized_end=665
  _globals['_COMMITMENTCONTRACTMETA']._serialized_start=667
  _globals['_COMMITMENTCONTRACTMETA']._serialized_end=760
  _globals['_INSPECTCOMMITMENTCONTRACTSREQUEST']._serialized_start=763
  _globals['_INSPECTCOMMITMENTCONTRACTSREQUEST']._serialized_end=977
  _globals['_INSPECTCOMMITMENTCONTRACTSRESPONSE']._serialized_start=979
  _globals['_INSPECTCOMMITMENTCONTRACTSRESPONSE']._serialized_end=1037
  _globals['_COMMITMENTCONTRACT']._serialized_start=1040
  _globals['_COMMITMENTCONTRACT']._serialized_end=1299
  _globals['_CONTRACTSTATE']._serialized_start=1302
  _globals['_CONTRACTSTATE']._serialized_end=2402
  _globals['_CONTRACTSTATE_SYNCHRONIZERSTATE']._serialized_start=1320
  _globals['_CONTRACTSTATE_SYNCHRONIZERSTATE']._serialized_end=1894
  _globals['_CONTRACTSTATE_CREATED']._serialized_start=1896
  _globals['_CONTRACTSTATE_CREATED']._serialized_end=1905
  _globals['_CONTRACTSTATE_ASSIGNED']._serialized_start=1908
  _globals['_CONTRACTSTATE_ASSIGNED']._serialized_end=2100
  _globals['_CONTRACTSTATE_ARCHIVED']._serialized_start=2102
  _globals['_CONTRACTSTATE_ARCHIVED']._serialized_end=2112
  _globals['_CONTRACTSTATE_UNASSIGNED']._serialized_start=2115
  _globals['_CONTRACTSTATE_UNASSIGNED']._serialized_end=2357
  _globals['_CONTRACTSTATE_UNKNOWN']._serialized_start=2359
  _globals['_CONTRACTSTATE_UNKNOWN']._serialized_end=2368
  _globals['_CONTRACTSTATE_REASSIGNMENTID']._serialized_start=2370
  _globals['_CONTRACTSTATE_REASSIGNMENTID']._serialized_end=2402
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSREQUEST']._serialized_start=2405
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSREQUEST']._serialized_end=2742
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSRESPONSE']._serialized_start=2745
  _globals['_LOOKUPRECEIVEDACSCOMMITMENTSRESPONSE']._serialized_end=2896
  _globals['_TIMERANGE']._serialized_start=2899
  _globals['_TIMERANGE']._serialized_end=3040
  _globals['_SYNCHRONIZERTIMERANGE']._serialized_start=3043
  _globals['_SYNCHRONIZERTIMERANGE']._serialized_end=3211
  _globals['_INTERVAL']._serialized_start=3214
  _globals['_INTERVAL']._serialized_end=3376
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_start=3379
  _globals['_RECEIVEDACSCOMMITMENT']._serialized_end=3791
  _globals['_RECEIVEDACSCOMMITMENTPERSYNCHRONIZER']._serialized_start=3794
  _globals['_RECEIVEDACSCOMMITMENTPERSYNCHRONIZER']._serialized_end=3971
  _globals['_SENTACSCOMMITMENT']._serialized_start=3974
  _globals['_SENTACSCOMMITMENT']._serialized_end=4374
  _globals['_SENTACSCOMMITMENTPERSYNCHRONIZER']._serialized_start=4377
  _globals['_SENTACSCOMMITMENTPERSYNCHRONIZER']._serialized_end=4538
  _globals['_LOOKUPSENTACSCOMMITMENTSREQUEST']._serialized_start=4541
  _globals['_LOOKUPSENTACSCOMMITMENTSREQUEST']._serialized_end=4870
  _globals['_LOOKUPSENTACSCOMMITMENTSRESPONSE']._serialized_start=4873
  _globals['_LOOKUPSENTACSCOMMITMENTSRESPONSE']._serialized_end=5008
  _globals['_SLOWCOUNTERPARTICIPANTSYNCHRONIZERCONFIG']._serialized_start=5011
  _globals['_SLOWCOUNTERPARTICIPANTSYNCHRONIZERCONFIG']._serialized_end=5326
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_start=5329
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_end=5488
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_start=5490
  _globals['_SETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_end=5535
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_start=5537
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSREQUEST']._serialized_end=5624
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_start=5627
  _globals['_GETCONFIGFORSLOWCOUNTERPARTICIPANTSRESPONSE']._serialized_end=5787
  _globals['_COUNTERPARTICIPANTINFO']._serialized_start=5790
  _globals['_COUNTERPARTICIPANTINFO']._serialized_end=6105
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSREQUEST']._serialized_start=6108
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSREQUEST']._serialized_end=6305
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSRESPONSE']._serialized_start=6308
  _globals['_GETINTERVALSBEHINDFORCOUNTERPARTICIPANTSRESPONSE']._serialized_end=6472
  _globals['_COUNTINFLIGHTREQUEST']._serialized_start=6474
  _globals['_COUNTINFLIGHTREQUEST']._serialized_end=6537
  _globals['_COUNTINFLIGHTRESPONSE']._serialized_start=6539
  _globals['_COUNTINFLIGHTRESPONSE']._serialized_end=6662
  _globals['_PARTICIPANTINSPECTIONSERVICE']._serialized_start=7068
  _globals['_PARTICIPANTINSPECTIONSERVICE']._serialized_end=8863
# @@protoc_insertion_point(module_scope)
