# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file

import builtins as _builtins, typing as _typing

import grpc as _grpc
from grpc import aio as _grpc_aio

from .topology_manager_read_service_pb2 import ExportTopologySnapshotRequest, ExportTopologySnapshotResponse, ExportTopologySnapshotV2Request, ExportTopologySnapshotV2Response, GenesisStateRequest, GenesisStateResponse, GenesisStateV2Request, GenesisStateV2Response, ListAllRequest, ListAllResponse, ListAvailableStoresRequest, ListAvailableStoresResponse, ListDecentralizedNamespaceDefinitionRequest, ListDecentralizedNamespaceDefinitionResponse, ListMediatorSynchronizerStateRequest, ListMediatorSynchronizerStateResponse, ListNamespaceDelegationRequest, ListNamespaceDelegationResponse, ListOwnerToKeyMappingRequest, ListOwnerToKeyMappingResponse, ListParticipantSynchronizerPermissionRequest, ListParticipantSynchronizerPermissionResponse, ListPartyHostingLimitsRequest, ListPartyHostingLimitsResponse, ListPartyToKeyMappingRequest, ListPartyToKeyMappingResponse, ListPartyToParticipantRequest, ListPartyToParticipantResponse, ListSequencerConnectionSuccessorRequest, ListSequencerConnectionSuccessorResponse, ListSequencerSynchronizerStateRequest, ListSequencerSynchronizerStateResponse, ListSynchronizerParametersStateRequest, ListSynchronizerParametersStateResponse, ListSynchronizerTrustCertificateRequest, ListSynchronizerTrustCertificateResponse, ListSynchronizerUpgradeAnnouncementRequest, ListSynchronizerUpgradeAnnouncementResponse, ListVettedPackagesRequest, ListVettedPackagesResponse, LogicalUpgradeStateRequest, LogicalUpgradeStateResponse

__all__ = [
    "TopologyManagerReadServiceStub",
]


# noinspection PyPep8Naming,DuplicatedCode
class TopologyManagerReadServiceStub:
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc.Channel) -> _TopologyManagerReadServiceBlockingStub: ...  # type: ignore
    @classmethod  # type: ignore
    @_typing.overload
    def __new__(cls, channel: _grpc_aio.Channel) -> _TopologyManagerReadServiceAsyncStub: ...  # type: ignore
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDecentralizedNamespaceDefinitionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToKeyMappingResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]: ...
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerTrustCertificateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerTrustCertificateResponse]: ...
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantSynchronizerPermissionResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantSynchronizerPermissionResponse]: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyHostingLimitsResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]: ...
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerParametersStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerParametersStateResponse]: ...
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorSynchronizerStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorSynchronizerStateResponse]: ...
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerSynchronizerStateResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerSynchronizerStateResponse]: ...
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerUpgradeAnnouncementResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerUpgradeAnnouncementResponse]: ...
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerConnectionSuccessorResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerConnectionSuccessorResponse]: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]: ...
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse | _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotResponse]: ...
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotV2Response] | _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotV2Response]: ...
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]: ...
    def GenesisStateV2(self, __1: GenesisStateV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateV2Response] | _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateV2Response]: ...
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[LogicalUpgradeStateResponse] | _grpc_aio.UnaryStreamCall[_typing.Any, LogicalUpgradeStateResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceBlockingStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListNamespaceDelegationResponse: ...
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListDecentralizedNamespaceDefinitionResponse: ...
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListOwnerToKeyMappingResponse: ...
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToKeyMappingResponse: ...
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerTrustCertificateResponse: ...
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListParticipantSynchronizerPermissionResponse: ...
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyHostingLimitsResponse: ...
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListVettedPackagesResponse: ...
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListPartyToParticipantResponse: ...
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerParametersStateResponse: ...
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListMediatorSynchronizerStateResponse: ...
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerSynchronizerStateResponse: ...
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSynchronizerUpgradeAnnouncementResponse: ...
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListSequencerConnectionSuccessorResponse: ...
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAvailableStoresResponse: ...
    def ListAll(self, __1: ListAllRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> ListAllResponse: ...
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotResponse]: ...
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[ExportTopologySnapshotV2Response]: ...
    def GenesisState(self, __1: GenesisStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateResponse]: ...
    def GenesisStateV2(self, __1: GenesisStateV2Request, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[GenesisStateV2Response]: ...
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_typing.Tuple[_typing.Tuple[str, str | bytes], ...]] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc.CallIterator[LogicalUpgradeStateResponse]: ...

# noinspection PyPep8Naming,DuplicatedCode
class _TopologyManagerReadServiceAsyncStub(TopologyManagerReadServiceStub):
    def ListNamespaceDelegation(self, __1: ListNamespaceDelegationRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListNamespaceDelegationResponse]: ...  # type: ignore
    def ListDecentralizedNamespaceDefinition(self, __1: ListDecentralizedNamespaceDefinitionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListDecentralizedNamespaceDefinitionResponse]: ...  # type: ignore
    def ListOwnerToKeyMapping(self, __1: ListOwnerToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListOwnerToKeyMappingResponse]: ...  # type: ignore
    def ListPartyToKeyMapping(self, __1: ListPartyToKeyMappingRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToKeyMappingResponse]: ...  # type: ignore
    def ListSynchronizerTrustCertificate(self, __1: ListSynchronizerTrustCertificateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerTrustCertificateResponse]: ...  # type: ignore
    def ListParticipantSynchronizerPermission(self, __1: ListParticipantSynchronizerPermissionRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListParticipantSynchronizerPermissionResponse]: ...  # type: ignore
    def ListPartyHostingLimits(self, __1: ListPartyHostingLimitsRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyHostingLimitsResponse]: ...  # type: ignore
    def ListVettedPackages(self, __1: ListVettedPackagesRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListVettedPackagesResponse]: ...  # type: ignore
    def ListPartyToParticipant(self, __1: ListPartyToParticipantRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListPartyToParticipantResponse]: ...  # type: ignore
    def ListSynchronizerParametersState(self, __1: ListSynchronizerParametersStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerParametersStateResponse]: ...  # type: ignore
    def ListMediatorSynchronizerState(self, __1: ListMediatorSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListMediatorSynchronizerStateResponse]: ...  # type: ignore
    def ListSequencerSynchronizerState(self, __1: ListSequencerSynchronizerStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerSynchronizerStateResponse]: ...  # type: ignore
    def ListSynchronizerUpgradeAnnouncement(self, __1: ListSynchronizerUpgradeAnnouncementRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSynchronizerUpgradeAnnouncementResponse]: ...  # type: ignore
    def ListSequencerConnectionSuccessor(self, __1: ListSequencerConnectionSuccessorRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListSequencerConnectionSuccessorResponse]: ...  # type: ignore
    def ListAvailableStores(self, __1: ListAvailableStoresRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAvailableStoresResponse]: ...  # type: ignore
    def ListAll(self, __1: ListAllRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryUnaryCall[_typing.Any, ListAllResponse]: ...  # type: ignore
    def ExportTopologySnapshot(self, __1: ExportTopologySnapshotRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotResponse]: ...  # type: ignore
    def ExportTopologySnapshotV2(self, __1: ExportTopologySnapshotV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, ExportTopologySnapshotV2Response]: ...  # type: ignore
    def GenesisState(self, __1: GenesisStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateResponse]: ...  # type: ignore
    def GenesisStateV2(self, __1: GenesisStateV2Request, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, GenesisStateV2Response]: ...  # type: ignore
    def LogicalUpgradeState(self, __1: LogicalUpgradeStateRequest, *, timeout: _typing.Optional[float] = ..., metadata: _typing.Optional[_grpc_aio.Metadata] = ..., credentials: _typing.Optional[_grpc.CallCredentials] = ..., wait_for_ready: _typing.Optional[bool] = ..., compression: _typing.Optional[_grpc.Compression] = ...) -> _grpc_aio.UnaryStreamCall[_typing.Any, LogicalUpgradeStateResponse]: ...  # type: ignore
