# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/active_contract.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/active_contract.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nCcom/digitalasset/canton/admin/participant/v30/active_contract.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xc4\x01\n\x11\x41\x63tiveContractOld\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12S\n\x08\x63ontract\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.admin.participant.v30.ContractR\x08\x63ontract\x12\x31\n\x14reassignment_counter\x18\x03 \x01(\x03R\x13reassignmentCounter\"\x9b\x05\n\x08\x43ontract\x12\x1f\n\x0b\x63ontract_id\x18\x01 \x01(\tR\ncontractId\x12\x32\n\x15raw_contract_instance\x18\x02 \x01(\x0cR\x13rawContractInstance\x12\\\n\x08metadata\x18\x03 \x01(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.Contract.MetadataR\x08metadata\x12H\n\x12ledger_create_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10ledgerCreateTime\x12/\n\x13\x61uthentication_data\x18\x05 \x01(\x0cR\x12\x61uthenticationData\x1a\xfd\x01\n\x08Metadata\x12<\n\x1anon_maintainer_signatories\x18\x01 \x03(\tR\x18nonMaintainerSignatories\x12<\n\x1anon_signatory_stakeholders\x18\x02 \x03(\tR\x18nonSignatoryStakeholders\x12S\n\x03key\x18\x03 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.participant.v30.Contract.GlobalKeyR\x03key\x12 \n\x0bmaintainers\x18\x04 \x03(\tR\x0bmaintainers\x1a\x61\n\tGlobalKey\x12\x1f\n\x0btemplate_id\x18\x01 \x01(\x0cR\ntemplateId\x12\x10\n\x03key\x18\x02 \x01(\x0cR\x03key\x12!\n\x0cpackage_name\x18\x03 \x01(\tR\x0bpackageName\"9\n\x0e\x41\x63tiveContract\x12\'\n\x0f\x61\x63tive_contract\x18\x01 \x01(\x0cR\x0e\x61\x63tiveContractB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.active_contract_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_ACTIVECONTRACTOLD']._serialized_start=152
  _globals['_ACTIVECONTRACTOLD']._serialized_end=348
  _globals['_CONTRACT']._serialized_start=351
  _globals['_CONTRACT']._serialized_end=1018
  _globals['_CONTRACT_METADATA']._serialized_start=666
  _globals['_CONTRACT_METADATA']._serialized_end=919
  _globals['_CONTRACT_GLOBALKEY']._serialized_start=921
  _globals['_CONTRACT_GLOBALKEY']._serialized_end=1018
  _globals['_ACTIVECONTRACT']._serialized_start=1020
  _globals['_ACTIVECONTRACT']._serialized_end=1077
# @@protoc_insertion_point(module_scope)
