# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/domain/admin/v0/mediator_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/domain/admin/v0/mediator_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....health.admin.v0 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v0_dot_status__service__pb2
from ....health.admin.v1 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_health_dot_admin_dot_v1_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nEcom/digitalasset/canton/domain/admin/v0/mediator_status_service.proto\x12\'com.digitalasset.canton.domain.admin.v0\x1a<com/digitalasset/canton/health/admin/v0/status_service.proto\x1a<com/digitalasset/canton/health/admin/v1/status_service.proto\"\x17\n\x15MediatorStatusRequest\"\x8d\x04\n\x16MediatorStatusResponse\x12v\n\x06status\x18\x01 \x01(\x0b\x32\\.com.digitalasset.canton.domain.admin.v0.MediatorStatusResponse.MediatorStatusResponseStatusH\x00R\x06status\x12\x66\n\x0bunavailable\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.health.admin.v0.NodeStatus.NotInitializedH\x00R\x0bunavailable\x12L\n\x07\x66\x61ilure\x18\x03 \x01(\x0b\x32\x30.com.digitalasset.canton.health.admin.v1.FailureH\x00R\x07\x66\x61ilure\x1a\xbc\x01\n\x1cMediatorStatusResponseStatus\x12T\n\rcommon_status\x18\x01 \x01(\x0b\x32/.com.digitalasset.canton.health.admin.v1.StatusR\x0c\x63ommonStatus\x12\x1b\n\tdomain_id\x18\x02 \x01(\tR\x08\x64omainId\x12)\n\x10protocol_version\x18\x03 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind2\xab\x01\n\x15MediatorStatusService\x12\x91\x01\n\x0eMediatorStatus\x12>.com.digitalasset.canton.domain.admin.v0.MediatorStatusRequest\x1a?.com.digitalasset.canton.domain.admin.v0.MediatorStatusResponseBXZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.domain.admin.v0.mediator_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZVgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/domain/admin/v0'
  _globals['_MEDIATORSTATUSREQUEST']._serialized_start=238
  _globals['_MEDIATORSTATUSREQUEST']._serialized_end=261
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_start=264
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_end=789
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_start=593
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_end=781
  _globals['_MEDIATORSTATUSSERVICE']._serialized_start=792
  _globals['_MEDIATORSTATUSSERVICE']._serialized_end=963
# @@protoc_insertion_point(module_scope)
