# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/crypto.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/crypto.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#com/daml/ledger/api/v2/crypto.proto\x12\x16\x63om.daml.ledger.api.v2\"\xb1\x01\n\x10SigningPublicKey\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.CryptoKeyFormatR\x06\x66ormat\x12\x19\n\x08key_data\x18\x02 \x01(\x0cR\x07keyData\x12\x41\n\x08key_spec\x18\x03 \x01(\x0e\x32&.com.daml.ledger.api.v2.SigningKeySpecR\x07keySpec\"\xeb\x01\n\tSignature\x12?\n\x06\x66ormat\x18\x01 \x01(\x0e\x32\'.com.daml.ledger.api.v2.SignatureFormatR\x06\x66ormat\x12\x1c\n\tsignature\x18\x02 \x01(\x0cR\tsignature\x12\x1b\n\tsigned_by\x18\x03 \x01(\tR\x08signedBy\x12\x62\n\x16signing_algorithm_spec\x18\x04 \x01(\x0e\x32,.com.daml.ledger.api.v2.SigningAlgorithmSpecR\x14signingAlgorithmSpec*\xb5\x01\n\x0eSigningKeySpec\x12 \n\x1cSIGNING_KEY_SPEC_UNSPECIFIED\x10\x00\x12\"\n\x1eSIGNING_KEY_SPEC_EC_CURVE25519\x10\x01\x12\x1c\n\x18SIGNING_KEY_SPEC_EC_P256\x10\x02\x12\x1c\n\x18SIGNING_KEY_SPEC_EC_P384\x10\x03\x12!\n\x1dSIGNING_KEY_SPEC_EC_SECP256K1\x10\x04*\xaa\x01\n\x0f\x43ryptoKeyFormat\x12!\n\x1d\x43RYPTO_KEY_FORMAT_UNSPECIFIED\x10\x00\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_DER\x10\x01\x12\x19\n\x15\x43RYPTO_KEY_FORMAT_RAW\x10\x02\x12\x36\n2CRYPTO_KEY_FORMAT_DER_X509_SUBJECT_PUBLIC_KEY_INFO\x10\x03\"\x06\x08\x90N\x10\x90N*\xb8\x01\n\x14SigningAlgorithmSpec\x12&\n\"SIGNING_ALGORITHM_SPEC_UNSPECIFIED\x10\x00\x12\"\n\x1eSIGNING_ALGORITHM_SPEC_ED25519\x10\x01\x12)\n%SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_256\x10\x02\x12)\n%SIGNING_ALGORITHM_SPEC_EC_DSA_SHA_384\x10\x03*\xa4\x01\n\x0fSignatureFormat\x12 \n\x1cSIGNATURE_FORMAT_UNSPECIFIED\x10\x00\x12\x18\n\x14SIGNATURE_FORMAT_RAW\x10\x01\x12\x18\n\x14SIGNATURE_FORMAT_DER\x10\x02\x12\x1b\n\x17SIGNATURE_FORMAT_CONCAT\x10\x03\x12\x1e\n\x19SIGNATURE_FORMAT_SYMBOLIC\x10\x90NB\x8a\x01\n\x16\x63om.daml.ledger.api.v2B\x10\x43ryptoOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.crypto_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\020CryptoOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_SIGNINGKEYSPEC']._serialized_start=482
  _globals['_SIGNINGKEYSPEC']._serialized_end=663
  _globals['_CRYPTOKEYFORMAT']._serialized_start=666
  _globals['_CRYPTOKEYFORMAT']._serialized_end=836
  _globals['_SIGNINGALGORITHMSPEC']._serialized_start=839
  _globals['_SIGNINGALGORITHMSPEC']._serialized_end=1023
  _globals['_SIGNATUREFORMAT']._serialized_start=1026
  _globals['_SIGNATUREFORMAT']._serialized_end=1190
  _globals['_SIGNINGPUBLICKEY']._serialized_start=64
  _globals['_SIGNINGPUBLICKEY']._serialized_end=241
  _globals['_SIGNATURE']._serialized_start=244
  _globals['_SIGNATURE']._serialized_end=479
# @@protoc_insertion_point(module_scope)
