# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from __future__ import annotations

from collections.abc import Mapping
from typing import TYPE_CHECKING, Any, TypeVar

from attrs import define as _attrs_define
from attrs import field as _attrs_field

if TYPE_CHECKING:
    from ..models.archived_event import ArchivedEvent


T = TypeVar("T", bound="EventType0")


@_attrs_define
class EventType0:
    """
    Attributes:
        archived_event (ArchivedEvent): Records that a contract has been archived, and choices may no longer be
            exercised on it.
    """

    archived_event: ArchivedEvent
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)

    def to_dict(self) -> dict[str, Any]:
        archived_event = self.archived_event.to_dict()

        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "ArchivedEvent": archived_event,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.archived_event import ArchivedEvent

        d = dict(src_dict)
        archived_event = ArchivedEvent.from_dict(d.pop("ArchivedEvent"))

        event_type_0 = cls(
            archived_event=archived_event,
        )

        event_type_0.additional_properties = d
        return event_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
