# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...health.v30 import status_service_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_health_dot_v30_dot_status__service__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/admin/mediator/v30/mediator_status_service.proto\x12*com.digitalasset.canton.admin.mediator.v30\x1a=com/digitalasset/canton/admin/health/v30/status_service.proto\"\x17\n\x15MediatorStatusRequest\"\xdd\x03\n\x16MediatorStatusResponse\x12y\n\x06status\x18\x01 \x01(\x0b\x32_.com.digitalasset.canton.admin.mediator.v30.MediatorStatusResponse.MediatorStatusResponseStatusH\x00R\x06status\x12\x63\n\x0fnot_initialized\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.admin.health.v30.NotInitializedH\x00R\x0enotInitialized\x1a\xda\x01\n\x1cMediatorStatusResponseStatus\x12U\n\rcommon_status\x18\x01 \x01(\x0b\x32\x30.com.digitalasset.canton.admin.health.v30.StatusR\x0c\x63ommonStatus\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\x12)\n\x10protocol_version\x18\x03 \x01(\x05R\x0fprotocolVersionB\x06\n\x04kind2\xb1\x01\n\x15MediatorStatusService\x12\x97\x01\n\x0eMediatorStatus\x12\x41.com.digitalasset.canton.admin.mediator.v30.MediatorStatusRequest\x1a\x42.com.digitalasset.canton.admin.mediator.v30.MediatorStatusResponseB[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/mediator/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.mediator.v30.mediator_status_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/mediator/v30'
  _globals['_MEDIATORSTATUSREQUEST']._serialized_start=183
  _globals['_MEDIATORSTATUSREQUEST']._serialized_end=206
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_start=209
  _globals['_MEDIATORSTATUSRESPONSE']._serialized_end=686
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_start=460
  _globals['_MEDIATORSTATUSRESPONSE_MEDIATORSTATUSRESPONSESTATUS']._serialized_end=678
  _globals['_MEDIATORSTATUSSERVICE']._serialized_start=689
  _globals['_MEDIATORSTATUSSERVICE']._serialized_end=866
# @@protoc_insertion_point(module_scope)
