# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar

DESCRIPTOR: _descriptor.FileDescriptor

class SetPassiveRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class SetPassiveResponse(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...
