# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/daml/ledger/api/v2/update_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/daml/ledger/api/v2/update_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import offset_checkpoint_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_offset__checkpoint__pb2
from . import reassignment_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_reassignment__pb2
from . import topology_transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_topology__transaction__pb2
from . import transaction_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__pb2
from . import transaction_filter_pb2 as com_dot_daml_dot_ledger_dot_api_dot_v2_dot_transaction__filter__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+com/daml/ledger/api/v2/update_service.proto\x12\x16\x63om.daml.ledger.api.v2\x1a.com/daml/ledger/api/v2/offset_checkpoint.proto\x1a)com/daml/ledger/api/v2/reassignment.proto\x1a\x31\x63om/daml/ledger/api/v2/topology_transaction.proto\x1a(com/daml/ledger/api/v2/transaction.proto\x1a/com/daml/ledger/api/v2/transaction_filter.proto\"\xe0\x01\n\x11GetUpdatesRequest\x12\'\n\x0f\x62\x65gin_exclusive\x18\x01 \x01(\x03R\x0e\x62\x65ginExclusive\x12(\n\rend_inclusive\x18\x02 \x01(\x03H\x00R\x0c\x65ndInclusive\x88\x01\x01\x12I\n\rupdate_format\x18\x05 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormatB\x10\n\x0e_end_inclusiveJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05R\x06\x66ilterR\x07verbose\"\xee\x02\n\x12GetUpdatesResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12W\n\x11offset_checkpoint\x18\x03 \x01(\x0b\x32(.com.daml.ledger.api.v2.OffsetCheckpointH\x00R\x10offsetCheckpoint\x12`\n\x14topology_transaction\x18\x04 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update\"}\n\x18GetUpdateByOffsetRequest\x12\x16\n\x06offset\x18\x01 \x01(\x03R\x06offset\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"~\n\x14GetUpdateByIdRequest\x12\x1b\n\tupdate_id\x18\x01 \x01(\tR\x08updateId\x12I\n\rupdate_format\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.UpdateFormatR\x0cupdateFormat\"\x94\x02\n\x11GetUpdateResponse\x12G\n\x0btransaction\x18\x01 \x01(\x0b\x32#.com.daml.ledger.api.v2.TransactionH\x00R\x0btransaction\x12J\n\x0creassignment\x18\x02 \x01(\x0b\x32$.com.daml.ledger.api.v2.ReassignmentH\x00R\x0creassignment\x12`\n\x14topology_transaction\x18\x03 \x01(\x0b\x32+.com.daml.ledger.api.v2.TopologyTransactionH\x00R\x13topologyTransactionB\x08\n\x06update2\xd2\x02\n\rUpdateService\x12\x65\n\nGetUpdates\x12).com.daml.ledger.api.v2.GetUpdatesRequest\x1a*.com.daml.ledger.api.v2.GetUpdatesResponse0\x01\x12p\n\x11GetUpdateByOffset\x12\x30.com.daml.ledger.api.v2.GetUpdateByOffsetRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponse\x12h\n\rGetUpdateById\x12,.com.daml.ledger.api.v2.GetUpdateByIdRequest\x1a).com.daml.ledger.api.v2.GetUpdateResponseB\x91\x01\n\x16\x63om.daml.ledger.api.v2B\x17UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\xaa\x02\x16\x43om.Daml.Ledger.Api.V2b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.daml.ledger.api.v2.update_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\026com.daml.ledger.api.v2B\027UpdateServiceOuterClassZEgithub.com/digital-asset/dazl-client/v8/go/api/com/daml/ledger/api/v2\252\002\026Com.Daml.Ledger.Api.V2'
  _globals['_GETUPDATESREQUEST']._serialized_start=305
  _globals['_GETUPDATESREQUEST']._serialized_end=529
  _globals['_GETUPDATESRESPONSE']._serialized_start=532
  _globals['_GETUPDATESRESPONSE']._serialized_end=898
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_start=900
  _globals['_GETUPDATEBYOFFSETREQUEST']._serialized_end=1025
  _globals['_GETUPDATEBYIDREQUEST']._serialized_start=1027
  _globals['_GETUPDATEBYIDREQUEST']._serialized_end=1153
  _globals['_GETUPDATERESPONSE']._serialized_start=1156
  _globals['_GETUPDATERESPONSE']._serialized_end=1432
  _globals['_UPDATESERVICE']._serialized_start=1435
  _globals['_UPDATESERVICE']._serialized_end=1773
# @@protoc_insertion_point(module_scope)
