# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ...sequencer.v30 import sequencer_connection_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_sequencer_dot_v30_dot_sequencer__connection__pb2
from ...time.v30 import time_tracker_config_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_time_dot_v30_dot_time__tracker__config__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nMcom/digitalasset/canton/admin/participant/v30/synchronizer_connectivity.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a\x46\x63om/digitalasset/canton/admin/sequencer/v30/sequencer_connection.proto\x1a@com/digitalasset/canton/admin/time/v30/time_tracker_config.proto\x1a\x1egoogle/protobuf/duration.proto\"\x8b\x05\n\x1cSynchronizerConnectionConfig\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12v\n\x15sequencer_connections\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionsR\x14sequencerConnections\x12%\n\x0emanual_connect\x18\x03 \x01(\x08R\rmanualConnect\x12\x38\n\x18physical_synchronizer_id\x18\x04 \x01(\tR\x16physicalSynchronizerId\x12\x1a\n\x08priority\x18\x05 \x01(\x05R\x08priority\x12I\n\x13initial_retry_delay\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x11initialRetryDelay\x12\x41\n\x0fmax_retry_delay\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\rmaxRetryDelay\x12h\n\x0ctime_tracker\x18\x08 \x01(\x0b\x32\x45.com.digitalasset.canton.admin.time.v30.SynchronizerTimeTrackerConfigR\x0btimeTracker\x12O\n$initialize_from_trusted_synchronizer\x18\n \x01(\x08R!initializeFromTrustedSynchronizer\"H\n\x1dReconnectSynchronizersRequest\x12\'\n\x0fignore_failures\x18\x01 \x01(\x08R\x0eignoreFailures\" \n\x1eReconnectSynchronizersResponse\"\xc1\x04\n\x1bRegisterSynchronizerRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x9a\x01\n\x17synchronizer_connection\x18\x02 \x01(\x0e\x32\x61.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerRequest.SynchronizerConnectionR\x16synchronizerConnection\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"\x8a\x01\n\x16SynchronizerConnection\x12\'\n#SYNCHRONIZER_CONNECTION_UNSPECIFIED\x10\x00\x12 \n\x1cSYNCHRONIZER_CONNECTION_NONE\x10\x01\x12%\n!SYNCHRONIZER_CONNECTION_HANDSHAKE\x10\x02\"\x1e\n\x1cRegisterSynchronizerResponse\"\xf8\x02\n\x19ModifySynchronizerRequest\x12=\n\x18physical_synchronizer_id\x18\x01 \x01(\tH\x00R\x16physicalSynchronizerId\x88\x01\x01\x12j\n\nnew_config\x18\x02 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\tnewConfig\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x03 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidationB\x1b\n\x19_physical_synchronizer_id\"\x1c\n\x1aModifySynchronizerResponse\"$\n\"ListRegisteredSynchronizersRequest\"\x84\x03\n#ListRegisteredSynchronizersResponse\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersResponse.ResultR\x07results\x1a\xe7\x01\n\x06Result\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x1c\n\tconnected\x18\x02 \x01(\x08R\tconnected\x12=\n\x18physical_synchronizer_id\x18\x03 \x01(\tH\x00R\x16physicalSynchronizerId\x88\x01\x01\x42\x1b\n\x19_physical_synchronizer_id\"c\n\x1cReconnectSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12\x14\n\x05retry\x18\x02 \x01(\x08R\x05retry\"V\n\x1dReconnectSynchronizerResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"\x96\x02\n\x1a\x43onnectSynchronizerRequest\x12\x63\n\x06\x63onfig\x18\x01 \x01(\x0b\x32K.com.digitalasset.canton.admin.participant.v30.SynchronizerConnectionConfigR\x06\x63onfig\x12\x92\x01\n\x1fsequencer_connection_validation\x18\x02 \x01(\x0e\x32J.com.digitalasset.canton.admin.sequencer.v30.SequencerConnectionValidationR\x1dsequencerConnectionValidation\"T\n\x1b\x43onnectSynchronizerResponse\x12\x35\n\x16\x63onnected_successfully\x18\x01 \x01(\x08R\x15\x63onnectedSuccessfully\"N\n\x1d\x44isconnectSynchronizerRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\" \n\x1e\x44isconnectSynchronizerResponse\"#\n!DisconnectAllSynchronizersRequest\"$\n\"DisconnectAllSynchronizersResponse\"#\n!ListConnectedSynchronizersRequest\"\xef\x02\n\"ListConnectedSynchronizersResponse\x12\x91\x01\n\x17\x63onnected_synchronizers\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersResponse.ResultR\x16\x63onnectedSynchronizers\x1a\xb4\x01\n\x06Result\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x38\n\x18physical_synchronizer_id\x18\x03 \x01(\tR\x16physicalSynchronizerId\x12\x18\n\x07healthy\x18\x04 \x01(\x08R\x07healthy\"I\n\x18GetSynchronizerIdRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"~\n\x19GetSynchronizerIdResponse\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x38\n\x18physical_synchronizer_id\x18\x02 \x01(\tR\x16physicalSynchronizerId\">\n\rLogoutRequest\x12-\n\x12synchronizer_alias\x18\x01 \x01(\tR\x11synchronizerAlias\"\x10\n\x0eLogoutResponse2\xd3\x0f\n\x1fSynchronizerConnectivityService\x12\xac\x01\n\x13\x43onnectSynchronizer\x12I.com.digitalasset.canton.admin.participant.v30.ConnectSynchronizerRequest\x1aJ.com.digitalasset.canton.admin.participant.v30.ConnectSynchronizerResponse\x12\xaf\x01\n\x14RegisterSynchronizer\x12J.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerRequest\x1aK.com.digitalasset.canton.admin.participant.v30.RegisterSynchronizerResponse\x12\xb5\x01\n\x16ReconnectSynchronizers\x12L.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizersRequest\x1aM.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizersResponse\x12\xb2\x01\n\x15ReconnectSynchronizer\x12K.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizerRequest\x1aL.com.digitalasset.canton.admin.participant.v30.ReconnectSynchronizerResponse\x12\xa9\x01\n\x12ModifySynchronizer\x12H.com.digitalasset.canton.admin.participant.v30.ModifySynchronizerRequest\x1aI.com.digitalasset.canton.admin.participant.v30.ModifySynchronizerResponse\x12\xb5\x01\n\x16\x44isconnectSynchronizer\x12L.com.digitalasset.canton.admin.participant.v30.DisconnectSynchronizerRequest\x1aM.com.digitalasset.canton.admin.participant.v30.DisconnectSynchronizerResponse\x12\xc1\x01\n\x1a\x44isconnectAllSynchronizers\x12P.com.digitalasset.canton.admin.participant.v30.DisconnectAllSynchronizersRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.DisconnectAllSynchronizersResponse\x12\x85\x01\n\x06Logout\x12<.com.digitalasset.canton.admin.participant.v30.LogoutRequest\x1a=.com.digitalasset.canton.admin.participant.v30.LogoutResponse\x12\xc1\x01\n\x1aListConnectedSynchronizers\x12P.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersRequest\x1aQ.com.digitalasset.canton.admin.participant.v30.ListConnectedSynchronizersResponse\x12\xc4\x01\n\x1bListRegisteredSynchronizers\x12Q.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersRequest\x1aR.com.digitalasset.canton.admin.participant.v30.ListRegisteredSynchronizersResponse\x12\xa6\x01\n\x11GetSynchronizerId\x12G.com.digitalasset.canton.admin.participant.v30.GetSynchronizerIdRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetSynchronizerIdResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.synchronizer_connectivity_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_SYNCHRONIZERCONNECTIONCONFIG']._serialized_start=299
  _globals['_SYNCHRONIZERCONNECTIONCONFIG']._serialized_end=950
  _globals['_RECONNECTSYNCHRONIZERSREQUEST']._serialized_start=952
  _globals['_RECONNECTSYNCHRONIZERSREQUEST']._serialized_end=1024
  _globals['_RECONNECTSYNCHRONIZERSRESPONSE']._serialized_start=1026
  _globals['_RECONNECTSYNCHRONIZERSRESPONSE']._serialized_end=1058
  _globals['_REGISTERSYNCHRONIZERREQUEST']._serialized_start=1061
  _globals['_REGISTERSYNCHRONIZERREQUEST']._serialized_end=1638
  _globals['_REGISTERSYNCHRONIZERREQUEST_SYNCHRONIZERCONNECTION']._serialized_start=1500
  _globals['_REGISTERSYNCHRONIZERREQUEST_SYNCHRONIZERCONNECTION']._serialized_end=1638
  _globals['_REGISTERSYNCHRONIZERRESPONSE']._serialized_start=1640
  _globals['_REGISTERSYNCHRONIZERRESPONSE']._serialized_end=1670
  _globals['_MODIFYSYNCHRONIZERREQUEST']._serialized_start=1673
  _globals['_MODIFYSYNCHRONIZERREQUEST']._serialized_end=2049
  _globals['_MODIFYSYNCHRONIZERRESPONSE']._serialized_start=2051
  _globals['_MODIFYSYNCHRONIZERRESPONSE']._serialized_end=2079
  _globals['_LISTREGISTEREDSYNCHRONIZERSREQUEST']._serialized_start=2081
  _globals['_LISTREGISTEREDSYNCHRONIZERSREQUEST']._serialized_end=2117
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE']._serialized_start=2120
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE']._serialized_end=2508
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE_RESULT']._serialized_start=2277
  _globals['_LISTREGISTEREDSYNCHRONIZERSRESPONSE_RESULT']._serialized_end=2508
  _globals['_RECONNECTSYNCHRONIZERREQUEST']._serialized_start=2510
  _globals['_RECONNECTSYNCHRONIZERREQUEST']._serialized_end=2609
  _globals['_RECONNECTSYNCHRONIZERRESPONSE']._serialized_start=2611
  _globals['_RECONNECTSYNCHRONIZERRESPONSE']._serialized_end=2697
  _globals['_CONNECTSYNCHRONIZERREQUEST']._serialized_start=2700
  _globals['_CONNECTSYNCHRONIZERREQUEST']._serialized_end=2978
  _globals['_CONNECTSYNCHRONIZERRESPONSE']._serialized_start=2980
  _globals['_CONNECTSYNCHRONIZERRESPONSE']._serialized_end=3064
  _globals['_DISCONNECTSYNCHRONIZERREQUEST']._serialized_start=3066
  _globals['_DISCONNECTSYNCHRONIZERREQUEST']._serialized_end=3144
  _globals['_DISCONNECTSYNCHRONIZERRESPONSE']._serialized_start=3146
  _globals['_DISCONNECTSYNCHRONIZERRESPONSE']._serialized_end=3178
  _globals['_DISCONNECTALLSYNCHRONIZERSREQUEST']._serialized_start=3180
  _globals['_DISCONNECTALLSYNCHRONIZERSREQUEST']._serialized_end=3215
  _globals['_DISCONNECTALLSYNCHRONIZERSRESPONSE']._serialized_start=3217
  _globals['_DISCONNECTALLSYNCHRONIZERSRESPONSE']._serialized_end=3253
  _globals['_LISTCONNECTEDSYNCHRONIZERSREQUEST']._serialized_start=3255
  _globals['_LISTCONNECTEDSYNCHRONIZERSREQUEST']._serialized_end=3290
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE']._serialized_start=3293
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE']._serialized_end=3660
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE_RESULT']._serialized_start=3480
  _globals['_LISTCONNECTEDSYNCHRONIZERSRESPONSE_RESULT']._serialized_end=3660
  _globals['_GETSYNCHRONIZERIDREQUEST']._serialized_start=3662
  _globals['_GETSYNCHRONIZERIDREQUEST']._serialized_end=3735
  _globals['_GETSYNCHRONIZERIDRESPONSE']._serialized_start=3737
  _globals['_GETSYNCHRONIZERIDRESPONSE']._serialized_end=3863
  _globals['_LOGOUTREQUEST']._serialized_start=3865
  _globals['_LOGOUTREQUEST']._serialized_end=3927
  _globals['_LOGOUTRESPONSE']._serialized_start=3929
  _globals['_LOGOUTRESPONSE']._serialized_end=3945
  _globals['_SYNCHRONIZERCONNECTIVITYSERVICE']._serialized_start=3948
  _globals['_SYNCHRONIZERCONNECTIVITYSERVICE']._serialized_end=5951
# @@protoc_insertion_point(module_scope)
