# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/mediator/admin/v30/mediator_inspection_service.proto\x12*com.digitalasset.canton.mediator.admin.v30\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa5\x01\n\x0fVerdictsRequest\x12k\n\"most_recently_received_record_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x1emostRecentlyReceivedRecordTime\x88\x01\x01\x42%\n#_most_recently_received_record_time\"a\n\x10VerdictsResponse\x12M\n\x07verdict\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.mediator.admin.v30.VerdictR\x07verdict\"\x8b\x04\n\x07Verdict\x12-\n\x12submitting_parties\x18\x01 \x03(\tR\x11submittingParties\x12<\n\x1asubmitting_participant_uid\x18\x02 \x01(\tR\x18submittingParticipantUid\x12S\n\x07verdict\x18\x03 \x01(\x0e\x32\x39.com.digitalasset.canton.mediator.admin.v30.VerdictResultR\x07verdict\x12G\n\x11\x66inalization_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x10\x66inalizationTime\x12;\n\x0brecord_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nrecordTime\x12%\n\x0emediator_group\x18\x06 \x01(\rR\rmediatorGroup\x12k\n\x11transaction_views\x18\x07 \x01(\x0b\x32<.com.digitalasset.canton.mediator.admin.v30.TransactionViewsH\x00R\x10transactionViews\x12\x1b\n\tupdate_id\x18\x08 \x01(\tR\x08updateIdB\x07\n\x05views\"\x87\x02\n\x10TransactionViews\x12]\n\x05views\x18\x01 \x03(\x0b\x32G.com.digitalasset.canton.mediator.admin.v30.TransactionViews.ViewsEntryR\x05views\x12\x1d\n\nroot_views\x18\x02 \x03(\x05R\trootViews\x1au\n\nViewsEntry\x12\x10\n\x03key\x18\x01 \x01(\x05R\x03key\x12Q\n\x05value\x18\x02 \x01(\x0b\x32;.com.digitalasset.canton.mediator.admin.v30.TransactionViewR\x05value:\x02\x38\x01\"\xaf\x01\n\x0fTransactionView\x12\x1c\n\tinformees\x18\x01 \x03(\tR\tinformees\x12\x61\n\x12\x63onfirming_parties\x18\x02 \x03(\x0b\x32\x32.com.digitalasset.canton.mediator.admin.v30.QuorumR\x11\x63onfirmingParties\x12\x1b\n\tsub_views\x18\x03 \x03(\x05R\x08subViews\"@\n\x06Quorum\x12\x18\n\x07parties\x18\x01 \x03(\tR\x07parties\x12\x1c\n\tthreshold\x18\x02 \x01(\x05R\tthreshold*i\n\rVerdictResult\x12\x1e\n\x1aVERDICT_RESULT_UNSPECIFIED\x10\x00\x12\x1b\n\x17VERDICT_RESULT_ACCEPTED\x10\x01\x12\x1b\n\x17VERDICT_RESULT_REJECTED\x10\x02\x32\xa5\x01\n\x19MediatorInspectionService\x12\x87\x01\n\x08Verdicts\x12;.com.digitalasset.canton.mediator.admin.v30.VerdictsRequest\x1a<.com.digitalasset.canton.mediator.admin.v30.VerdictsResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.mediator.admin.v30.mediator_inspection_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/mediator/admin/v30'
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._loaded_options = None
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_options = b'8\001'
  _globals['_VERDICTRESULT']._serialized_start=1460
  _globals['_VERDICTRESULT']._serialized_end=1565
  _globals['_VERDICTSREQUEST']._serialized_start=158
  _globals['_VERDICTSREQUEST']._serialized_end=323
  _globals['_VERDICTSRESPONSE']._serialized_start=325
  _globals['_VERDICTSRESPONSE']._serialized_end=422
  _globals['_VERDICT']._serialized_start=425
  _globals['_VERDICT']._serialized_end=948
  _globals['_TRANSACTIONVIEWS']._serialized_start=951
  _globals['_TRANSACTIONVIEWS']._serialized_end=1214
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_start=1097
  _globals['_TRANSACTIONVIEWS_VIEWSENTRY']._serialized_end=1214
  _globals['_TRANSACTIONVIEW']._serialized_start=1217
  _globals['_TRANSACTIONVIEW']._serialized_end=1392
  _globals['_QUORUM']._serialized_start=1394
  _globals['_QUORUM']._serialized_end=1458
  _globals['_MEDIATORINSPECTIONSERVICE']._serialized_start=1568
  _globals['_MEDIATORINSPECTIONSERVICE']._serialized_end=1733
# @@protoc_insertion_point(module_scope)
