# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nVcom/digitalasset/canton/sequencer/admin/v30/sequencer_bft_administration_service.proto\x12+com.digitalasset.canton.sequencer.admin.v30\"o\n\x16\x41\x64\x64PeerEndpointRequest\x12U\n\x08\x65ndpoint\x18\x01 \x01(\x0b\x32\x39.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointR\x08\x65ndpoint\"y\n\x19RemovePeerEndpointRequest\x12\\\n\x0b\x65ndpoint_id\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\nendpointId\"\xff\x01\n\x0cPeerEndpoint\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\x12\x63\n\nplain_text\x18\x03 \x01(\x0b\x32\x42.com.digitalasset.canton.sequencer.admin.v30.PlainTextPeerEndpointH\x00R\tplainText\x12P\n\x03tls\x18\x04 \x01(\x0b\x32<.com.digitalasset.canton.sequencer.admin.v30.TlsPeerEndpointH\x00R\x03tlsB\n\n\x08security\"P\n\x0ePeerEndpointId\x12\x18\n\x07\x61\x64\x64ress\x18\x01 \x01(\tR\x07\x61\x64\x64ress\x12\x12\n\x04port\x18\x02 \x01(\rR\x04port\x12\x10\n\x03tls\x18\x03 \x01(\x08R\x03tls\"\x17\n\x15PlainTextPeerEndpoint\"\xf3\x01\n\x0fTlsPeerEndpoint\x12J\n\x1f\x63ustom_server_trust_certificate\x18\x01 \x01(\x0cH\x00R\x1c\x63ustomServerTrustCertificate\x88\x01\x01\x12p\n\x12\x63lient_certificate\x18\x02 \x01(\x0b\x32\x41.com.digitalasset.canton.sequencer.admin.v30.TlsClientCertificateR\x11\x63lientCertificateB\"\n _custom_server_trust_certificate\"m\n\x14TlsClientCertificate\x12+\n\x11\x63\x65rtificate_chain\x18\x01 \x01(\x0cR\x10\x63\x65rtificateChain\x12(\n\x10private_key_file\x18\x02 \x01(\tR\x0eprivateKeyFile\"/\n\x17\x41\x64\x64PeerEndpointResponse\x12\x14\n\x05\x61\x64\x64\x65\x64\x18\x01 \x01(\x08R\x05\x61\x64\x64\x65\x64\"6\n\x1aRemovePeerEndpointResponse\x12\x18\n\x07removed\x18\x01 \x01(\x08R\x07removed\"2\n\rAuthenticated\x12!\n\x0csequencer_id\x18\x01 \x01(\tR\x0bsequencerId\"\xc1\x04\n\x18PeerEndpointHealthStatus\x12\x82\x01\n\x10unknown_endpoint\x18\x01 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.UnknownEndpointH\x00R\x0funknownEndpoint\x12x\n\x0c\x64isconnected\x18\x02 \x01(\x0b\x32R.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.DisconnectedH\x00R\x0c\x64isconnected\x12\x81\x01\n\x0funauthenticated\x18\x03 \x01(\x0b\x32U.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatus.UnauthenticatedH\x00R\x0funauthenticated\x12\x62\n\rauthenticated\x18\x04 \x01(\x0b\x32:.com.digitalasset.canton.sequencer.admin.v30.AuthenticatedH\x00R\rauthenticated\x1a\x11\n\x0fUnknownEndpoint\x1a\x0e\n\x0c\x44isconnected\x1a\x11\n\x0fUnauthenticatedB\x08\n\x06status\"\xaa\x01\n\x12PeerEndpointHealth\x12]\n\x06status\x18\x01 \x01(\x0b\x32\x45.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthStatusR\x06status\x12%\n\x0b\x64\x65scription\x18\x02 \x01(\tH\x00R\x0b\x64\x65scription\x88\x01\x01\x42\x0e\n\x0c_description\"\x81\x02\n\x12PeerEndpointStatus\x12\\\n\x0b\x65ndpoint_id\x18\x01 \x01(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\nendpointId\x12\x34\n\x16is_outgoing_connection\x18\x02 \x01(\x08R\x14isOutgoingConnection\x12W\n\x06health\x18\x03 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointHealthR\x06health\"\x8d\x02\n\x14PeerConnectionStatus\x12s\n\x14peer_endpoint_status\x18\x01 \x01(\x0b\x32?.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointStatusH\x00R\x12peerEndpointStatus\x12v\n\x18peer_incoming_connection\x18\x02 \x01(\x0b\x32:.com.digitalasset.canton.sequencer.admin.v30.AuthenticatedH\x00R\x16peerIncomingConnectionB\x08\n\x06status\"}\n\x1bGetPeerNetworkStatusRequest\x12^\n\x0c\x65ndpoint_ids\x18\x01 \x03(\x0b\x32;.com.digitalasset.canton.sequencer.admin.v30.PeerEndpointIdR\x0b\x65ndpointIds\"}\n\x1cGetPeerNetworkStatusResponse\x12]\n\x08statuses\x18\x01 \x03(\x0b\x32\x41.com.digitalasset.canton.sequencer.admin.v30.PeerConnectionStatusR\x08statuses\"\x1c\n\x1aGetOrderingTopologyRequest\"g\n\x1bGetOrderingTopologyResponse\x12#\n\rcurrent_epoch\x18\x01 \x01(\x03R\x0c\x63urrentEpoch\x12#\n\rsequencer_ids\x18\x02 \x03(\tR\x0csequencerIds\"?\n#SetPerformanceMetricsEnabledRequest\x12\x18\n\x07\x65nabled\x18\x01 \x01(\x08R\x07\x65nabled\"&\n$SetPerformanceMetricsEnabledResponse2\x89\x07\n!SequencerBftAdministrationService\x12\x9c\x01\n\x0f\x41\x64\x64PeerEndpoint\x12\x43.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointRequest\x1a\x44.com.digitalasset.canton.sequencer.admin.v30.AddPeerEndpointResponse\x12\xa5\x01\n\x12RemovePeerEndpoint\x12\x46.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointRequest\x1aG.com.digitalasset.canton.sequencer.admin.v30.RemovePeerEndpointResponse\x12\xab\x01\n\x14GetPeerNetworkStatus\x12H.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusRequest\x1aI.com.digitalasset.canton.sequencer.admin.v30.GetPeerNetworkStatusResponse\x12\xa8\x01\n\x13GetOrderingTopology\x12G.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyRequest\x1aH.com.digitalasset.canton.sequencer.admin.v30.GetOrderingTopologyResponse\x12\xc3\x01\n\x1cSetPerformanceMetricsEnabled\x12P.com.digitalasset.canton.sequencer.admin.v30.SetPerformanceMetricsEnabledRequest\x1aQ.com.digitalasset.canton.sequencer.admin.v30.SetPerformanceMetricsEnabledResponseB\\ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.admin.v30.sequencer_bft_administration_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZZgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/admin/v30'
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_start=135
  _globals['_ADDPEERENDPOINTREQUEST']._serialized_end=246
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_start=248
  _globals['_REMOVEPEERENDPOINTREQUEST']._serialized_end=369
  _globals['_PEERENDPOINT']._serialized_start=372
  _globals['_PEERENDPOINT']._serialized_end=627
  _globals['_PEERENDPOINTID']._serialized_start=629
  _globals['_PEERENDPOINTID']._serialized_end=709
  _globals['_PLAINTEXTPEERENDPOINT']._serialized_start=711
  _globals['_PLAINTEXTPEERENDPOINT']._serialized_end=734
  _globals['_TLSPEERENDPOINT']._serialized_start=737
  _globals['_TLSPEERENDPOINT']._serialized_end=980
  _globals['_TLSCLIENTCERTIFICATE']._serialized_start=982
  _globals['_TLSCLIENTCERTIFICATE']._serialized_end=1091
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_start=1093
  _globals['_ADDPEERENDPOINTRESPONSE']._serialized_end=1140
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_start=1142
  _globals['_REMOVEPEERENDPOINTRESPONSE']._serialized_end=1196
  _globals['_AUTHENTICATED']._serialized_start=1198
  _globals['_AUTHENTICATED']._serialized_end=1248
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_start=1251
  _globals['_PEERENDPOINTHEALTHSTATUS']._serialized_end=1828
  _globals['_PEERENDPOINTHEALTHSTATUS_UNKNOWNENDPOINT']._serialized_start=1766
  _globals['_PEERENDPOINTHEALTHSTATUS_UNKNOWNENDPOINT']._serialized_end=1783
  _globals['_PEERENDPOINTHEALTHSTATUS_DISCONNECTED']._serialized_start=1785
  _globals['_PEERENDPOINTHEALTHSTATUS_DISCONNECTED']._serialized_end=1799
  _globals['_PEERENDPOINTHEALTHSTATUS_UNAUTHENTICATED']._serialized_start=1801
  _globals['_PEERENDPOINTHEALTHSTATUS_UNAUTHENTICATED']._serialized_end=1818
  _globals['_PEERENDPOINTHEALTH']._serialized_start=1831
  _globals['_PEERENDPOINTHEALTH']._serialized_end=2001
  _globals['_PEERENDPOINTSTATUS']._serialized_start=2004
  _globals['_PEERENDPOINTSTATUS']._serialized_end=2261
  _globals['_PEERCONNECTIONSTATUS']._serialized_start=2264
  _globals['_PEERCONNECTIONSTATUS']._serialized_end=2533
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_start=2535
  _globals['_GETPEERNETWORKSTATUSREQUEST']._serialized_end=2660
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_start=2662
  _globals['_GETPEERNETWORKSTATUSRESPONSE']._serialized_end=2787
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_start=2789
  _globals['_GETORDERINGTOPOLOGYREQUEST']._serialized_end=2817
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_start=2819
  _globals['_GETORDERINGTOPOLOGYRESPONSE']._serialized_end=2922
  _globals['_SETPERFORMANCEMETRICSENABLEDREQUEST']._serialized_start=2924
  _globals['_SETPERFORMANCEMETRICSENABLEDREQUEST']._serialized_end=2987
  _globals['_SETPERFORMANCEMETRICSENABLEDRESPONSE']._serialized_start=2989
  _globals['_SETPERFORMANCEMETRICSENABLEDRESPONSE']._serialized_end=3027
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_start=3030
  _globals['_SEQUENCERBFTADMINISTRATIONSERVICE']._serialized_end=3935
# @@protoc_insertion_point(module_scope)
