# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/admin/participant/v30/party_management_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/admin/participant/v30/party_management_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import acs_import_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_acs__import__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nLcom/digitalasset/canton/admin/participant/v30/party_management_service.proto\x12-com.digitalasset.canton.admin.participant.v30\x1a>com/digitalasset/canton/admin/participant/v30/acs_import.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xb6\x02\n\x14\x41\x64\x64PartyAsyncRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\'\n\x0ftopology_serial\x18\x04 \x01(\rR\x0etopologySerial\x12{\n\x16participant_permission\x18\x05 \x01(\x0e\x32\x44.com.digitalasset.canton.admin.participant.v30.ParticipantPermissionR\x15participantPermission\"H\n\x15\x41\x64\x64PartyAsyncResponse\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"K\n\x18GetAddPartyStatusRequest\x12/\n\x14\x61\x64\x64_party_request_id\x18\x01 \x01(\tR\x11\x61\x64\x64PartyRequestId\"\x93\x17\n\x19GetAddPartyStatusResponse\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16source_participant_uid\x18\x03 \x01(\tR\x14sourceParticipantUid\x12\x34\n\x16target_participant_uid\x18\x04 \x01(\tR\x14targetParticipantUid\x12\'\n\x0ftopology_serial\x18\x05 \x01(\rR\x0etopologySerial\x12{\n\x16participant_permission\x18\x06 \x01(\x0e\x32\x44.com.digitalasset.canton.admin.participant.v30.ParticipantPermissionR\x15participantPermission\x12g\n\x06status\x18\x07 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x06status\x1a\xb6\x13\n\x06Status\x12\x92\x01\n\x12proposal_processed\x18\x01 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ProposalProcessedH\x00R\x11proposalProcessed\x12\x92\x01\n\x12\x61greement_accepted\x18\x02 \x01(\x0b\x32\x61.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.AgreementAcceptedH\x00R\x11\x61greementAccepted\x12\x95\x01\n\x13topology_authorized\x18\x03 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.TopologyAuthorizedH\x00R\x12topologyAuthorized\x12\x9e\x01\n\x16\x63onnection_established\x18\x04 \x01(\x0b\x32\x65.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ConnectionEstablishedH\x00R\x15\x63onnectionEstablished\x12\x89\x01\n\x0freplicating_acs\x18\x05 \x01(\x0b\x32^.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ReplicatingAcsH\x00R\x0ereplicatingAcs\x12\x96\x01\n\x14\x66ully_replicated_acs\x18\x06 \x01(\x0b\x32\x62.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.FullyReplicatedAcsH\x00R\x12\x66ullyReplicatedAcs\x12y\n\tcompleted\x18\x07 \x01(\x0b\x32Y.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.CompletedH\x00R\tcompleted\x12m\n\x05\x65rror\x18\x08 \x01(\x0b\x32U.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.ErrorH\x00R\x05\x65rror\x12\x82\x01\n\x0c\x64isconnected\x18\t \x01(\x0b\x32\\.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.Status.DisconnectedH\x00R\x0c\x64isconnected\x1a\x13\n\x11ProposalProcessed\x1a\x38\n\x11\x41greementAccepted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x1as\n\x12TopologyAuthorized\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1av\n\x15\x43onnectionEstablished\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x1a\xa2\x01\n\x0eReplicatingAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\xa6\x01\n\x12\x46ullyReplicatedAcs\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\x9d\x01\n\tCompleted\x12#\n\rsequencer_uid\x18\x01 \x01(\tR\x0csequencerUid\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x31\n\x14\x63ontracts_replicated\x18\x03 \x01(\rR\x13\x63ontractsReplicated\x1a\xb1\x01\n\x05\x45rror\x12#\n\rerror_message\x18\x01 \x01(\tR\x0c\x65rrorMessage\x12\x82\x01\n\x15status_prior_to_error\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x12statusPriorToError\x1a\xcc\x01\n\x0c\x44isconnected\x12-\n\x12\x64isconnect_message\x18\x01 \x01(\tR\x11\x64isconnectMessage\x12\x8c\x01\n\x1astatus_prior_to_disconnect\x18\x02 \x01(\x0b\x32O.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse.StatusR\x17statusPriorToDisconnectB\x08\n\x06status\"\xa1\x02\n\x15\x45xportPartyAcsRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16target_participant_uid\x18\x03 \x01(\tR\x14targetParticipantUid\x12\x34\n\x16\x62\x65gin_offset_exclusive\x18\x04 \x01(\x03R\x14\x62\x65ginOffsetExclusive\x12X\n\x1bwait_for_activation_timeout\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18waitForActivationTimeout\".\n\x16\x45xportPartyAcsResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xfb\x02\n\x15ImportPartyAcsRequest\x12!\n\x0c\x61\x63s_snapshot\x18\x01 \x01(\x0cR\x0b\x61\x63sSnapshot\x12,\n\x12workflow_id_prefix\x18\x02 \x01(\tR\x10workflowIdPrefix\x12s\n\x14\x63ontract_import_mode\x18\x03 \x01(\x0e\x32\x41.com.digitalasset.canton.admin.participant.v30.ContractImportModeR\x12\x63ontractImportMode\x12\x9b\x01\n\"representative_package_id_override\x18\x04 \x01(\x0b\x32N.com.digitalasset.canton.admin.participant.v30.RepresentativePackageIdOverrideR\x1frepresentativePackageIdOverride\"\x18\n\x16ImportPartyAcsResponse\"\x9d\x01\n\"GetHighestOffsetByTimestampRequest\x12\'\n\x0fsynchronizer_id\x18\x01 \x01(\tR\x0esynchronizerId\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x14\n\x05\x66orce\x18\x03 \x01(\x08R\x05\x66orce\"J\n#GetHighestOffsetByTimestampResponse\x12#\n\rledger_offset\x18\x01 \x01(\x03R\x0cledgerOffset\"\xf5\x01\n\x1f\x43learPartyOnboardingFlagRequest\x12\x19\n\x08party_id\x18\x01 \x01(\tR\x07partyId\x12\'\n\x0fsynchronizer_id\x18\x02 \x01(\tR\x0esynchronizerId\x12\x34\n\x16\x62\x65gin_offset_exclusive\x18\x03 \x01(\x03R\x14\x62\x65ginOffsetExclusive\x12X\n\x1bwait_for_activation_timeout\x18\x04 \x01(\x0b\x32\x19.google.protobuf.DurationR\x18waitForActivationTimeout\"\xb8\x01\n ClearPartyOnboardingFlagResponse\x12\x1c\n\tonboarded\x18\x01 \x01(\x08R\tonboarded\x12Y\n\x18\x65\x61rliest_retry_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x16\x65\x61rliestRetryTimestamp\x88\x01\x01\x42\x1b\n\x19_earliest_retry_timestamp*\xb7\x01\n\x15ParticipantPermission\x12&\n\"PARTICIPANT_PERMISSION_UNSPECIFIED\x10\x00\x12%\n!PARTICIPANT_PERMISSION_SUBMISSION\x10\x01\x12\'\n#PARTICIPANT_PERMISSION_CONFIRMATION\x10\x02\x12&\n\"PARTICIPANT_PERMISSION_OBSERVATION\x10\x03\x32\xa7\x08\n\x16PartyManagementService\x12\x9a\x01\n\rAddPartyAsync\x12\x43.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncRequest\x1a\x44.com.digitalasset.canton.admin.participant.v30.AddPartyAsyncResponse\x12\xa6\x01\n\x11GetAddPartyStatus\x12G.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusRequest\x1aH.com.digitalasset.canton.admin.participant.v30.GetAddPartyStatusResponse\x12\x9f\x01\n\x0e\x45xportPartyAcs\x12\x44.com.digitalasset.canton.admin.participant.v30.ExportPartyAcsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.ExportPartyAcsResponse0\x01\x12\x9f\x01\n\x0eImportPartyAcs\x12\x44.com.digitalasset.canton.admin.participant.v30.ImportPartyAcsRequest\x1a\x45.com.digitalasset.canton.admin.participant.v30.ImportPartyAcsResponse(\x01\x12\xc4\x01\n\x1bGetHighestOffsetByTimestamp\x12Q.com.digitalasset.canton.admin.participant.v30.GetHighestOffsetByTimestampRequest\x1aR.com.digitalasset.canton.admin.participant.v30.GetHighestOffsetByTimestampResponse\x12\xbb\x01\n\x18\x43learPartyOnboardingFlag\x12N.com.digitalasset.canton.admin.participant.v30.ClearPartyOnboardingFlagRequest\x1aO.com.digitalasset.canton.admin.participant.v30.ClearPartyOnboardingFlagResponseB^Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.admin.participant.v30.party_management_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\\github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/admin/participant/v30'
  _globals['_PARTICIPANTPERMISSION']._serialized_start=5106
  _globals['_PARTICIPANTPERMISSION']._serialized_end=5289
  _globals['_ADDPARTYASYNCREQUEST']._serialized_start=257
  _globals['_ADDPARTYASYNCREQUEST']._serialized_end=567
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_start=569
  _globals['_ADDPARTYASYNCRESPONSE']._serialized_end=641
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_start=643
  _globals['_GETADDPARTYSTATUSREQUEST']._serialized_end=718
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_start=721
  _globals['_GETADDPARTYSTATUSRESPONSE']._serialized_end=3684
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_start=1198
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS']._serialized_end=3684
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_start=2479
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_PROPOSALPROCESSED']._serialized_end=2498
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_start=2500
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_AGREEMENTACCEPTED']._serialized_end=2556
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_start=2558
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_TOPOLOGYAUTHORIZED']._serialized_end=2673
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_start=2675
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_CONNECTIONESTABLISHED']._serialized_end=2793
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_start=2796
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_REPLICATINGACS']._serialized_end=2958
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_FULLYREPLICATEDACS']._serialized_start=2961
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_FULLYREPLICATEDACS']._serialized_end=3127
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_start=3130
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_COMPLETED']._serialized_end=3287
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_start=3290
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_ERROR']._serialized_end=3467
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_DISCONNECTED']._serialized_start=3470
  _globals['_GETADDPARTYSTATUSRESPONSE_STATUS_DISCONNECTED']._serialized_end=3674
  _globals['_EXPORTPARTYACSREQUEST']._serialized_start=3687
  _globals['_EXPORTPARTYACSREQUEST']._serialized_end=3976
  _globals['_EXPORTPARTYACSRESPONSE']._serialized_start=3978
  _globals['_EXPORTPARTYACSRESPONSE']._serialized_end=4024
  _globals['_IMPORTPARTYACSREQUEST']._serialized_start=4027
  _globals['_IMPORTPARTYACSREQUEST']._serialized_end=4406
  _globals['_IMPORTPARTYACSRESPONSE']._serialized_start=4408
  _globals['_IMPORTPARTYACSRESPONSE']._serialized_end=4432
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPREQUEST']._serialized_start=4435
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPREQUEST']._serialized_end=4592
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPRESPONSE']._serialized_start=4594
  _globals['_GETHIGHESTOFFSETBYTIMESTAMPRESPONSE']._serialized_end=4668
  _globals['_CLEARPARTYONBOARDINGFLAGREQUEST']._serialized_start=4671
  _globals['_CLEARPARTYONBOARDINGFLAGREQUEST']._serialized_end=4916
  _globals['_CLEARPARTYONBOARDINGFLAGRESPONSE']._serialized_start=4919
  _globals['_CLEARPARTYONBOARDINGFLAGRESPONSE']._serialized_end=5103
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_start=5292
  _globals['_PARTYMANAGEMENTSERVICE']._serialized_end=6355
# @@protoc_insertion_point(module_scope)
