# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nycom/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1/standalone_bft_ordering_service.proto\x12Scom.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1\"9\n\x0bSendRequest\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload\"S\n\x0cSendResponse\x12.\n\x10rejection_reason\x18\x01 \x01(\tH\x00R\x0frejectionReason\x88\x01\x01\x42\x13\n\x11_rejection_reason\"7\n\x12ReadOrderedRequest\x12!\n\x0cstart_height\x18\x01 \x01(\x03R\x0bstartHeight\"\xa1\x01\n\x13ReadOrderedResponse\x12\x16\n\x06height\x18\x01 \x01(\x03R\x06height\x12r\n\x05\x62lock\x18\x02 \x03(\x0b\x32\\.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.OrderedR\x05\x62lock\"5\n\x07Ordered\x12\x10\n\x03tag\x18\x01 \x01(\tR\x03tag\x12\x18\n\x07payload\x18\x02 \x01(\x0cR\x07payload2\xd1\x03\n\x1cStandaloneBftOrderingService\x12\xcb\x01\n\x04Send\x12`.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.SendRequest\x1a\x61.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.SendResponse\x12\xe2\x01\n\x0bReadOrdered\x12g.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.ReadOrderedRequest\x1ah.com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.ReadOrderedResponse0\x01\x42\x85\x01Z\x82\x01github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.synchronizer.sequencing.sequencer.bftordering.standalone.v1.standalone_bft_ordering_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z\202\001github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/synchronizer/sequencing/sequencer/bftordering/standalone/v1'
  _globals['_SENDREQUEST']._serialized_start=210
  _globals['_SENDREQUEST']._serialized_end=267
  _globals['_SENDRESPONSE']._serialized_start=269
  _globals['_SENDRESPONSE']._serialized_end=352
  _globals['_READORDEREDREQUEST']._serialized_start=354
  _globals['_READORDEREDREQUEST']._serialized_end=409
  _globals['_READORDEREDRESPONSE']._serialized_start=412
  _globals['_READORDEREDRESPONSE']._serialized_end=573
  _globals['_ORDERED']._serialized_start=575
  _globals['_ORDERED']._serialized_end=628
  _globals['_STANDALONEBFTORDERINGSERVICE']._serialized_start=631
  _globals['_STANDALONEBFTORDERINGSERVICE']._serialized_end=1096
# @@protoc_insertion_point(module_scope)
