# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import synchronizer_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_synchronizer__parameters__pb2
from ....protocol.v30 import topology_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_topology__pb2
from . import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nNcom/digitalasset/canton/topology/admin/v30/topology_manager_read_service.proto\x12*com.digitalasset.canton.topology.admin.v30\x1a\x42\x63om/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x1a\x33\x63om/digitalasset/canton/protocol/v30/topology.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\x90\x05\n\tBaseQuery\x12I\n\x05store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12\x1c\n\tproposals\x18\x02 \x01(\x08R\tproposals\x12Z\n\toperation\x18\x03 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12\x38\n\x08snapshot\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampH\x00R\x08snapshot\x12\x37\n\nhead_state\x18\x06 \x01(\x0b\x32\x16.google.protobuf.EmptyH\x00R\theadState\x12W\n\x05range\x18\x07 \x01(\x0b\x32?.com.digitalasset.canton.topology.admin.v30.BaseQuery.TimeRangeH\x00R\x05range\x12*\n\x11\x66ilter_signed_key\x18\x08 \x01(\tR\x0f\x66ilterSignedKey\x12.\n\x10protocol_version\x18\t \x01(\x05H\x01R\x0fprotocolVersion\x88\x01\x01\x1am\n\tTimeRange\x12.\n\x04\x66rom\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x04\x66rom\x12\x30\n\x05until\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x05untilB\x0c\n\ntime_queryB\x13\n\x11_protocol_versionJ\x04\x08\x04\x10\x05\"\xde\x03\n\nBaseResult\x12I\n\x05store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x05store\x12\x38\n\tsequenced\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tsequenced\x12\x39\n\nvalid_from\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tvalidFrom\x12;\n\x0bvalid_until\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\nvalidUntil\x12Z\n\toperation\x18\x05 \x01(\x0e\x32<.com.digitalasset.canton.protocol.v30.Enums.TopologyChangeOpR\toperation\x12)\n\x10transaction_hash\x18\x06 \x01(\x0cR\x0ftransactionHash\x12\x16\n\x06serial\x18\x07 \x01(\x05R\x06serial\x12\x34\n\x16signed_by_fingerprints\x18\x08 \x03(\tR\x14signedByFingerprints\"\xe4\x01\n\x1eListNamespaceDelegationRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\x12\x41\n\x1d\x66ilter_target_key_fingerprint\x18\x03 \x01(\tR\x1a\x66ilterTargetKeyFingerprint\"\xbb\x02\n\x1fListNamespaceDelegationResponse\x12l\n\x07results\x18\x01 \x03(\x0b\x32R.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse.ResultR\x07results\x1a\xa9\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12M\n\x04item\x18\x02 \x01(\x0b\x32\x39.com.digitalasset.canton.protocol.v30.NamespaceDelegationR\x04item\"\xae\x01\n+ListDecentralizedNamespaceDefinitionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x66ilter_namespace\x18\x02 \x01(\tR\x0f\x66ilterNamespace\"\xe2\x02\n,ListDecentralizedNamespaceDefinitionResponse\x12y\n\x07results\x18\x01 \x03(\x0b\x32_.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse.ResultR\x07results\x1a\xb6\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Z\n\x04item\x18\x02 \x01(\x0b\x32\x46.com.digitalasset.canton.protocol.v30.DecentralizedNamespaceDefinitionR\x04item\"\xd8\x01\n\x1cListOwnerToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x31\n\x15\x66ilter_key_owner_type\x18\x02 \x01(\tR\x12\x66ilterKeyOwnerType\x12/\n\x14\x66ilter_key_owner_uid\x18\x03 \x01(\tR\x11\x66ilterKeyOwnerUid\"\xb5\x02\n\x1dListOwnerToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.OwnerToKeyMappingR\x04item\"\x97\x01\n\x1cListPartyToKeyMappingRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\"\xb5\x02\n\x1dListPartyToKeyMappingResponse\x12j\n\x07results\x18\x01 \x03(\x0b\x32P.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse.ResultR\x07results\x1a\xa7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12K\n\x04item\x18\x02 \x01(\x0b\x32\x37.com.digitalasset.canton.protocol.v30.PartyToKeyMappingR\x04item\"\x9e\x01\n\'ListSynchronizerTrustCertificateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xd6\x02\n(ListSynchronizerTrustCertificateResponse\x12u\n\x07results\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateResponse.ResultR\x07results\x1a\xb2\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12V\n\x04item\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SynchronizerTrustCertificateR\x04item\"\xa3\x01\n,ListParticipantSynchronizerPermissionRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xe5\x02\n-ListParticipantSynchronizerPermissionResponse\x12z\n\x07results\x18\x01 \x03(\x0b\x32`.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionResponse.ResultR\x07results\x1a\xb7\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12[\n\x04item\x18\x02 \x01(\x0b\x32G.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerPermissionR\x04item\"\x94\x01\n\x1dListPartyHostingLimitsRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x1d\n\nfilter_uid\x18\x02 \x01(\tR\tfilterUid\"\xb8\x02\n\x1eListPartyHostingLimitsResponse\x12k\n\x07results\x18\x01 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyHostingLimitsR\x04item\"\xa0\x01\n\x19ListVettedPackagesRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12-\n\x12\x66ilter_participant\x18\x02 \x01(\tR\x11\x66ilterParticipant\"\xac\x02\n\x1aListVettedPackagesResponse\x12g\n\x07results\x18\x01 \x03(\x0b\x32M.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse.ResultR\x07results\x1a\xa4\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12H\n\x04item\x18\x02 \x01(\x0b\x32\x34.com.digitalasset.canton.protocol.v30.VettedPackagesR\x04item\"\xc7\x01\n\x1dListPartyToParticipantRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12!\n\x0c\x66ilter_party\x18\x02 \x01(\tR\x0b\x66ilterParty\x12-\n\x12\x66ilter_participant\x18\x03 \x01(\tR\x11\x66ilterParticipant\"\xb8\x02\n\x1eListPartyToParticipantResponse\x12k\n\x07results\x18\x02 \x03(\x0b\x32Q.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse.ResultR\x07results\x1a\xa8\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12L\n\x04item\x18\x02 \x01(\x0b\x32\x38.com.digitalasset.canton.protocol.v30.PartyToParticipantR\x04item\"\xb4\x01\n&ListSynchronizerParametersStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xd5\x02\n\'ListSynchronizerParametersStateResponse\x12t\n\x07results\x18\x01 \x03(\x0b\x32Z.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateResponse.ResultR\x07results\x1a\xb3\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12W\n\x04item\x18\x02 \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.DynamicSynchronizerParametersR\x04item\"\xb2\x01\n$ListMediatorSynchronizerStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xcd\x02\n%ListMediatorSynchronizerStateResponse\x12r\n\x07results\x18\x01 \x03(\x0b\x32X.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateResponse.ResultR\x07results\x1a\xaf\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12S\n\x04item\x18\x02 \x01(\x0b\x32?.com.digitalasset.canton.protocol.v30.MediatorSynchronizerStateR\x04item\"\xb3\x01\n%ListSequencerSynchronizerStateRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xd0\x02\n&ListSequencerSynchronizerStateResponse\x12s\n\x07results\x18\x01 \x03(\x0b\x32Y.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateResponse.ResultR\x07results\x1a\xb0\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12T\n\x04item\x18\x02 \x01(\x0b\x32@.com.digitalasset.canton.protocol.v30.SequencerSynchronizerStateR\x04item\"\xb8\x01\n*ListSynchronizerUpgradeAnnouncementRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12\x34\n\x16\x66ilter_synchronizer_id\x18\x02 \x01(\tR\x14\x66ilterSynchronizerId\"\xdf\x02\n+ListSynchronizerUpgradeAnnouncementResponse\x12x\n\x07results\x18\x01 \x03(\x0b\x32^.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementResponse.ResultR\x07results\x1a\xb5\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12Y\n\x04item\x18\x02 \x01(\x0b\x32\x45.com.digitalasset.canton.protocol.v30.SynchronizerUpgradeAnnouncementR\x04item\"\xaf\x01\n\'ListSequencerConnectionSuccessorRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12.\n\x13\x66ilter_sequencer_id\x18\x02 \x01(\tR\x11\x66ilterSequencerId\"\xd6\x02\n(ListSequencerConnectionSuccessorResponse\x12u\n\x07results\x18\x01 \x03(\x0b\x32[.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorResponse.ResultR\x07results\x1a\xb2\x01\n\x06Result\x12P\n\x07\x63ontext\x18\x01 \x01(\x0b\x32\x36.com.digitalasset.canton.topology.admin.v30.BaseResultR\x07\x63ontext\x12V\n\x04item\x18\x02 \x01(\x0b\x32\x42.com.digitalasset.canton.protocol.v30.SequencerConnectionSuccessorR\x04item\"\x1c\n\x1aListAvailableStoresRequest\"o\n\x1bListAvailableStoresResponse\x12P\n\tstore_ids\x18\x01 \x03(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdR\x08storeIds\"\xbc\x01\n\x0eListAllRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"k\n\x0fListAllResponse\x12X\n\x06result\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x06result\"\xcb\x01\n\x1d\x45xportTopologySnapshotRequest\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"6\n\x1e\x45xportTopologySnapshotResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xcd\x01\n\x1f\x45xportTopologySnapshotV2Request\x12T\n\nbase_query\x18\x01 \x01(\x0b\x32\x35.com.digitalasset.canton.topology.admin.v30.BaseQueryR\tbaseQuery\x12)\n\x10\x65xclude_mappings\x18\x02 \x03(\tR\x0f\x65xcludeMappings\x12)\n\x10\x66ilter_namespace\x18\x03 \x01(\tR\x0f\x66ilterNamespace\"8\n ExportTopologySnapshotV2Response\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xcf\x01\n\x13GenesisStateRequest\x12g\n\x12synchronizer_store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdH\x00R\x11synchronizerStore\x88\x01\x01\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB\x15\n\x13_synchronizer_store\",\n\x14GenesisStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\xd1\x01\n\x15GenesisStateV2Request\x12g\n\x12synchronizer_store\x18\x01 \x01(\x0b\x32\x33.com.digitalasset.canton.topology.admin.v30.StoreIdH\x00R\x11synchronizerStore\x88\x01\x01\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestampB\x15\n\x13_synchronizer_store\".\n\x16GenesisStateV2Response\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk\"\x1c\n\x1aLogicalUpgradeStateRequest\"3\n\x1bLogicalUpgradeStateResponse\x12\x14\n\x05\x63hunk\x18\x01 \x01(\x0cR\x05\x63hunk2\xc4\x1e\n\x1aTopologyManagerReadService\x12\xb2\x01\n\x17ListNamespaceDelegation\x12J.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationRequest\x1aK.com.digitalasset.canton.topology.admin.v30.ListNamespaceDelegationResponse\x12\xd9\x01\n$ListDecentralizedNamespaceDefinition\x12W.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionRequest\x1aX.com.digitalasset.canton.topology.admin.v30.ListDecentralizedNamespaceDefinitionResponse\x12\xac\x01\n\x15ListOwnerToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListOwnerToKeyMappingResponse\x12\xac\x01\n\x15ListPartyToKeyMapping\x12H.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingRequest\x1aI.com.digitalasset.canton.topology.admin.v30.ListPartyToKeyMappingResponse\x12\xcd\x01\n ListSynchronizerTrustCertificate\x12S.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateRequest\x1aT.com.digitalasset.canton.topology.admin.v30.ListSynchronizerTrustCertificateResponse\x12\xdc\x01\n%ListParticipantSynchronizerPermission\x12X.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionRequest\x1aY.com.digitalasset.canton.topology.admin.v30.ListParticipantSynchronizerPermissionResponse\x12\xaf\x01\n\x16ListPartyHostingLimits\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyHostingLimitsResponse\x12\xa3\x01\n\x12ListVettedPackages\x12\x45.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesRequest\x1a\x46.com.digitalasset.canton.topology.admin.v30.ListVettedPackagesResponse\x12\xaf\x01\n\x16ListPartyToParticipant\x12I.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ListPartyToParticipantResponse\x12\xca\x01\n\x1fListSynchronizerParametersState\x12R.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateRequest\x1aS.com.digitalasset.canton.topology.admin.v30.ListSynchronizerParametersStateResponse\x12\xc4\x01\n\x1dListMediatorSynchronizerState\x12P.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateRequest\x1aQ.com.digitalasset.canton.topology.admin.v30.ListMediatorSynchronizerStateResponse\x12\xc7\x01\n\x1eListSequencerSynchronizerState\x12Q.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateRequest\x1aR.com.digitalasset.canton.topology.admin.v30.ListSequencerSynchronizerStateResponse\x12\xd6\x01\n#ListSynchronizerUpgradeAnnouncement\x12V.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementRequest\x1aW.com.digitalasset.canton.topology.admin.v30.ListSynchronizerUpgradeAnnouncementResponse\x12\xcd\x01\n ListSequencerConnectionSuccessor\x12S.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorRequest\x1aT.com.digitalasset.canton.topology.admin.v30.ListSequencerConnectionSuccessorResponse\x12\xa6\x01\n\x13ListAvailableStores\x12\x46.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresRequest\x1aG.com.digitalasset.canton.topology.admin.v30.ListAvailableStoresResponse\x12\x82\x01\n\x07ListAll\x12:.com.digitalasset.canton.topology.admin.v30.ListAllRequest\x1a;.com.digitalasset.canton.topology.admin.v30.ListAllResponse\x12\xb1\x01\n\x16\x45xportTopologySnapshot\x12I.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotRequest\x1aJ.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotResponse0\x01\x12\xb7\x01\n\x18\x45xportTopologySnapshotV2\x12K.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotV2Request\x1aL.com.digitalasset.canton.topology.admin.v30.ExportTopologySnapshotV2Response0\x01\x12\x93\x01\n\x0cGenesisState\x12?.com.digitalasset.canton.topology.admin.v30.GenesisStateRequest\x1a@.com.digitalasset.canton.topology.admin.v30.GenesisStateResponse0\x01\x12\x99\x01\n\x0eGenesisStateV2\x12\x41.com.digitalasset.canton.topology.admin.v30.GenesisStateV2Request\x1a\x42.com.digitalasset.canton.topology.admin.v30.GenesisStateV2Response0\x01\x12\xa8\x01\n\x13LogicalUpgradeState\x12\x46.com.digitalasset.canton.topology.admin.v30.LogicalUpgradeStateRequest\x1aG.com.digitalasset.canton.topology.admin.v30.LogicalUpgradeStateResponse0\x01\x42[ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.topology.admin.v30.topology_manager_read_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZYgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/topology/admin/v30'
  _globals['_BASEQUERY']._serialized_start=367
  _globals['_BASEQUERY']._serialized_end=1023
  _globals['_BASEQUERY_TIMERANGE']._serialized_start=873
  _globals['_BASEQUERY_TIMERANGE']._serialized_end=982
  _globals['_BASERESULT']._serialized_start=1026
  _globals['_BASERESULT']._serialized_end=1504
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_start=1507
  _globals['_LISTNAMESPACEDELEGATIONREQUEST']._serialized_end=1735
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_start=1738
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE']._serialized_end=2053
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_start=1884
  _globals['_LISTNAMESPACEDELEGATIONRESPONSE_RESULT']._serialized_end=2053
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_start=2056
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONREQUEST']._serialized_end=2230
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_start=2233
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE']._serialized_end=2587
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_start=2405
  _globals['_LISTDECENTRALIZEDNAMESPACEDEFINITIONRESPONSE_RESULT']._serialized_end=2587
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_start=2590
  _globals['_LISTOWNERTOKEYMAPPINGREQUEST']._serialized_end=2806
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_start=2809
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE']._serialized_end=3118
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=2951
  _globals['_LISTOWNERTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3118
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_start=3121
  _globals['_LISTPARTYTOKEYMAPPINGREQUEST']._serialized_end=3272
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_start=3275
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE']._serialized_end=3584
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_start=3417
  _globals['_LISTPARTYTOKEYMAPPINGRESPONSE_RESULT']._serialized_end=3584
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATEREQUEST']._serialized_start=3587
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATEREQUEST']._serialized_end=3745
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE']._serialized_start=3748
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE']._serialized_end=4090
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE_RESULT']._serialized_start=3912
  _globals['_LISTSYNCHRONIZERTRUSTCERTIFICATERESPONSE_RESULT']._serialized_end=4090
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONREQUEST']._serialized_start=4093
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONREQUEST']._serialized_end=4256
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE']._serialized_start=4259
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE']._serialized_end=4616
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE_RESULT']._serialized_start=4433
  _globals['_LISTPARTICIPANTSYNCHRONIZERPERMISSIONRESPONSE_RESULT']._serialized_end=4616
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_start=4619
  _globals['_LISTPARTYHOSTINGLIMITSREQUEST']._serialized_end=4767
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_start=4770
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE']._serialized_end=5082
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_start=4914
  _globals['_LISTPARTYHOSTINGLIMITSRESPONSE_RESULT']._serialized_end=5082
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_start=5085
  _globals['_LISTVETTEDPACKAGESREQUEST']._serialized_end=5245
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_start=5248
  _globals['_LISTVETTEDPACKAGESRESPONSE']._serialized_end=5548
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_start=5384
  _globals['_LISTVETTEDPACKAGESRESPONSE_RESULT']._serialized_end=5548
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_start=5551
  _globals['_LISTPARTYTOPARTICIPANTREQUEST']._serialized_end=5750
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_start=5753
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE']._serialized_end=6065
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_start=5897
  _globals['_LISTPARTYTOPARTICIPANTRESPONSE_RESULT']._serialized_end=6065
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATEREQUEST']._serialized_start=6068
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATEREQUEST']._serialized_end=6248
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE']._serialized_start=6251
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE']._serialized_end=6592
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE_RESULT']._serialized_start=6413
  _globals['_LISTSYNCHRONIZERPARAMETERSSTATERESPONSE_RESULT']._serialized_end=6592
  _globals['_LISTMEDIATORSYNCHRONIZERSTATEREQUEST']._serialized_start=6595
  _globals['_LISTMEDIATORSYNCHRONIZERSTATEREQUEST']._serialized_end=6773
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE']._serialized_start=6776
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE']._serialized_end=7109
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_start=6934
  _globals['_LISTMEDIATORSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_end=7109
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATEREQUEST']._serialized_start=7112
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATEREQUEST']._serialized_end=7291
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE']._serialized_start=7294
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE']._serialized_end=7630
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_start=7454
  _globals['_LISTSEQUENCERSYNCHRONIZERSTATERESPONSE_RESULT']._serialized_end=7630
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTREQUEST']._serialized_start=7633
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTREQUEST']._serialized_end=7817
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE']._serialized_start=7820
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE']._serialized_end=8171
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE_RESULT']._serialized_start=7990
  _globals['_LISTSYNCHRONIZERUPGRADEANNOUNCEMENTRESPONSE_RESULT']._serialized_end=8171
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORREQUEST']._serialized_start=8174
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORREQUEST']._serialized_end=8349
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE']._serialized_start=8352
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE']._serialized_end=8694
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE_RESULT']._serialized_start=8516
  _globals['_LISTSEQUENCERCONNECTIONSUCCESSORRESPONSE_RESULT']._serialized_end=8694
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_start=8696
  _globals['_LISTAVAILABLESTORESREQUEST']._serialized_end=8724
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_start=8726
  _globals['_LISTAVAILABLESTORESRESPONSE']._serialized_end=8837
  _globals['_LISTALLREQUEST']._serialized_start=8840
  _globals['_LISTALLREQUEST']._serialized_end=9028
  _globals['_LISTALLRESPONSE']._serialized_start=9030
  _globals['_LISTALLRESPONSE']._serialized_end=9137
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_start=9140
  _globals['_EXPORTTOPOLOGYSNAPSHOTREQUEST']._serialized_end=9343
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_start=9345
  _globals['_EXPORTTOPOLOGYSNAPSHOTRESPONSE']._serialized_end=9399
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_start=9402
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2REQUEST']._serialized_end=9607
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_start=9609
  _globals['_EXPORTTOPOLOGYSNAPSHOTV2RESPONSE']._serialized_end=9665
  _globals['_GENESISSTATEREQUEST']._serialized_start=9668
  _globals['_GENESISSTATEREQUEST']._serialized_end=9875
  _globals['_GENESISSTATERESPONSE']._serialized_start=9877
  _globals['_GENESISSTATERESPONSE']._serialized_end=9921
  _globals['_GENESISSTATEV2REQUEST']._serialized_start=9924
  _globals['_GENESISSTATEV2REQUEST']._serialized_end=10133
  _globals['_GENESISSTATEV2RESPONSE']._serialized_start=10135
  _globals['_GENESISSTATEV2RESPONSE']._serialized_end=10181
  _globals['_LOGICALUPGRADESTATEREQUEST']._serialized_start=10183
  _globals['_LOGICALUPGRADESTATEREQUEST']._serialized_end=10211
  _globals['_LOGICALUPGRADESTATERESPONSE']._serialized_start=10213
  _globals['_LOGICALUPGRADESTATERESPONSE']._serialized_end=10264
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_start=10267
  _globals['_TOPOLOGYMANAGERREADSERVICE']._serialized_end=14175
# @@protoc_insertion_point(module_scope)
