# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/protocol/v30/synchronizer_parameters.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/protocol/v30/synchronizer_parameters.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nBcom/digitalasset/canton/protocol/v30/synchronizer_parameters.proto\x12$com.digitalasset.canton.protocol.v30\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x1egoogle/protobuf/duration.proto\"\x97\x01\n\x1b\x41\x63sCommitmentsCatchUpConfig\x12\x32\n\x15\x63\x61tchup_interval_skip\x18\x01 \x01(\rR\x13\x63\x61tchupIntervalSkip\x12\x44\n\x1fnr_intervals_to_trigger_catchup\x18\x02 \x01(\rR\x1bnrIntervalsToTriggerCatchup\"p\n\x1dParticipantSynchronizerLimits\x12\x43\n\x1e\x63onfirmation_requests_max_rate\x18\x01 \x01(\rR\x1b\x63onfirmationRequestsMaxRateJ\x04\x08\x02\x10\x03J\x04\x08\x03\x10\x04\"\xd7\n\n\x1d\x44ynamicSynchronizerParameters\x12]\n\x1d\x63onfirmation_response_timeout\x18\x01 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1b\x63onfirmationResponseTimeout\x12U\n\x19mediator_reaction_timeout\x18\x02 \x01(\x0b\x32\x19.google.protobuf.DurationR\x17mediatorReactionTimeout\x12_\n\x1e\x61ssignment_exclusivity_timeout\x18\x03 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1c\x61ssignmentExclusivityTimeout\x12\x63\n!ledger_time_record_time_tolerance\x18\x05 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1dledgerTimeRecordTimeTolerance\x12R\n\x17reconciliation_interval\x18\x06 \x01(\x0b\x32\x19.google.protobuf.DurationR\x16reconciliationInterval\x12_\n\x1emediator_deduplication_timeout\x18\x07 \x01(\x0b\x32\x19.google.protobuf.DurationR\x1cmediatorDeduplicationTimeout\x12(\n\x10max_request_size\x18\x08 \x01(\rR\x0emaxRequestSize\x12r\n\x16onboarding_restriction\x18\t \x01(\x0e\x32;.com.digitalasset.canton.protocol.v30.OnboardingRestrictionR\x15onboardingRestriction\x12\x8b\x01\n\x1fparticipant_synchronizer_limits\x18\r \x01(\x0b\x32\x43.com.digitalasset.canton.protocol.v30.ParticipantSynchronizerLimitsR\x1dparticipantSynchronizerLimits\x12n\n&sequencer_aggregate_submission_timeout\x18\x0f \x01(\x0b\x32\x19.google.protobuf.DurationR#sequencerAggregateSubmissionTimeout\x12g\n\x0ftraffic_control\x18\x10 \x01(\x0b\x32>.com.digitalasset.canton.protocol.v30.TrafficControlParametersR\x0etrafficControl\x12y\n\x17\x61\x63s_commitments_catchup\x18\x11 \x01(\x0b\x32\x41.com.digitalasset.canton.protocol.v30.AcsCommitmentsCatchUpConfigR\x15\x61\x63sCommitmentsCatchup\x12m\n&preparation_time_record_time_tolerance\x18\x12 \x01(\x0b\x32\x19.google.protobuf.DurationR\"preparationTimeRecordTimeToleranceJ\x04\x08\x04\x10\x05J\x04\x08\x0b\x10\x0cJ\x04\x08\x0c\x10\rJ\x04\x08\x0e\x10\x0f*\xf7\x01\n\x15OnboardingRestriction\x12&\n\"ONBOARDING_RESTRICTION_UNSPECIFIED\x10\x00\x12,\n(ONBOARDING_RESTRICTION_UNRESTRICTED_OPEN\x10\x01\x12.\n*ONBOARDING_RESTRICTION_UNRESTRICTED_LOCKED\x10\x02\x12*\n&ONBOARDING_RESTRICTION_RESTRICTED_OPEN\x10\x03\x12,\n(ONBOARDING_RESTRICTION_RESTRICTED_LOCKED\x10\x04\x42UZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.protocol.v30.synchronizer_parameters_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZSgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/protocol/v30'
  _globals['_ONBOARDINGRESTRICTION']._serialized_start=1850
  _globals['_ONBOARDINGRESTRICTION']._serialized_end=2097
  _globals['_ACSCOMMITMENTSCATCHUPCONFIG']._serialized_start=212
  _globals['_ACSCOMMITMENTSCATCHUPCONFIG']._serialized_end=363
  _globals['_PARTICIPANTSYNCHRONIZERLIMITS']._serialized_start=365
  _globals['_PARTICIPANTSYNCHRONIZERLIMITS']._serialized_end=477
  _globals['_DYNAMICSYNCHRONIZERPARAMETERS']._serialized_start=480
  _globals['_DYNAMICSYNCHRONIZERPARAMETERS']._serialized_end=1847
# @@protoc_insertion_point(module_scope)
