# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/participant/protocol/v30/party_replication.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/participant/protocol/v30/party_replication.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....admin.participant.v30 import active_contract_pb2 as com_dot_digitalasset_dot_canton_dot_admin_dot_participant_dot_v30_dot_active__contract__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nHcom/digitalasset/canton/participant/protocol/v30/party_replication.proto\x12\x30\x63om.digitalasset.canton.participant.protocol.v30\x1a\x43\x63om/digitalasset/canton/admin/participant/v30/active_contract.proto\"\x82\x04\n(PartyReplicationTargetParticipantMessage\x12\x87\x01\n\ninitialize\x18\x01 \x01(\x0b\x32\x65.com.digitalasset.canton.participant.protocol.v30.PartyReplicationTargetParticipantMessage.InitializeH\x00R\ninitialize\x12\x8d\x01\n\x0esend_acs_up_to\x18\x02 \x01(\x0b\x32\x66.com.digitalasset.canton.participant.protocol.v30.PartyReplicationTargetParticipantMessage.SendAcsUpToH\x00R\x0bsendAcsUpTo\x1aY\n\nInitialize\x12K\n\"initial_contract_ordinal_inclusive\x18\x01 \x01(\rR\x1finitialContractOrdinalInclusive\x1aR\n\x0bSendAcsUpTo\x12\x43\n\x1emax_contract_ordinal_inclusive\x18\x01 \x01(\rR\x1bmaxContractOrdinalInclusiveB\r\n\x0binstruction\"\xbf\x03\n(PartyReplicationSourceParticipantMessage\x12\x82\x01\n\tacs_batch\x18\x01 \x01(\x0b\x32\x63.com.digitalasset.canton.participant.protocol.v30.PartyReplicationSourceParticipantMessage.AcsBatchH\x00R\x08\x61\x63sBatch\x12\x83\x01\n\nend_of_acs\x18\x02 \x01(\x0b\x32\x63.com.digitalasset.canton.participant.protocol.v30.PartyReplicationSourceParticipantMessage.EndOfACSH\x00R\x08\x65ndOfAcs\x1aj\n\x08\x41\x63sBatch\x12^\n\tcontracts\x18\x01 \x03(\x0b\x32@.com.digitalasset.canton.admin.participant.v30.ActiveContractOldR\tcontracts\x1a\n\n\x08\x45ndOfACSB\x10\n\x0e\x64\x61ta_or_statusBaZ_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.participant.protocol.v30.party_replication_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'Z_github.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/participant/protocol/v30'
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE']._serialized_start=196
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE']._serialized_end=710
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_INITIALIZE']._serialized_start=522
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_INITIALIZE']._serialized_end=611
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_SENDACSUPTO']._serialized_start=613
  _globals['_PARTYREPLICATIONTARGETPARTICIPANTMESSAGE_SENDACSUPTO']._serialized_end=695
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE']._serialized_start=713
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE']._serialized_end=1160
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ACSBATCH']._serialized_start=1024
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ACSBATCH']._serialized_end=1130
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ENDOFACS']._serialized_start=1132
  _globals['_PARTYREPLICATIONSOURCEPARTICIPANTMESSAGE_ENDOFACS']._serialized_end=1142
# @@protoc_insertion_point(module_scope)
