# Copyright (c) 2017-2026 Digital Asset (Switzerland) GmbH and/or its affiliates. All rights reserved.
# SPDX-License-Identifier: Apache-2.0
# fmt: off
# isort: skip_file
# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: com/digitalasset/canton/sequencer/api/v30/sequencer_service.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'com/digitalasset/canton/sequencer/api/v30/sequencer_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from ....protocol.v30 import traffic_control_parameters_pb2 as com_dot_digitalasset_dot_canton_dot_protocol_dot_v30_dot_traffic__control__parameters__pb2
from ....topology.admin.v30 import common_pb2 as com_dot_digitalasset_dot_canton_dot_topology_dot_admin_dot_v30_dot_common__pb2
from ....v30 import trace_context_pb2 as com_dot_digitalasset_dot_canton_dot_v30_dot_trace__context__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nAcom/digitalasset/canton/sequencer/api/v30/sequencer_service.proto\x12)com.digitalasset.canton.sequencer.api.v30\x1a\x45\x63om/digitalasset/canton/protocol/v30/traffic_control_parameters.proto\x1a\x37\x63om/digitalasset/canton/topology/admin/v30/common.proto\x1a/com/digitalasset/canton/v30/trace_context.proto\"N\n\x10SendAsyncRequest\x12:\n\x19signed_submission_request\x18\x01 \x01(\x0cR\x17signedSubmissionRequest\"\xfb\x01\n\x19TrafficControlErrorReason\x12`\n\x05\x65rror\x18\x01 \x01(\x0b\x32J.com.digitalasset.canton.sequencer.api.v30.TrafficControlErrorReason.ErrorR\x05\x65rror\x1a|\n\x05\x45rror\x12\x33\n\x14insufficient_traffic\x18\x01 \x01(\tH\x00R\x13insufficientTraffic\x12\x34\n\x15outdated_traffic_cost\x18\x02 \x01(\tH\x00R\x13outdatedTrafficCostB\x08\n\x06reason\"\x13\n\x11SendAsyncResponse\"^\n\x13SubscriptionRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12!\n\ttimestamp\x18\x02 \x01(\x03H\x00R\ttimestamp\x88\x01\x01\x42\x0c\n\n_timestamp\"\x9c\x01\n\x14SubscriptionResponse\x12\x34\n\x16signed_sequenced_event\x18\x01 \x01(\x0cR\x14signedSequencedEvent\x12N\n\rtrace_context\x18\x02 \x01(\x0b\x32).com.digitalasset.canton.v30.TraceContextR\x0ctraceContext\"J\n\x12\x41\x63knowledgeRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"\x15\n\x13\x41\x63knowledgeResponse\"X\n\x18\x41\x63knowledgeSignedRequest\x12<\n\x1asigned_acknowledge_request\x18\x01 \x01(\x0cR\x18signedAcknowledgeRequest\"\x1b\n\x19\x41\x63knowledgeSignedResponse\"=\n#DownloadTopologyStateForInitRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"\x9d\x01\n$DownloadTopologyStateForInitResponse\x12u\n\x15topology_transactions\x18\x01 \x01(\x0b\x32@.com.digitalasset.canton.topology.admin.v30.TopologyTransactionsR\x14topologyTransactions\"A\n\'DownloadTopologyStateForInitHashRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\"Z\n(DownloadTopologyStateForInitHashResponse\x12.\n\x13topology_state_hash\x18\x01 \x01(\x0cR\x11topologyStateHash\"W\n\x1fGetTrafficStateForMemberRequest\x12\x16\n\x06member\x18\x01 \x01(\tR\x06member\x12\x1c\n\ttimestamp\x18\x02 \x01(\x03R\ttimestamp\"{\n GetTrafficStateForMemberResponse\x12W\n\rtraffic_state\x18\x01 \x01(\x0b\x32\x32.com.digitalasset.canton.protocol.v30.TrafficStateR\x0ctrafficState\"\x10\n\x0eGetTimeRequest\"b\n\x0fGetTimeResponse\x12\x36\n\x14sequencing_timestamp\x18\x01 \x01(\x03H\x00R\x13sequencingTimestamp\x88\x01\x01\x42\x17\n\x15_sequencing_timestamp2\x98\t\n\x10SequencerService\x12\x86\x01\n\tSendAsync\x12;.com.digitalasset.canton.sequencer.api.v30.SendAsyncRequest\x1a<.com.digitalasset.canton.sequencer.api.v30.SendAsyncResponse\x12\x8e\x01\n\tSubscribe\x12>.com.digitalasset.canton.sequencer.api.v30.SubscriptionRequest\x1a?.com.digitalasset.canton.sequencer.api.v30.SubscriptionResponse0\x01\x12\x9e\x01\n\x11\x41\x63knowledgeSigned\x12\x43.com.digitalasset.canton.sequencer.api.v30.AcknowledgeSignedRequest\x1a\x44.com.digitalasset.canton.sequencer.api.v30.AcknowledgeSignedResponse\x12\xc1\x01\n\x1c\x44ownloadTopologyStateForInit\x12N.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitRequest\x1aO.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitResponse0\x01\x12\xcb\x01\n DownloadTopologyStateForInitHash\x12R.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitHashRequest\x1aS.com.digitalasset.canton.sequencer.api.v30.DownloadTopologyStateForInitHashResponse\x12\xb3\x01\n\x18GetTrafficStateForMember\x12J.com.digitalasset.canton.sequencer.api.v30.GetTrafficStateForMemberRequest\x1aK.com.digitalasset.canton.sequencer.api.v30.GetTrafficStateForMemberResponse\x12\x80\x01\n\x07GetTime\x12\x39.com.digitalasset.canton.sequencer.api.v30.GetTimeRequest\x1a:.com.digitalasset.canton.sequencer.api.v30.GetTimeResponseBZZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'com.digitalasset.canton.sequencer.api.v30.sequencer_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'ZXgithub.com/digital-asset/dazl-client/v8/go/api/com/digitalasset/canton/sequencer/api/v30'
  _globals['_SENDASYNCREQUEST']._serialized_start=289
  _globals['_SENDASYNCREQUEST']._serialized_end=367
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_start=370
  _globals['_TRAFFICCONTROLERRORREASON']._serialized_end=621
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_start=497
  _globals['_TRAFFICCONTROLERRORREASON_ERROR']._serialized_end=621
  _globals['_SENDASYNCRESPONSE']._serialized_start=623
  _globals['_SENDASYNCRESPONSE']._serialized_end=642
  _globals['_SUBSCRIPTIONREQUEST']._serialized_start=644
  _globals['_SUBSCRIPTIONREQUEST']._serialized_end=738
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_start=741
  _globals['_SUBSCRIPTIONRESPONSE']._serialized_end=897
  _globals['_ACKNOWLEDGEREQUEST']._serialized_start=899
  _globals['_ACKNOWLEDGEREQUEST']._serialized_end=973
  _globals['_ACKNOWLEDGERESPONSE']._serialized_start=975
  _globals['_ACKNOWLEDGERESPONSE']._serialized_end=996
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_start=998
  _globals['_ACKNOWLEDGESIGNEDREQUEST']._serialized_end=1086
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_start=1088
  _globals['_ACKNOWLEDGESIGNEDRESPONSE']._serialized_end=1115
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_start=1117
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITREQUEST']._serialized_end=1178
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_start=1181
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITRESPONSE']._serialized_end=1338
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHREQUEST']._serialized_start=1340
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHREQUEST']._serialized_end=1405
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHRESPONSE']._serialized_start=1407
  _globals['_DOWNLOADTOPOLOGYSTATEFORINITHASHRESPONSE']._serialized_end=1497
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_start=1499
  _globals['_GETTRAFFICSTATEFORMEMBERREQUEST']._serialized_end=1586
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_start=1588
  _globals['_GETTRAFFICSTATEFORMEMBERRESPONSE']._serialized_end=1711
  _globals['_GETTIMEREQUEST']._serialized_start=1713
  _globals['_GETTIMEREQUEST']._serialized_end=1729
  _globals['_GETTIMERESPONSE']._serialized_start=1731
  _globals['_GETTIMERESPONSE']._serialized_end=1829
  _globals['_SEQUENCERSERVICE']._serialized_start=1832
  _globals['_SEQUENCERSERVICE']._serialized_end=3008
# @@protoc_insertion_point(module_scope)
